define([
    'jquery',
    'core/modal_factory',
    'core/modal_events',
    'core/fragment',
    'core/str',
    'core/templates',
    'core/ajax',
    'theme_enlight/slick',
], function($, Modal, ModalEvents, Fragment, Str, Templates, AJAX, slick) {
    'use strict';

    var SELECTORS = {
        triggerSetting: '.editblock-theme',
        blockSettingBody: '#block-settings-parent #block-form-content',
        blockSettingForm: '#block-settings-parent #block-form-content form#enlightblocksetting',
        blockSettingClose: '#block-settings-parent #close-blocksettings .close'
    };

    var carouselActive = {
        testimonial : '.testimonial-element',
        testimonialIndicator: ".testimonial-element ol.carousel-indicators li",
        comboCourse: "#combo-list-block .carousel-item",
        featureStyle2: ".site-features #style2featurescarousel .carousel-item"
    }

    var customizeClass = 'enlight-customize-triggered';

    var THIS;


    var EnlightFront = function(contextid, inView) {
        THIS = this;
        document.querySelectorAll(SELECTORS.triggerSetting).forEach((block) => {
            THIS.setupEvents(block);
        });
        this.contextId = contextid;
        this.setupTitleAnimation();
        this.setupCarouselactive();
        this.ourTeamHandler();
        this.combolistHandler();
        this.inView = inView;
        window.onload = function () {
            var loader = document.getElementById('theme_loader');
            if (loader) {
                var style = window.getComputedStyle(loader);
                if (style.display != 'none') {
                    loader.style.visibility = "hidden";
                }
            }
        }
    };


    EnlightFront.prototype.ourteamContainer = $('.our-team-block .ourteam-ajax-container');

    EnlightFront.prototype.ourTeamHandler = function() {
        var self = this;
        $('.our-team .card-header').click(function() {
            var content = $(this).parents('.team-user-item').find('.ourteam-continer').html();
            self.ourteamContainer.show();
            self.animateOurteam(content);
        });

        if ($('body').hasClass('dir-rtl')) {
            // Close event for the our team ajax container.
             $(document.body).on('click', '.ourteam-ajax-container .overlay, .ourteam-ajax-container .close', function() {
               $('.ourteam-ajax-container').hide();
            });
        } else {
            $(document.body).on('click', '.ourteam-ajax-container .overlay, .ourteam-ajax-container .close', function() {
                $('.ourteam-ajax-container').hide();
            });
        }
    };

    EnlightFront.prototype.combolistHandler = function() {
        $('select#combolist-container').on('change', function() {
            var categoryid = $(this).val();
            var result = Fragment.loadFragment('theme_enlight', 'get_combocate_courses', THIS.contextId, {categoryid: categoryid});
            result.done(function(html, js) {
                console.log(html);
                $("#frontpage-category-combo").find("#combo-list-block").replaceWith(html);
                $("#frontpage-category-combo #combo-list-block").find(".carousel-item:nth-child(1)").addClass("active");
            });
        });
    };

    EnlightFront.prototype.animateOurteam = function(html) {
        var self = this;
        self.ourteamContainer.html(html);
        if ($('body').hasClass('dir-rtl')) {
            self.ourteamContainer.find('.inner-block').show('slide', {direction:"left"}, 500);
        } else {
            self.ourteamContainer.find('.inner-block').show('slide', {direction: "right"}, 500);
        }
        return true;
    };

    EnlightFront.prototype.setupCarouselactive = function() {
        this.testimonialCarsouselHandler();
        this.comboCourseCarsouselHandler();
        this.siteFeatureCarsouselHandler();
    };

    EnlightFront.prototype.siteFeatureCarsouselHandler = function() {

        var featureStyle2Carousel = document.querySelectorAll(carouselActive.featureStyle2)[0];
        if (featureStyle2Carousel) {
            featureStyle2Carousel.classList.add("active");
        }
    };

    EnlightFront.prototype.comboCourseCarsouselHandler = function() {
        var comboCourseCarousel = document.querySelectorAll(carouselActive.comboCourse)[0];
        if (comboCourseCarousel) {
            comboCourseCarousel.classList.add("active");
        }
    };

    EnlightFront.prototype.testimonialCarsouselHandler = function() {
        var testimonialCarousel = document.querySelectorAll(carouselActive.testimonial)[0];
        if (testimonialCarousel) {
            $(testimonialCarousel).find(".carousel-item:nth-child(1)").addClass('active');
            $(testimonialCarousel).find("carousel-indicators li:nth-child(1)").addClass('active');
        }
        var testimonialCarouselIndicator = document.querySelectorAll(carouselActive.testimonialIndicator);
        if (testimonialCarouselIndicator) {
            testimonialCarouselIndicator.forEach(function(item, index) {
                console.log(typeof index);
                if(index == 0) {
                    item.setAttribute("class", "active");
                }
                item.setAttribute("data-slide-to", index);
            });
        }
    };

    EnlightFront.prototype.contextId = 0;

    EnlightFront.prototype.inView = function(){};

    EnlightFront.prototype.setupEvents = function(block) {
        // Setup blocks settings.
        block.addEventListener('click', function(event) {
            document.querySelectorAll(SELECTORS.triggerSetting).forEach((prev) => {
                prev.parentNode.classList.remove(customizeClass);
            });
            this.parentNode.classList.add(customizeClass);
            var loaderElement = $(event.currentTarget);
            loaderElement.addClass('active');
            THIS.triggerSettingModal(loaderElement, this.getAttribute('data-setting'), this.getAttribute('data-updateid'));
        });
    };

    EnlightFront.prototype.triggerSettingModal = function(loaderElement, setting='', updateid = '') {
        if (setting != '') {
            Fragment.loadFragment('theme_enlight', 'load_block_settings', THIS.contextId, {block: setting}).done((html, js) => {
                document.querySelector(SELECTORS.blockSettingBody).parentNode.classList.add('show');
                Templates.replaceNodeContents(SELECTORS.blockSettingBody, html, js);
                document.querySelector(SELECTORS.blockSettingForm).addEventListener('submit', (e) => {
                    e.preventDefault();
                    THIS.submitBlockSettings(e, setting, updateid);
                    THIS.triggerSettingModal(setting, updateid);
                });
                $('.form-group.fitem.btn-cancel input#id_cancel').click(function(){
                   $('#block-settings-parent').removeClass('show');
                   Templates.replaceNodeContents(SELECTORS.blockSettingBody, '', '');
                });
                document.querySelectorAll(SELECTORS.blockSettingClose)[0].addEventListener('click', () => {
                    document.querySelector(SELECTORS.blockSettingBody).parentNode.classList.remove('show');
                    Templates.replaceNodeContents(SELECTORS.blockSettingBody, '', '');
                });
                $(loaderElement).removeClass('active');
            });
        }
    }

    EnlightFront.prototype.submitBlockSettings = (e, setting, updateid) => {
        var blockform = document.querySelector(SELECTORS.blockSettingForm);
        let loaderElement = $(e.currentTarget).find("#id_submitbutton").parent();
        let button = $(e.currentTarget).find("#id_submitbutton");
        button.addClass('active');
        button.attr('disabled', true);
        loaderElement.addClass('active');
        var blockformdata = new FormData(blockform);
        var formdatastr = new URLSearchParams(blockformdata).toString();

        Fragment.loadFragment('theme_enlight', 'apply_blocksettings', THIS.contextId, {formdata: formdatastr}).done((html, js) => {
            if (html !== null) {
                Templates.replaceNode(updateid, html, js);
                var updatedblock = document.querySelector(updateid+ ' #enblock-'+setting);
                THIS.setupEvents(updatedblock);
            }
        });
        setTimeout(() => {
            button.removeClass('active');
            button.removeAttr('disabled');
            $(loaderElement).removeClass('active');
        }, 500);
    };


    EnlightFront.prototype.doTitleAnimation = () => {
        var animationBlocks = document.querySelectorAll('.frontpage-blocks [data-animation*="animated"]');
        if (animationBlocks !== null) {
            animationBlocks.forEach((block) => {
                if (THIS.inView(block)) {
                    setupAnimation(block);
                }
            })
        }

        function setupAnimation(block) {
            var animationClass = block.getAttribute('data-animation');
            block.classList.add('animated', animationClass.replace('animated', '').trim());
        }
    };

    EnlightFront.prototype.doInnerAnimation = () => {
        var animationBlocks = document.querySelectorAll('.frontpage-blocks [data-inneranimation*="animated"]');
        if (animationBlocks !== null) {
            animationBlocks.forEach((block) => {
                // if (THIS.inView(block)) {
                    doInnerAnimation(block);
                // }
            })
        }

        function doInnerAnimation(block) {
            var animationClass = block.getAttribute('data-inneranimation');
            var animateItem = block.getAttribute('data-animation-item');
            block.querySelectorAll(animateItem).forEach((item) => {
                if (THIS.inView(item)) {
                    item.classList.add('animated', animationClass.replace('animated', '').trim());
                }
            })
        }
    };

    EnlightFront.prototype.setupTitleAnimation = () => {
        window.onload = () => {
            THIS.doTitleAnimation();
            THIS.doInnerAnimation();
        };
        document.addEventListener('scroll', function() {
            THIS.doTitleAnimation();
            THIS.doInnerAnimation();
        })
    };

    return {
        init: function(contextid) {
            new EnlightFront(contextid, this.inView);
        },

        inView: function(el) {
            const rect = el.getBoundingClientRect();
            // console.log(rect);
            return (
                rect.top >= 0 &&
                rect.left >= 0 &&
                rect.bottom <= (window.innerHeight || document.documentElement.clientHeight)
                // && rect.right <= (window.innerWidth || document.documentElement.clientWidth)

            );
        }
    };

});
