<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * define enlight external class.
 * @package theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author LMSACE Dev Team
 * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace theme_enlight;

use theme_config;

/**
 * define enlight external class.
 */
class external extends \external_api {

    /**
     * Parameters defintion to preset template.
     *
     * @return array list of params
     */
    public static function apply_blocksettings_parameters() {

        return new \external_function_parameters(
            array(
                'contextid' => new \external_value(PARAM_INT, 'The context id for the course'),
                'formdata' => new \external_value(PARAM_RAW, 'The data from the user notes'),
            )
        );
    }

    /**
     * Create module using selected preset template with the preset configdata.
     * @param int $contextid
     * @param mixed $formdata
     * @return string display html.
     */
    public static function apply_blocksettings($contextid, $formdata) {
        global $PAGE, $CFG, $DB, $THEME;
        require_once($CFG->dirroot.'/lib/adminlib.php');
        parse_str($formdata, $data);
        $context = \context::instance_by_id($contextid);
        $PAGE->set_context($context);
        admin_write_settings($data);
        $PAGE->reload_theme();
        theme_enlight_get_setting('', '', true);
        $renderer = $PAGE->get_renderer('core', 'course');
        $ids = $renderer->frontpage_items_settingsid();
        if (isset($ids->{$data['blockname']})) {
            return $renderer->frontpage($ids->{$data['blockname']});
        } else if ($data['blockname'] == 'footer') {
            return \theme_enlight\output\layout::footer();
        }
        return '';
    }

    /**
     * Return parameters to preset template.
     * @return mixed
     */
    public static function apply_blocksettings_returns() {
        return new \external_value(PARAM_RAW, 'Count of Page user notes');
    }
}
