<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * course renderer.
 *
 * @package theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author LMSACE Dev Team
 * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace theme_enlight\output\core;
defined('MOODLE_INTERNAL') || die;


use moodle_url;
use lang_string;
use html_writer;
use core_course_category;
use coursecat_helper;
use stdClass;

require_once($CFG->libdir.'/formslib.php');

/**
 * The core course renderer
 */
class course_renderer extends \core_course_renderer {

    /**
     * Renders course info box.
     *
     * @param stdClass $course
     * @return string
     */
    public function course_info_box(stdClass $course) {
        global $CFG;
        require_once($CFG->dirroot.'/course/format/lib.php');
        $layout = course_get_format($course);
        if ($this->page->pagetype == 'course-info' && file_exists($CFG->dirroot.'/course/format/eduemy/lib.php')
            && $layout->get_format() == 'eduemy') {
            require_once($CFG->dirroot.'/course/format/eduemy/lib.php');
            $content = '';
            $content .= $this->output->box_start('generalbox info');
            $chelper = new \coursecat_helper();
            $chelper->set_show_courses(self::COURSECAT_SHOW_COURSES_EXPANDED);
            $content .= (new \format_eduemy\overview($course, []))->info_page();
            $content .= $this->output->box_end();
            return $content;
        }
        return parent::course_info_box($course);
    }

    /**
     * Renderer function for override the frontpage categories list
     * @return string(html)
     */
    public function popular_courses() {

        global $CFG;
        $template = [];
        $popularcoursetype = theme_enlight_get_setting('popularCourse_type');
        $popularcourseid = theme_enlight_get_setting('popularCourse_id');

        $pcoursetitle = theme_enlight_get_setting('popularcourses_title');
        $template['popularcoursetitle'] = theme_enlight_lang($pcoursetitle);
        $subtitle = theme_enlight_get_setting('popularcourses_subtitle');
        $template['popularsubcoursetitle'] = theme_enlight_lang($subtitle);
        $template['popularcoursedesc'] = theme_enlight_get_setting('popularcourses_desc');

        $headingstatus = "";
        $popularcontent = '';
        if ($popularcoursetype == 1 ) {
            $pcourses = $this->course_insights_home(1);

            if (empty($pcourses)) {
                return false;
            }
            $astu = array();
            foreach ($pcourses as $pcourse) {
                $rcourseids[] = $pcourse['cid'];
                $astu[$pcourse['cid']] = $pcourse['students'];
            }
        } else if ($popularcoursetype == 2 ) {
            $pcourses = explode(',', $popularcourseid);
            $rcourseids = array_filter($pcourses, 'strlen');
            $rcourseids = $this->check_course_id($rcourseids);
        } else {
            $rcourseids = "";
        }
        if (empty($rcourseids)) {
            return '';
        }

        $pcourseids = $rcourseids;
        $template['totalpcourse'] = count($pcourseids);
        $template['titleanimation'] = \theme_enlight\customblocks::animationclass();
        $template['classes'] = theme_enlight_block_backgroundclass('popularcoursesbg_type');
        $coursesdata = [];
        if (!empty($pcourseids)) {
            foreach ($pcourseids as $courseid) {
                $data = [];
                if (!empty($courseid)) {
                    $course = $this->get_course($courseid);
                    if (!empty($course)) {
                        $headingstatus = true;
                        $noimgurl = $this->output->image_url('no-image', 'theme');
                        $data['courseurl'] = new moodle_url('/course/view.php', array('id' => $courseid ));
                        if ($course instanceof stdClass) {
                            $course = new \core_course_list_element($course);
                        }
                        $data['coursename'] = $course->get_formatted_name();
                        $imgurl = '';
                        $summary = theme_enlight_strip_html_tags($course->summary);
                        $data['summary'] = theme_enlight_course_trim_char($summary, 75);
                        $context = \context_course::instance($course->id);
                        $nostudents = count_role_users(5, $context);

                        foreach ($course->get_course_overviewfiles() as $file) {
                            $isimage = $file->is_valid_image();
                            $imgurl = file_encode_url("$CFG->wwwroot/pluginfile.php",
                                '/'. $file->get_contextid(). '/'. $file->get_component(). '/'.
                                $file->get_filearea(). $file->get_filepath(). $file->get_filename(), !$isimage);
                            if (!$isimage) {
                                $imgurl = $noimgurl;
                            }
                        }

                        if (empty($imgurl)) {
                            $imgurl = $noimgurl;
                        }
                        $data['imgurl'] = $imgurl;
                    }
                }
                $coursesdata[] = $data;
            }
        }
        $template['courses'] = $coursesdata;
        if (empty($pcourseids) || $headingstatus != true) {
            return "";
        }

        $this->include_frontslide_js('popularcourses');
        /* Display the popular courses in Home page */
        return $this->render_template('popularcourses', $template);
    }

    /**
     * Check categories exits or not.
     * @param array $categoryids
     * @return array categories.
     */
    public function check_categories_id($categoryids) {
        global $DB;
        if (!empty($categoryids)) {
            foreach ($categoryids as $key => $categoryid) {
                if (empty($categoryid) || !is_numeric($categoryid)) {
                    unset($categoryids[$key]);
                }
                if (!$DB->record_exists('course_categories', array('id' => $categoryid))) {
                    unset($categoryids[$key]);
                }
            }
        }
        return $categoryids;
    }

    /**
     * Frontpage categories list.
     * @return string categories html.
     */
    public function frontpage_categories_list() {

        global $CFG;
        $template = [];
        $reports = [];
        $displaytype = theme_enlight_get_setting('categories_displaytype');
        if ($displaytype == '') {
            $content = html_writer::start_tag('div', array('class' => 'container'));
            $content .= parent::frontpage_categories_list();
            $content .= html_writer::end_tag('div');
            return $content;
        }

        $displayoption = theme_enlight_get_setting('categories_displaytypeoption');
        $customcategoriesids = theme_enlight_get_setting('customcategories_ids');
        if ($displayoption == 'random') {
            $categoryids = $this->get_categories_id();
            shuffle($categoryids);
            $categoryids = array_slice($categoryids, 0, 6);
        } else if ($displayoption == 'custom') {
            $cucategoryids = explode(',', $customcategoriesids);
            $categoryids = $this->check_categories_id($cucategoryids);
            $categoryids = array_slice($categoryids, 0, 6);
        }
        $categories = core_course_category::get_many($categoryids);
        $noimgurl = $this->output->image_url('no-image', 'theme');
        $tcount = count($categories);
        $template['tcount'] = $tcount;
        $template['sliderClass'] = 'list_categories';
        $titleanimation = \theme_enlight\customblocks::blockanimation('categorynewsanim');
        $template['titleanimation'] = $titleanimation;
        $template['title'] = theme_enlight_lang(theme_enlight_get_setting('coursecat_title'));
        $template['subtitle'] = theme_enlight_lang(theme_enlight_get_setting('coursecat_subtitle'));
        $template['description'] = theme_enlight_get_setting('coursecat_desc');
        $catedata = [];
        $i = 0;
        if (!empty($categories)) {
            $firstcol = [];
            $secondcol = [];
            $thirdcol = [];
            foreach ($categories as $key => $categoryinfo) {
                $data = [];
                $imgname = 'categoryimg'.$key;
                $imgurl = $this->page->theme->setting_file_url($imgname, $imgname);
                $data['imgurl'] = empty($imgurl) ? $noimgurl : $imgurl;
                $data['cateurl'] = new moodle_url('/course/index.php', array('categoryid' => $key));
                $data['catename'] = $categoryinfo->get_formatted_name();
                $data['courses'] = $categoryinfo->get_courses_count();
                $data['clearfix'] = ($displaytype != '1' || ($displaytype == "1" && $tcount <= 1)) ? true : false;
                $reports[] = $data;
                if ($i == 0) {
                    $firstcol[] = $data;
                } else if ($i == 1 || $i == 2) {
                    $secondcol[] = $data;
                } else {
                    $thirdcol[] = $data;
                }
                $i++;
            }
            $catedata['firstcol'] = $firstcol;
            $catedata['secondcol'] = $secondcol;
            $catedata['thirdcol'] = $thirdcol;
        }
        $template['caterows'] = $catedata;
        $template['mobcaterows'] = $reports;
        $this->include_frontslide_js('categorynews');
        return $this->render_template('categories', $template);
    }

    /**
     * Returns HTML to print list of available courses for the frontpage.
     *
     * @return string
     */
    public function frontpage_available_courses() {

        global $CFG;

        $displayoption = theme_enlight_get_setting('availablecourse_displaytype');
        if ($displayoption == '0') {

            $content = html_writer::start_tag('div', array('class' => 'container'));
            $content .= parent::frontpage_available_courses();
            $content .= html_writer::end_tag('div');

            return $content;
        }

        $chelper = new \coursecat_helper();
        $chelper->set_show_courses(self::COURSECAT_SHOW_COURSES_EXPANDED)->set_courses_display_options(
            array(
                'recursive' => true,
                'limit' => $CFG->frontpagecourselimit,
                'viewmoreurl' => new moodle_url('/course/index.php'),
                'viewmoretext' => new lang_string('fulllistofcourses'))
            );

        $chelper->set_attributes(array('class' => 'frontpage-course-list-all'));
        $courses = \core_course_category::top()->get_courses($chelper->get_courses_display_options());
        $totalcount = \core_course_category::top()->get_courses_count($chelper->get_courses_display_options());
        if (!$totalcount && !$this->page->user_is_editing() && has_capability('moodle/course:create',
            \context_system::instance())) {
            // Print link to create a new course, for the 1st available category.
            return $this->add_new_course_button();
        }

        return $this->available_courses($chelper, $courses, $totalcount);
    }

    /**
     * Renders the list of courses
     * @param coursecat_helper $chelper various display options
     * @param array $courses the list of courses to display
     * @param int|null $totalcount total number of courses (affects display mode if it is AUTO or pagination if applicable),
     *     defaulted to count($courses)
     * @return string
     */
    public function available_courses(\coursecat_helper $chelper, $courses, $totalcount = null) {
        if (!empty($courses)) {
            $data = [];
            $attributes = $chelper->get_and_erase_attributes('courses');
            $content = \html_writer::start_tag('div', $attributes);

            foreach ($courses as $course) {
                $classes = '';
                $data[] = $this->available_coursebox($chelper, $course, $classes);
            }
            $totalcourse = count($data);
            $categoryurl = new moodle_url('course/index.php');
            $enableteacher = theme_enlight_get_setting('avilablecourse_teacherinfo');
            $enableicon  = theme_enlight_get_setting('avilablecourseinfo_displaytype');
            $countcourse = count($data);
            $enablearrow = ($countcourse > 3) ? true : false;
            $animationclass = \theme_enlight\customblocks::blockanimation('availablecoursesanim');
            $content .= $this->render_template('availablecourses', [
                'courses' => $data,
                'category_url' => $categoryurl,
                'enableteachers' => $enableteacher,
                'totalavacount' => $totalcourse,
                'enableicon' => $enableicon,
                'enable_arrow' => $enablearrow,
                'itemanimation' => $animationclass
            ]);

            $content .= \html_writer::end_tag('div');

            $this->include_frontslide_js('availablecourses');

            return $content;
        }
    }

    /**
     * Returns HTML to print list of courses user is enrolled to for the frontpage
     *
     * Also lists remote courses or remote hosts if MNET authorisation is used
     *
     * @return string
     */
    public function frontpage_my_courses() {

        global $USER, $CFG, $DB;

        if (!isloggedin() || isguestuser()) {
            return '';
        }

        $displayoption = theme_enlight_get_setting('mycourse_displaytype');
        if ($displayoption == '0') {
            $content = html_writer::start_tag('div', array('class' => 'enrolled-course-list'));
            $coursehtml = parent::frontpage_my_courses();
            if ($coursehtml == '') {
                $mycoursestyle = "<style> #frontpage-course-list.frontpage-mycourse-list { display:none;} </style>";
                $coursehtml = html_writer::div($mycoursestyle, '', array('id' => 'mycourses'));
            }
            $content .= $coursehtml;
            $content .= html_writer::end_tag('div');
            return $content;
        }

        $courses  = enrol_get_my_courses('summary, summaryformat');
        $rhosts   = array();
        $rcourses = array();

        if (!empty($CFG->mnet_dispatcher_mode) && $CFG->mnet_dispatcher_mode === 'strict') {
            $rcourses = get_my_remotecourses($USER->id);
            $rhosts   = get_my_remotehosts();
        }

        $mycourses = '';

        if (!empty($courses) || !empty($rcourses) || !empty($rhosts)) {

            $chelper = new \coursecat_helper();
            $totalcount = count($courses);
            if (count($courses) > $CFG->frontpagecourselimit) {
                // There are more enrolled courses than we can display, display link to 'My courses'.
                $courses = array_slice($courses, 0, $CFG->frontpagecourselimit, true);
                $chelper->set_courses_display_options(array(
                        'viewmoreurl' => new moodle_url('/my/'),
                        'viewmoretext' => new lang_string('mycourses')
                    ));
            } else if (\core_course_category::top()->is_uservisible()) {
                // All enrolled courses are displayed, display link to 'All courses' if there are more courses in system.
                $chelper->set_courses_display_options(array(
                        'viewmoreurl' => new moodle_url('/course/index.php'),
                        'viewmoretext' => new lang_string('fulllistofcourses')
                    ));
                $totalcount = $DB->count_records('course') - 1;
            }
            $chelper->set_show_courses(self::COURSECAT_SHOW_COURSES_EXPANDED)->set_attributes(
                array('class' => 'frontpage-course-list-enrolled')
            );

            foreach ($courses as $course) {
                $course = new \core_course_list_element($course);
                $coursedetails = $this->available_coursebox($chelper, $course, $totalcount);
                $coursedetails['progress'] = $this->get_user_course_progress($course, $USER->id);
                $gradeurl = new moodle_url('/course/user.php', array('id' => $course->id,
                    'user' => $USER->id, 'mode' => 'grade'));
                $coursedetails['grade_link'] = $gradeurl->out(false);
                $badgeurl = new moodle_url('/badges/view.php', array('type' => 2, 'id' => $course->id));
                $coursedetails['badge_link'] = $badgeurl->out(false);
                $coursedetails['images'] = reset($coursedetails['images']);
                $courselist[] = $coursedetails;

            }
            $totalcount = count($courselist);
            $enablearrow = ($totalcount > 3) ? true : false;
            $animationclass = \theme_enlight\customblocks::blockanimation('enrolledcoursesanim');
            $mycourses = $this->render_template('mycourses', [
                'courses' => $courselist,
                'totmycount' => $totalcount,
                'enable_arrow' => $enablearrow,
                'itemanimation' => $animationclass
            ]);

        }

        $this->include_frontslide_js('mycourses');

        return $mycourses;
    }

    /**
     * Get the course images.
     * @param object $course
     * @return array course images.
     */
    public function get_courseimage($course) {
        global $CFG;
        if (!empty($course)) {

            $imgurl = $this->output->image_url('no-image', 'theme');
            $i = 0;

            foreach ($course->get_course_overviewfiles() as $file) {

                $isimage = $file->is_valid_image();
                if ($isimage) {

                    $imgurl = file_encode_url("$CFG->wwwroot/pluginfile.php",
                    '/'. $file->get_contextid(). '/'. $file->get_component(). '/'.
                    $file->get_filearea(). $file->get_filepath(). $file->get_filename(), !$isimage);
                    $data[] = ['imgurl' => $imgurl, 'target' => $i ];
                    $i++;

                }
            }
            return (empty($data)) ? array(['imgurl' => $imgurl, 'active' => true] ) : $data;
        }
    }

    /**
     * Get the available course data.
     * @param coursecat_helper $chelper
     * @param object $course
     * @param string $additionalclasses
     * @return array
     */
    public function available_coursebox(\coursecat_helper $chelper, $course, $additionalclasses = '') {
        global $CFG, $USER;
        $classes = trim('coursebox clearfix '. $additionalclasses);
        $content = \html_writer::start_tag('div', array(
            'class' => $classes,
            'data-courseid' => $course->id,
            'data-type' => self::COURSECAT_TYPE_COURSE,
        ));
        $category = \core_course_category::get($course->category);
        $data['category'] = format_string($category->name);
        $data['category_link'] = new \moodle_url('/course/index.php', array('categoryid' => $category->id));
        $coursename = $chelper->get_course_formatted_name($course);
        $data['name'] = $coursename;
        $data['summary'] = $chelper->get_course_formatted_summary($course);
        $coursenamelink = \html_writer::link(new moodle_url('/course/view.php', array('id' => $course->id)),
                                            $coursename, array('class' => $course->visible ? '' : ' dimmed'));
        $summary = $course->summary;
        $data['description'] = $summary;
        $stats = enlight_get_course_stats($course);
        if ($stats) {
            $data = array_merge($stats, $data);
        }
        $data['imgurl'] = '';
        $images = $this->get_courseimage($course);
        $data['images'] = $images;
        $data['countimage'] = count($images);
        $data['link'] = new \moodle_url('/course/view.php', array('id' => $course->id));
        $data['coursename'] = $coursenamelink;
        $data['startdate'] = userdate($course->startdate, '%B %d, %Y', '', false);
        $data['enddate'] = userdate($course->enddate, '%d/%m/%Y, %I:%M %p', '', false);
        $data['enrolicons'] = $this->get_course_icons($course);
        $data['teachers'] = $this->get_course_teachers($course);
        $data['cost'] = $this->get_currancy_course($course->id);
        $data['courseid'] = $course->id;
        $context = \context_course::instance($course->id);
        $enrolled = is_enrolled($context, $USER->id, '', true);
        if ($enrolled) {
            $enableenroll = '';
            $view = true;
        } else {
            $enableenroll = true;
            $view = '';
        }
        $data['enableEnroll'] = $enableenroll;
        $data['view'] = $view;
        $enableindicators = '';
        if (count($images) > 1) {
            $enableindicators = true;
        }
        $data['enableindicators'] = $enableindicators;
        return $data;
    }

    /**
     * Get course enrollment icons.
     * @param object $course
     */
    public function get_course_icons($course) {
        if ($icons = enrol_get_course_info_icons($course)) {
            $content = html_writer::start_tag('div', array('class' => 'enrolmenticons'));
            foreach ($icons as $pixicon) {
                $content .= $this->render($pixicon);
            }
            $content .= html_writer::end_tag('div'); // Enrolmenticons.
            return $content;
        }

    }

    /**
     * Get the course teachers
     * @param object $course
     */
    public function get_course_teachers($course) {
        // Display course contacts. See core_course_list_element::get_course_contacts().
        if ($course->has_course_contacts()) {
            $content = html_writer::start_tag('ul', array('class' => 'teachers'));
            foreach ($course->get_course_contacts() as $coursecontact) {
                $rolenames = array_map(function ($role) {
                    return $role->displayname;
                }, $coursecontact['roles']);
                $userobject = \core_user::get_user($coursecontact['user']->id);
                if (!empty($userobject)) {
                    $userpicture = new \user_picture(\core_user::get_user($coursecontact['user']->id) );
                    $userimage = html_writer::empty_tag('img', array('src' => $userpicture->get_url($this->page)) );
                }
                $name = html_writer::link(new moodle_url('/user/view.php',
                                array('id' => $coursecontact['user']->id, 'course' => SITEID)),
                            $userimage);
                $content .= html_writer::tag('li', $name, array('title' => $coursecontact['username']));
            }
            $content .= html_writer::end_tag('ul'); // Teachers.
            return $content;
        }
    }

    /**
     * Returns HTML to print list of courses user is enrolled to for the frontpage
     *
     * Also lists remote courses or remote hosts if MNET authorisation is used
     *
     * @param object $course
     * @param int $userid
     * @return string
     */
    public function get_user_course_progress($course, $userid) {
        $courseprogress = \core_completion\progress::get_course_progress_percentage($course, $userid);
        return (int) $courseprogress;
    }

    /**
     * Select the category page layout.
     * @param core_course_category $category
     * @return string $ouput
     */
    public function course_category($category) {
        global $CFG;
        $usertop = core_course_category::user_top();
        if (empty($category)) {
            $coursecat = $usertop;
        } else if (is_object($category) && $category instanceof core_course_category) {
            $coursecat = $category;
        } else {
            $categoryid = is_object($category) ? $category->id : $category;
            $coursecat = core_course_category::get($categoryid);
        }
        $site = get_site();
        $output = '';

        if ($coursecat->can_create_course() || $coursecat->has_manage_capability()) {
            // Add 'Manage' button if user has permissions to edit this category.
            $managebutton = $this->single_button(new moodle_url('/course/management.php',
                array('categoryid' => $coursecat->id)), get_string('managecourses'), 'get');
            $this->page->set_button($managebutton);
        }

        if (core_course_category::is_simple_site()) {
            // There is only one category in the system, do not display link to it.
            $strfulllistofcourses = get_string('fulllistofcourses');
            $this->page->set_title("$site->shortname: $strfulllistofcourses");
        } else if (!$coursecat->id || !$coursecat->is_uservisible()) {
            $strcategories = get_string('categories');
            $this->page->set_title("$site->shortname: $strcategories");
        } else {
            $strfulllistofcourses = get_string('fulllistofcourses');
            $this->page->set_title("$site->shortname: $strfulllistofcourses");

        }

        $categorieslist = core_course_category::make_categories_list();
        if (count($categorieslist) > 1) {
            $categorieslist[0] = get_string('categories');
            $output .= html_writer::start_tag('div', array('class' => 'categorypicker'));
            $select = new \single_select(new moodle_url('/course/index.php'), 'categoryid',
                    $categorieslist, $coursecat->id, null, 'switchcategory');

            $output .= $this->render($select);
            $output .= html_writer::end_tag('div'); // Categorypicker.
        }
        $courselisting['categorypicker'] = $output;

        $chelper = new coursecat_helper();
        if ($description = $chelper->get_category_formatted_description($coursecat)) {
            $courselisting['categorydescription'] = $this->box($description, array('class' => 'generalbox info'));
        }
         // Prepare parameters for courses and categories lists in the tree.
        $chelper->set_show_courses(self::COURSECAT_SHOW_COURSES_AUTO)->set_attributes(
            array('class' => 'category-browse category-browse-'.$coursecat->id));
        $courselisting['viewmoretext'] = new lang_string('viewallcourses');
        $courselisting['searchform'] = $this->course_search_form();

        // Bottom add new course button.
        $output = $this->container_start('buttons');
        if ($coursecat->is_uservisible()) {
            $context = get_category_or_system_context($coursecat->id);
            if (has_capability('moodle/course:create', $context)) {
                // Print link to create a new course, for the 1st available category.
                if ($coursecat->id) {
                    $url = new moodle_url('/course/edit.php', array('category' => $coursecat->id, 'returnto' => 'category'));
                } else {
                    $url = new moodle_url('/course/edit.php',
                        array('category' => $CFG->defaultrequestcategory, 'returnto' => 'topcat'));
                }
                $output .= $this->single_button($url, get_string('addnewcourse'), 'get');
            }
            ob_start();
            print_course_request_buttons($context);
            $output .= ob_get_contents();
            ob_end_clean();
        }
        $output .= $this->container_end();

        $courselisting['bottombuttons'] = $output;

        // Custom function starts here.
        $clayout = get_config('theme_enlight', 'courselayout');
        $courselisting['pagebuttons'] = $this->page->button;
        if ($clayout == "layout1") {
            $courselisting['layout1'] = true;
        } else if ($clayout == "layout2") {
            $courselisting['layout2'] = true;
            $coursedisplayoptions = array();
            $catdisplayoptions = array();
            $browse = optional_param('browse', null, PARAM_ALPHA);
            $perpage = optional_param('perpage', $CFG->coursesperpage, PARAM_INT);
            $page = optional_param('page', 0, PARAM_INT);
            $baseurl = new moodle_url('/course/index.php');
            if ($coursecat->id) {
                $baseurl->param('categoryid', $coursecat->id);
            }
            if ($perpage != $CFG->coursesperpage) {
                $baseurl->param('perpage', $perpage);
            }
            $coursedisplayoptions['limit'] = $perpage;
            $catdisplayoptions['limit'] = $perpage;
            $coursedisplayoptions['offset'] = $page * $perpage;
            $coursedisplayoptions['paginationurl'] = new moodle_url($baseurl);

            if ($browse === 'courses' || !$coursecat->get_children_count()) {

                $coursedisplayoptions['paginationurl'] = new moodle_url($baseurl, array('browse' => 'courses'));
                $catdisplayoptions['nodisplay'] = true;
                $catdisplayoptions['viewmoreurl'] = new moodle_url($baseurl, array('browse' => 'categories'));
                $catdisplayoptions['viewmoretext'] = new lang_string('viewallsubcategories');
            } else if ( $browse === 'categories' || !$coursecat->get_courses_count()) {
                $coursedisplayoptions['nodisplay'] = true;
                $catdisplayoptions['offset'] = $page * $perpage;
                $catdisplayoptions['paginationurl'] = new moodle_url($baseurl, array('browse' => 'categories'));
                $coursedisplayoptions['viewmoreurl'] = new moodle_url($baseurl, array('browse' => 'courses'));
                $coursedisplayoptions['viewmoretext'] = new lang_string('viewallcourses');
                $coursedisplayoptions['recursive'] = true;
                $coursedisplayoptions['paginationurl'] = new moodle_url($baseurl);

            } else {
                // We have a category that has both subcategories and courses, display pagination separately.
                $coursedisplayoptions['viewmoreurl'] = new moodle_url($baseurl, array('browse' => 'courses', 'page' => 1));
                $catdisplayoptions['viewmoreurl'] = new moodle_url($baseurl, array('browse' => 'categories', 'page' => 1));
                $coursedisplayoptions['recursive'] = true;

            }

            if ( !(isset($categoryid) && $categoryid) ) {

                $totalcount = core_course_category::get(0)->get_courses_count(array('recursive' => true));
            }

            $chelper->set_courses_display_options($coursedisplayoptions)->set_categories_display_options($catdisplayoptions);
            $courses = $coursecat->get_courses($chelper->get_courses_display_options());

            $totalcount = (isset($totalcount)) ? $totalcount : $coursecat->get_courses_count();

            $courselisting['courses'] = $this->course_listing_coursedetails($chelper, $coursecat, $courses);

            // Generate the pagination url.
            $paginationurl = $chelper->get_courses_display_option('paginationurl');
            $perpage = $chelper->get_courses_display_option('limit', $CFG->coursesperpage);
            $page = $chelper->get_courses_display_option('offset') / $perpage;
            $pagingbar = $this->paging_bar($totalcount, $page, $perpage, $paginationurl->out(false, array('perpage' => $perpage)));
            $courselisting['pagingbar'] = $pagingbar;

        } else {

            return parent::course_category($category);
        }
        // Browse one selected category.
        if (isset($categoryid) && $categoryid) {
            $courselisting['listcategory'] = false;
            $courselisting['listcourses'] = true;
            $courselisting['showcategorypicker'] = true;
            $courselisting['categories'] = $this->course_listing_page($chelper, $coursecat,
                [$categoryid => $coursecat->get_formatted_name() ] );
        } else {
            // List all the categories in slider view layout-1.
            $courselisting['listcategory'] = true;
            $courselisting['categories'] = $this->course_listing_page($chelper, $coursecat);
        }
        return $this->output->render_from_template('theme_enlight/courselisting', $courselisting);

    }

    /**
     * Get the course listing details.
     * @param coursecat_helper $chelper various display options
     * @param core_course_category $coursecat top category (this category's name and description will NOT be added to the tree)
     * @param object $courses courses list
     * @return string
     */
    public function course_listing_coursedetails($chelper, $coursecat, $courses) {

        if (empty($courses)) {
            return [];
        }
        $courselist = [];
        foreach ($courses as $course) {
            $courselist[] = $this->available_coursebox($chelper, $course);
        }
        return $courselist;
    }

    /**
     * Get the category listing data.
     * @param coursecat_helper $chelper various display options
     * @param core_course_category $coursecat top category
     * @param object $categories
     * @return array
     */
    public function course_listing_page($chelper, $coursecat, $categories=array()) {

        if (empty($categories)) {
            $categories = $coursecat->make_categories_list();
        }

        $baseurl = new moodle_url('/course/index.php');
        $data = [];
        $i = 0;
        foreach ($categories as $categoryid => $categoryname) {
            $cateurl = $baseurl;
            $cateurl->param('categoryid', $categoryid );
            $categorylist = [];
            // Get the category from the core_course_category object.
            $category  = $coursecat->get($categoryid);
            // Category formated name.
            $categorylist['categoryname'] = $category->name;
            $categorylist['cateid'] = $category->id;
            $categorylist['showcatecollapse'] = ($i == 0) ? true : false;
            // Returns the category path with it's parent.
            $parents = explode('/', $category->get_nested_name(false));
            // Remove the category name from the parent category path.
            array_pop($parents);
            $categorylist['parentcategory'] = implode('/', $parents);
            $categorylist['cateviewurl'] = $cateurl;
            $categorylist['categoryid'] = $categoryid;
            $courses = $category->get_courses();
            $fetchcourse = array();

            foreach ($courses as $key => $course) {
                $fetchcourse[] = $this->available_coursebox($chelper, $course);
            }

            $course = array();
            foreach ($fetchcourse as $list) {
                $course[] = $list;
            }

            $enablecourse = '';
            if (count($course) > 3) {
                $enablecourse = true;
            } else {
                $enablecourse = false;
            }

            $categorylist['enablecourse'] = $enablecourse;
            $categorylist['courses'] = $course;

            $data[] = $categorylist;

        }
        $i++;
        return $data;
    }

    /**
     * render the course blocks.
     * @param string $template
     * @param array|object $data
     */
    public function render_template($template, $data) {
        $data[$template] = 1;
        $data['ouput'] = $this->output;
        return $this->output->render_from_template('theme_enlight/course_blocks', $data);
    }

    /**
     * Get the available categories
     * @return array categories
     */
    public function get_categories() {
        global $DB;
        $categories = array();
        $results = $DB->get_records('course_categories', array('parent'  => '0', 'visible' => '1', 'depth' => '1'));
        if (!empty($results)) {
            foreach ($results as $value) {
                $categories[$value->id] = $value->name;
            }
        }
        return $categories;
    }

    /**
     * Get the categories ids.
     * @return array $categories.
     */
    public function get_categories_id() {
        global $DB;
        $categories = $DB->get_records_menu('course_categories', array('parent'  => '0', 'visible' => '1',
            'depth' => '1'), '', 'id, name', 0, 100);
        return array_keys($categories);
    }

    /**
     * Get the site couse infos.
     * @param int $f
     */
    public function course_insights_home($f = 0) {

        $courses = 0;
        $teachers = 0;
        $students = 0;
        $acourses = array();
        $astu = array();
        $atea = array();
        /* Get all courses */
        if ($ccc = get_courses('all', 'c.sortorder ASC', 'c.id,c.shortname,c.visible')) {
            foreach ($ccc as $cc) {
                if ($cc->visible == "0" || $cc->id == "1") {
                    continue;
                }
                $courses++;

                $context = \context_course::instance($cc->id);

                /* count no of teachers */
                $noteachers = count_role_users(3, $context);
                $teachers = $teachers + $noteachers;
                /* count no of students */
                $nostudents = count_role_users(5, $context);
                $students = $students + $nostudents;
                $acourses[] = array('cid' => $cc->id, 'students' => $nostudents,
                     'teachers' => $noteachers
                );
                $astu[] = $nostudents;
                $atea[] = $noteachers;
            }
        }
        if ($f == "1") {
            array_multisort($astu, SORT_DESC, $atea, SORT_DESC, $acourses);
            $acourses = array_slice($acourses, 0, 24, true);
            return $acourses;
        }
        return compact('courses', 'teachers', 'students');
    }

    /**
     * Get the course
     * @param int $courseid
     * @param bool $clone
     */
    public function get_course($courseid, $clone = true) {
        global $DB, $COURSE, $SITE;
        if (!empty($COURSE->id) && $COURSE->id == $courseid) {
            return $clone ? clone($COURSE) : $COURSE;
        } else if (!empty($SITE->id) && $SITE->id == $courseid) {
            return $clone ? clone($SITE) : $SITE;
        } else {
            $content = $DB->get_record('course', array('id' => $courseid), '*', IGNORE_MISSING);
            if (!empty($content)) {
                return $content;
            }
        }
    }
    /**
     * Validate the course ids.
     * @param array $rcourseids
     * @return array courseids.
     */
    public function check_course_id($rcourseids) {
        if (!empty($rcourseids)) {
            foreach ($rcourseids as $key => $rcourseid) {
                if (empty($rcourseid) && !is_integer($rcourseid)) {
                    unset($rcourseids[$key]);
                }
            }
        }
        return $rcourseids;
    }

    /**
     * Get the frontpage items.
     * @return object items.
     */
    public function frontpage_items_settingsid() : object {
        return (object) [
            'sitenews' => FRONTPAGENEWS,
            'availablecourses' => FRONTPAGEALLCOURSELIST,
            'enrolledcourses' => FRONTPAGEENROLLEDCOURSELIST,
            'categorynews' => FRONTPAGECATEGORYNAMES,
            'categorycombo' => FRONTPAGECATEGORYCOMBO,
            'popularcourses' => FRONTPAGEPOPULARCOURSES,
            'marketingaboutus' => FRONTPAGEMARKETING1,
            'marketinglearn' => FRONTPAGEMARKETING2,
            'sitefeatures' => FRONTPAGEFEATURES,
            'ourteam' => FRONTPAGEOURTEAM,
            'testimonials' => FRONTPAGETESTIMONIALS,
            'counters' => FRONTPAGECOUNTERS,
            'ourpartners' => FRONTPAGEPARTNERS,
        ];
    }

    /**
     * Get the block title.
     * @param string $setting
     * @param string $default
     * @return string title html.
     */
    public function frontpage_blocktitle(string $setting, string $default='') {
        $content = '';
        $title = theme_enlight_lang(theme_enlight_get_setting($setting.'_title'));
        $title = ($title) ? $title : (($default) ? get_string($default) : '');
        $description = theme_enlight_lang(theme_enlight_get_setting($setting.'_desc'));
        $subtitle = theme_enlight_lang(theme_enlight_get_setting($setting.'_subtitle'));
        $titleblock = html_writer::tag('h4', $title );
        $descriptionblock = ($description) ? html_writer::tag('p', $description ) : '';
        $subtitleblock = ($subtitle) ? html_writer::tag('h2', $subtitle ) : "";
        $titleanimation = \theme_enlight\customblocks::animationclass();
        $content .= html_writer::start_div('title-inner-block');
        $content .= html_writer::tag('div', $titleblock.$subtitleblock.$descriptionblock,
        ['class' => 'titleblock', 'data-animation' => $titleanimation]);
        $content .= html_writer::end_div();
        return $content;
    }

    /**
     * Call the frontpage slider js.
     * @param string $blockid
     * @return void
     */
    public function include_frontslide_js($blockid) {
        $this->page->requires->js_call_amd('theme_enlight/front-sliders', $blockid, []);
    }

    /**
     * Outputs contents for frontpage as configured in $CFG->frontpage or $CFG->frontpageloggedin
     * @param int|null $singleblock
     * @return string
     */
    public function frontpage(int $singleblock=null) {
        global $CFG, $SITE;

        $themeblocks = new \theme_enlight\customblocks();
        $output = '';
        $frontpageloggedin = theme_enlight_get_setting('frontpageloggedin');
        if (isloggedin() && !isguestuser() && !empty($frontpageloggedin)) {
            $frontpagelayout = $frontpageloggedin;
        } else {
            $frontpagelayout = theme_enlight_get_setting('frontpage');
        }

        if (!is_null($singleblock)) {
            $frontpagelayout = $singleblock;
        }

        foreach (explode(',', $frontpagelayout) as $v) {
            switch ($v) {
                // Display the main part of the front page.
                case FRONTPAGENEWS:
                    if ($SITE->newsitems) {
                        // Print forums only when needed.
                        require_once($CFG->dirroot .'/mod/forum/lib.php');
                        if (($newsforum = forum_get_course_forum($SITE->id, 'news')) &&
                                ($forumcontents = $this->frontpage_news($newsforum))) {
                            $newsforumcm = get_fast_modinfo($SITE)->instances['forum'][$newsforum->id];
                            $type = theme_enlight_get_setting('sitenewsType');
                            $classes = "site-news-forum";
                            $classes .= ($type == 0) ? "" : " site-news-theme-type";
                            $classes .= ($type) ? theme_enlight_block_backgroundclass('sitenewsbg_type') : '';
                            $title = $this->frontpage_blocktitle('sitenews');
                            $title = ($title) ?: $newsforumcm->get_formatted_name();
                            $output .= $this->frontpage_part('skipsitenews', 'site-news-forum',
                                $title, $forumcontents, $classes, 'sitenews', 'sitenewsbg_type');
                        }
                    }
                    break;

                case FRONTPAGEENROLLEDCOURSELIST:
                    $mycourseshtml = $this->frontpage_my_courses();
                    $type = theme_enlight_get_setting('mycourse_displaytype');
                    $classes = ' frontpage-mycourse-list';
                    $classes .= theme_enlight_block_backgroundclass('enrolledcoursesbg_type');
                    $classes .= ($type == 0) ? " frontpageblock-default" : " frontpageblock-theme";
                    $title = $this->frontpage_blocktitle('mycourse');

                    if (!empty($mycourseshtml)) {
                        $output .= $this->frontpage_part('skipmycourses', 'frontpage-course-list',
                            $title, $mycourseshtml, $classes, 'enrolledcourses', 'enrolledcoursesbg_type');
                    }
                    break;

                case FRONTPAGEALLCOURSELIST:
                        $type = theme_enlight_get_setting('availablecourse_displaytype');
                        $classes = ' frontpage-available-course ';
                        $classes .= ($type) ? theme_enlight_block_backgroundclass('availablecoursesbg_type') : '';
                        $classes .= ($type == 0) ? " frontpageblock-default" : " frontpageblock-theme";
                        $availablecourseshtml = $this->frontpage_available_courses();
                        $title = $this->frontpage_blocktitle('availablecourse');
                        $settings = ['title' => 'availablecourse_title', 'desc' => 'availablecourse_desc',
                        'block' => 'availablecourses'];
                        $output .= $this->frontpage_part('skipavailablecourses', 'frontpage-available-course-list',
                        $title, $availablecourseshtml, $classes, $settings['block'], 'availablecoursesbg_type');
                        break;

                case FRONTPAGECATEGORYNAMES:
                    $type = theme_enlight_get_setting('categories_displaytype');
                    $classes = "frontpage-category-names";
                    $classes .= theme_enlight_block_backgroundclass('categoriesbg_type');
                    $classes .= ($type == 0) ? " frontpageblock-default" : " frontpageblock-theme";
                    $title = $this->frontpage_blocktitle('coursecat');
                    $settings = ['block' => 'categorynews'];
                    $output .= $this->frontpage_part('skipcategories', 'frontpage-category-names',
                        $title, $this->frontpage_categories_list(), $classes, $settings['block'], 'categoriesbg_type');
                    break;

                case FRONTPAGECATEGORYCOMBO:
                    $classes = 'combo-element';
                    $classes .= theme_enlight_block_backgroundclass('combolistbg_type');
                    $title = $this->frontpage_blocktitle('combolist');
                    $output .= $this->frontpage_part('skipcourses', 'frontpage-category-combo',
                        $title, $this->frontpage_combo_list(), $classes, 'categorycombo', 'combolistbg_type');
                    break;

                case FRONTPAGECOURSESEARCH:
                    $classes = "frontpage-search";
                    $classes .= theme_enlight_block_backgroundclass('searchcoursesbg_type');
                    $secarchcontnet = $this->box($this->frontpage_course_search('', 'short'), 'mdl-align');
                    $title = $this->frontpage_blocktitle('csearch');
                    $output .= $this->frontpage_part('skipcourses', 'frontpage-search', $title, $secarchcontnet,
                        $classes, 'search', 'searchcoursesbg_type');
                    break;
                case FRONTPAGEPOPULARCOURSES:
                    $classes = "frontpage-popular-courses";
                    $classes .= theme_enlight_block_backgroundclass("popularcoursesbg_type");
                    $output .= $this->frontpage_themeblockpart('', 'frontpage-popular-courses', '',
                        $this->popular_courses(), $classes, 'popularcourses', 'popularcoursesbg_type');
                    break;
                case FRONTPAGEMARKETING1:
                    $classes = "frontpage-marketing-aboutus";
                    $classes .= theme_enlight_block_backgroundclass('mspot1bg_type');
                    $output .= $this->frontpage_themeblockpart('', 'frontpage-marketing-aboutus', '',
                        $themeblocks->marketingspot1(), $classes, 'marketingaboutus', 'mspot1bg_type');
                    break;
                case FRONTPAGEMARKETING2:
                    $classes = "frontpage-marketing-learn";
                    $classes .= theme_enlight_block_backgroundclass('mspot2bg_type');
                    $output .= $this->frontpage_themeblockpart('', 'frontpage-marketing-learn', '',
                        $themeblocks->marketingspot2(), $classes, 'marketinglearn', 'mspot2bg_type');
                    break;
                case FRONTPAGEFEATURES:
                    $classes = "frontpage-sitefeatures";
                    $classes .= theme_enlight_block_backgroundclass('sitefeaturesbg_type');
                    $output .= $this->frontpage_themeblockpart('', 'frontpage-sitefeatures', '',
                        $themeblocks->sitefeatures(), $classes, 'sitefeatures', 'sitefeaturesbg_type');
                    break;
                case FRONTPAGEOURTEAM:
                    $classes = "frontpage-ourteam";
                    $classes .= theme_enlight_block_backgroundclass('ourteambg_type');
                    $output .= $this->frontpage_themeblockpart('', 'frontpage-ourteam', '',
                        $themeblocks->our_team(), $classes, 'ourteam', 'ourteambg_type');
                    break;
                case FRONTPAGETESTIMONIALS:
                    $classes = "frontpage-testimonials";
                    $classes .= theme_enlight_block_backgroundclass('testimonialsbg_type');
                    $output .= $this->frontpage_themeblockpart('', 'frontpage-testimonials', '',
                        $themeblocks->testimonials(), $classes, 'testimonials', 'testimonialsbg_type');
                    break;
                case FRONTPAGECOUNTERS:
                    $classes = "frontpage-counters";
                    $classes .= theme_enlight_block_backgroundclass('counterbg_type');
                    $output .= $this->frontpage_themeblockpart('', 'frontpage-counters', '',
                        $themeblocks->counter(), $classes, 'counters', 'counterbg_type');
                    break;
                case FRONTPAGEPARTNERS:
                    $classes = "frontpage-our-partners";
                    $classes .= theme_enlight_block_backgroundclass('ourpartnerbg_type');
                    $output .= $this->frontpage_themeblockpart('', 'frontpage-our-partners', '',
                        $themeblocks->ourpartner(), $classes, 'ourpartners', 'ourpartnerbg_type');
                    break;
            }
        }
        return $output;
    }

    /**
     * Renders part of frontpage with a skip link (i.e. "My courses", "Site news", etc.)
     *
     * @param string $skipdivid
     * @param string $contentsdivid
     * @param string $header Header of the part
     * @param string $contents Contents of the part
     * @param string $classes
     * @param string $setting
     * @param string $backgroundtype
     * @return string
     */
    protected function frontpage_part($skipdivid, $contentsdivid, $header, $contents,
        $classes ='', $setting ='', $backgroundtype = '') {

        if (strval($contents) === '') {
            return '';
        }
        $output = html_writer::link('#' . $skipdivid,
            get_string('skipa', 'access', \core_text::strtolower(strip_tags($header))),
            array('class' => 'skip-block skip'));

        // Wrap frontpage part in div container.
        $animationclass = \theme_enlight\customblocks::blockanimation($setting.'anim');
        $animationitem = \theme_enlight\customblocks::animationitems($setting);
        $output .= html_writer::start_tag('div', array(
            'id' => $contentsdivid,
            'class' => $classes,
            'data-inneranimation' => $animationclass,
            'data-animation-item' => $animationitem
        ));
        $backsetting = theme_enlight_get_setting($backgroundtype);
        if (($backsetting == 1) || ($backsetting == 2)) {
            $output .= "<div class='bgtrans-overlay'></div>";
        }
        $output .= html_writer::start_div('container-fluid');
        $edithead = [];
        $output .= $header;
        if ($contentsdivid == 'frontpage-category-combo') {
            $categoryselector = new theme_enlight_combo_category_selector(null);
            $output .= $categoryselector->render();
        }
        $output .= $contents;
        $output .= html_writer::end_div();

        if ($setting != '' && is_siteadmin()) {
            $output .= html_writer::tag('div', '', ['class' => 'editblock-theme-loadicon']);
            $output .= html_writer::start_tag('span', [ 'id' => 'enblock-'.$setting,
                'class' => 'editblock-theme', 'data-updateid' => "#".$contentsdivid, 'data-setting' => $setting]);
            $output .= html_writer::tag('i', '', ['class' => 'fa fa-cog']);
            $output .= html_writer::end_tag('span');
        }
        // End frontpage part div container.
        $output .= html_writer::end_tag('div');
        $output .= html_writer::tag('span', '', array('class' => 'skip-block-to', 'id' => $skipdivid));
        return $output;
    }

    /**
     * Renders part of frontpage customblocks with a skip link (i.e. "Site features", "Ourteams", etc.)
     * @param string $skipdivid
     * @param string $contentsdivid
     * @param string $header Header of the part
     * @param string $contents Contents of the part
     * @param string $classes
     * @param string $setting
     * @param string $backgroundtype
     * @return string
     */
    protected function frontpage_themeblockpart($skipdivid, $contentsdivid, $header, $contents,
        $classes='', $setting='', $backgroundtype = '') {

        if (strval($contents) === '' ) {
            return '';
        }
        // Wrap frontpage part in div container.
        $animationclass = \theme_enlight\customblocks::blockanimation($setting.'anim');
        $animationitem = \theme_enlight\customblocks::animationitems($setting);
        $output = html_writer::start_tag('div', array(
                'id' => $contentsdivid,
                'class' => $classes,
                'data-inneranimation' => $animationclass,
                'data-animation-item' => $animationitem
            )
        );
        $edithead = [];
        $backsetting = theme_enlight_get_setting($backgroundtype);
        if (($backsetting == 1) || ($backsetting == 2)) {
            $output .= "<div class='bgtrans-overlay'></div>";
        }

        $output .= $contents;
        if ($setting != '' && is_siteadmin()) {
            $output .= html_writer::tag('div', '', ['class' => 'editblock-theme-loadicon']);
            $output .= html_writer::start_tag('span', ['class' => 'editblock-theme',
                'data-updateid' => "#". $contentsdivid, 'data-setting' => $setting]);
                $output .= html_writer::tag('i', '', ['class' => 'fa fa-cog']);
            $output .= html_writer::end_tag('span');
        }
        // End frontpage part div container.
        $output .= html_writer::end_tag('div');
        return $output;

    }

    /**
     * Front page course search box.
     * @param string $value
     * @param string $format
     * @return string course search html.
     */
    public function frontpage_course_search($value = '', $format = 'plain') {
        $template = [];
        static $count = 0;
        $formid = 'coursesearch';
        if ((++$count) > 1) {
            $formid .= $count;
        }

        switch ($format) {
            case 'navbar' :
                $formid = 'coursesearchnavbar';
                $inputid = 'navsearchbox';
                $inputsize = 20;
                break;
            case 'short' :
                $inputid = 'shortsearchbox';
                $inputsize = 12;
                break;
            default :
                $inputid = 'coursesearchbox';
                $inputsize = 30;
        }
        $template['searchurl'] = new moodle_url('/course/search.php');
        $template['formid'] = $formid;
        $template['inputid'] = $inputid;
        $template['inputsize'] = $inputsize;
        $template['inputvalue'] = s($value);
        $template['classes'] = theme_enlight_block_backgroundclass('searchcoursesbg_type');
        return $this->render_template('searchbox', $template);
    }

    /**
     * Returns HTML to display a tree of subcategories and courses in the given category
     *
     * @param coursecat_helper $chelper various display options
     * @param core_course_category $coursecat top category (this category's name and description will NOT be added to the tree)
     * @return string
     */
    protected function coursecat_tree(coursecat_helper $chelper, $coursecat) {
        // Reset the category expanded flag for this course category tree first.
        $this->categoryexpandedonload = false;
        $categorycontent = $this->coursecat_category_content($chelper, $coursecat, 0);
        if (empty($categorycontent)) {
            return '';
        }

        // Start content generation.
        $content = '';
        $attributes = $chelper->get_and_erase_attributes('course_category_tree clearfix');
        $content .= html_writer::start_tag('div', $attributes);

        if ($coursecat->get_children_count()) {
            $classes = array(
                'collapseexpand', 'aabtn'
            );

            $collapsetype = theme_enlight_combolist_type();
            // Check if the category content contains subcategories with children's content loaded.
            if ($this->categoryexpandedonload && !$collapsetype) {
                $classes[] = 'collapse-all';
                $linkname = get_string('collapseall');
            } else {
                $linkname = get_string('expandall');
            }
            // Only show the collapse/expand if there are children to expand.
            $content .= html_writer::start_tag('div', array('class' => 'collapsible-actions'));
            $content .= html_writer::link('#', $linkname, array('class' => implode(' ', $classes)));
            $content .= html_writer::end_tag('div');
            $this->page->requires->strings_for_js(array('collapseall', 'expandall'), 'moodle');
        }

        $content .= html_writer::tag('div', $categorycontent, array('class' => 'content'));
        $content .= html_writer::end_tag('div'); // Course_category_tree.
        return $content;
    }

    /**
     * Returns HTML to display a course category as a part of a tree
     *
     * This is an internal function, to display a particular category and all its contents
     * use {@see core_course_renderer::course_category()}
     *
     * @param coursecat_helper $chelper various display options
     * @param core_course_category $coursecat
     * @param int $depth depth of this category in the current tree
     * @return string
     */
    protected function coursecat_category(coursecat_helper $chelper, $coursecat, $depth) {
        // Open category tag.
        $classes = array('category');
        if (empty($coursecat->visible)) {
            $classes[] = 'dimmed_category';
        }
        if ($chelper->get_subcat_depth() > 0 && $depth >= $chelper->get_subcat_depth()) {
            // Do not load content.
            $categorycontent = '';
            $classes[] = 'notloaded';
            if ($coursecat->get_children_count() ||
                    ($chelper->get_show_courses() >= self::COURSECAT_SHOW_COURSES_COLLAPSED &&
                        $coursecat->get_courses_count())) {
                $classes[] = 'with_children';
                $classes[] = 'collapsed';
            }
        } else {
            // Load category content.
            $categorycontent = $this->coursecat_category_content($chelper, $coursecat, $depth);
            $classes[] = 'loaded';
            if (!empty($categorycontent)) {
                $classes[] = 'with_children';
                // Category content loaded with children.
                $this->categoryexpandedonload = true;
            }
        }

        if (theme_enlight_combolist_type()) {
            $classes[] = 'collapsed';
        }

        // Make sure JS file to expand category content is included.
        $this->coursecat_include_js();

        $content = html_writer::start_tag('div', array(
            'class' => join(' ', $classes),
            'data-categoryid' => $coursecat->id,
            'data-depth' => $depth,
            'data-showcourses' => $chelper->get_show_courses(),
            'data-type' => self::COURSECAT_TYPE_CATEGORY,
        ));

        // Category name.
        $categoryname = $coursecat->get_formatted_name();
        $categoryname = html_writer::link(new moodle_url('/course/index.php',
                array('categoryid' => $coursecat->id)),
                $categoryname);
        if ($chelper->get_show_courses() == self::COURSECAT_SHOW_COURSES_COUNT
                && ($coursescount = $coursecat->get_courses_count())) {
            $categoryname .= html_writer::tag('span', ' ('. $coursescount.')',
                    array('title' => get_string('numberofcourses'), 'class' => 'numberofcourse'));
        }
        $content .= html_writer::start_tag('div', array('class' => 'info'));

        $content .= html_writer::tag(($depth > 1) ? 'h4' : 'h3', $categoryname, array('class' => 'categoryname aabtn'));
        $content .= html_writer::end_tag('div'); // Info.

        // Add category content to the output.
        $content .= html_writer::tag('div', $categorycontent, array('class' => 'content'));

        $content .= html_writer::end_tag('div'); // Category.

        // Return the course category tree HTML.
        return $content;
    }

    /**
     * Get the cost currancy for course.
     * @param int $courseid
     * @return string currancy.
     */
    public function get_currancy_course($courseid) {
        $costcourse = '';
        $enrolplugin = enrol_get_instances($courseid, true);
        foreach ($enrolplugin as $key => $value) {
            if ($value->enrol == 'paypal') {
                $cost = $value->cost;
                $currency = $value->currency;
            }
        }
        if (isset($currency)) {
            $currency = theme_enlight_get_currency_symbol($currency);
        }

        if (isset($currency) && isset($cost)) {
            $costcourse = $currency . ' ' . $cost;
        }
        return $costcourse;
    }

    /**
     * Returns HTML to print tree with course categories and courses for the frontpage
     *
     * @return string
     */
    public function frontpage_combo_list() {
        global $CFG;
        // TODO MDL-10965 improve.
        $categories = [];
        $data = [];
        $tree = core_course_category::top();
        if (!$tree->get_children_count()) {
            return '';
        }
        $chelper = new coursecat_helper();
        $chelper->set_subcat_depth($CFG->maxcategorydepth)->set_categories_display_options(
            array(
                'limit' => $CFG->coursesperpage,
                'viewmoreurl' => new moodle_url('/course/index.php',
                        array('browse' => 'categories', 'page' => 1))
            ))->set_courses_display_options(
                array(
                'limit' => $CFG->coursesperpage,
                'viewmoreurl' => new moodle_url('/course/index.php',
                        array('browse' => 'courses', 'page' => 1))
            ))->set_attributes(array('class' => 'frontpage-category-combo'));
        if (!$chelper->get_categories_display_option('nodisplay')) {
            $categories = $tree->get_children($chelper->get_categories_display_options());
        }
        $noimgurl = $this->output->image_url('no-image', 'theme');
        $report = [];
        $courses = \core_course_category::top()->get_courses(array('recursive' => true));
        return $this->display_combolist_courses($courses);
    }

    /**
     * Returns the combo list courses for the frontpage.
     * @param array $courses the list of courses to display
     * @return array course combolist data
     */
    public function display_combolist_courses($courses) {
        $data = array();
        if (!empty($courses)) {
            foreach ($courses as $course) {
                $list = [];
                $courseimg = current($this->get_courseimage($course));
                $list['imgurl'] = $courseimg['imgurl'];
                $list['courseurl'] = new moodle_url('/course/view.php', array('id' => $course->id));
                $list['coursename'] = $course->get_formatted_name();
                $category = core_course_category::get($course->category);
                $list['category'] = $category->get_formatted_name();
                $data[] = $list;
            }
        }
        $data = array_chunk($data, 3);
        return $this->render_template('combolist', ['combo' => $data]);
    }
}

/**
 * The Selector of combo catagories.
 */
class theme_enlight_combo_category_selector extends \moodleform {
    /**
     * Form definition.
     */
    public function definition() {
        $mform    = $this->_form;
        $displaylist[0] = get_string('all');
        $displaylist += core_course_category::make_categories_list();
        $mform->addElement('autocomplete', 'category', '', $displaylist, array("id" => "combolist-container"));
        $mform->setDefault('category', 0);
    }
}

