<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Renderers to align Moodle's HTML with that expected by Bootstrap
 *
 * @package theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author LMSACE Dev Team
 * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace theme_enlight\output;

/**
 * Define the layout info.
 */
class layout {

    /**
     * Data for custom enlight headers.
     * @return array data.
     */
    public static function headerdata() {
        global $CFG, $PAGE, $OUTPUT, $SITE;
        require_once($CFG->libdir . '/behat/lib.php');
        require_once($CFG->dirroot . '/course/lib.php');

        $loggedin = isloggedin();

        // Add block button in editing mode.
        $addblockbutton = $OUTPUT->addblockbutton();

        user_preference_allow_ajax_update('drawer-open-nav', PARAM_ALPHA);
        user_preference_allow_ajax_update('drawer-open-block', PARAM_BOOL);
        user_preference_allow_ajax_update('drawer-open-block', PARAM_BOOL);
        $forceblockdraweropen = $OUTPUT->firstview_fakeblocks();
        if ($loggedin) {
            $blockdraweropen = (get_user_preferences('drawer-open-block') == true);
            $navdraweropen = (get_user_preferences('drawer-open-nav', 'false') == 'true');
            $courseindexopen = (get_user_preferences('drawer-open-index', true) == true);
        } else {
            $navdraweropen = false;
            $blockdraweropen = false;
            $courseindexopen = false;
        }

        if (defined('BEHAT_SITE_RUNNING')) {
            $blockdraweropen = true;
        }

        $extraclasses = ['uses-drawers'];
        if ($courseindexopen) {
            $extraclasses[] = 'drawer-open-index';
        }

        $blockshtml = $OUTPUT->blocks('side-pre');
        $hasblocks = (strpos($blockshtml, 'data-block=') !== false || !empty($addblockbutton));
        if (!$hasblocks) {
            $blockdraweropen = false;
        }

        $courseindex = core_course_drawer();
        if (!$courseindex) {
            $courseindexopen = false;
        }

        $enableheader = theme_enlight_get_setting('enableheader');
        if ($enableheader) {
            $extraclasses[] = 'secondary-header';
        }
        $headerstyle = theme_enlight_get_setting('headerStyle');
        $extraclasses[] = 'header-style-'.$headerstyle;
        $bodyattributes = $OUTPUT->body_attributes($extraclasses);

        // Enlight custom primary menu - includes.
        $enlightmenu = $OUTPUT->primarymenu();
        if ($enlightmenu == '') {
            $class = "navbar-toggler hidden-lg-up nocontent-navbar";
        } else {
            $class = "navbar-toggler hidden-lg-up";
        }
        $buildregionmainsettings = !$PAGE->include_region_main_settings_in_header_actions();
        $regionmainsettingsmenu = $buildregionmainsettings ? $OUTPUT->region_main_settings_menu() : false;
        // Secondary navigation included.
        $secondarynavigation = false;
        $overflow = '';
        if ($PAGE->has_secondary_navigation()) {
            $tablistnav = $PAGE->has_tablist_secondary_navigation();
            $moremenu = new \core\navigation\output\more_menu($PAGE->secondarynav, 'nav-tabs', true, $tablistnav);
            $secondarynavigation = $moremenu->export_for_template($OUTPUT);
            $overflowdata = $PAGE->secondarynav->get_overflow_menu_data();
            if (!is_null($overflowdata)) {
                $overflow = $overflowdata->export_for_template($OUTPUT);
            }
        }

        $primary = new \core\navigation\output\primary($PAGE);
        $renderer = $PAGE->get_renderer('core');
        $primarymenu = $primary->export_for_template($renderer);

        $surl = new \moodle_url('/course/search.php');
        $curl = new \moodle_url('/course/index.php');
        $logourl = theme_enlight_get_logo_url();
        $themeloader = get_theme_loader();
        $headerclasses = theme_enlight_header_style();
        $enablegobalsearch = false;
        if ($headerstyle != 3) {
            $enablegobalsearch = true;
        }
        $logintype = theme_enlight_get_setting('loginpageType');
        $enabledefaultlogintype = ($logintype == 0 ) ? 'enabledefaultlogintype' : '';
        $searchurl = new \moodle_url('/search/index.php');
        $header = $PAGE->activityheader;
        $headercontent = $header->export_for_template($renderer);
        $contextid = $PAGE->context->id;
        $templatecontext = [
            'sitename' => format_string($SITE->shortname, true, ['context' => \context_course::instance(SITEID),
                "escape" => false]),
            'output' => $OUTPUT,
            'sidepreblocks' => $blockshtml,
            'hasblocks' => $hasblocks,
            'bodyattributes' => $bodyattributes,
            'blockdraweropen' => $blockdraweropen,
            'courseindexopen' => isset($courseindexopen) ? $courseindexopen : false,
            'courseindex' => isset($courseindex) ? $courseindex : [],
            'navdraweropen' => $navdraweropen,
            'regionmainsettingsmenu' => $regionmainsettingsmenu,
            'hasregionmainsettingsmenu' => !empty($regionmainsettingsmenu),
            'overflow' => $overflow,
            'headercontent' => $headercontent,
            'addblockbutton' => $addblockbutton,
            'primarymoremenu' => $primarymenu['moremenu'],
            'secondarymoremenu' => $secondarynavigation ?: false,
            'mobileprimarynav' => $primarymenu['mobileprimarynav'],
            'usermenu' => $primarymenu['user'],
            'langmenu' => $primarymenu['lang'],
            'forceblockdraweropen' => $forceblockdraweropen,
            "curl" => $curl,
            "logourl" => $logourl,
            "theme_loader" => $themeloader,
            'headerstyle_class' => $headerclasses['headerstyle_class'],
            'transparent_class' => $headerclasses['transparent_class'],
            'centersplit' => $headerclasses['centersplit'],
            'topheaderclass' => $headerclasses['topheaderclass'],
            'topheadertransparentclass' => $headerclasses['topheadertransparentclass'],
            "primaryclass" => $class,
            "primarymenu" => $enlightmenu,
            'enablegobalsearch' => $enablegobalsearch,
            'searchurl' => $searchurl,
            'contextid' => $contextid,
            'enableheader' => $enableheader,
            'is_siteadmin' => is_siteadmin(),
            'enabledashboardreports' => theme_enlight_get_setting('enabledashboardreports'),
            'navdrawerthemecolor' => !empty(theme_enlight_get_setting('navdrawerbackcolor')) ? true : false,
            'cmenudisplayheader' => (theme_enlight_get_setting('cmenudisplay') == 'header') ? true : false,
            'cmenudisplaytopheader' => (theme_enlight_get_setting('cmenudisplay') == 'top') ? true : false,
            'popuplogin' => theme_enlight_get_setting('loginshowpopup'),
            'enabledefaultlogintype' => $enabledefaultlogintype
        ];
        if (!$loggedin) {
            self::logindata($templatecontext);
        }
        return $templatecontext;
    }

    /**
     * Data for custom enlight login info.
     * @param array $templatecontext
     * @return array
     */
    public static function logindata(&$templatecontext) {
        global $OUTPUT;
        $authsequence = get_enabled_auth_plugins(true); // Auths, in sequence.
        foreach ($authsequence as $authname) {
            $authplugin = get_auth_plugin($authname);
            // The auth plugin's loginpage_hook() can eventually set $frm and/or $user.
            $authplugin->loginpage_hook();
        }
        $form = new \core_auth\output\login($authsequence);
        $logindata = (array) $form->export_for_template($OUTPUT);
        $templatecontext = $logindata + $templatecontext;
    }

    /**
     * Data for custom enlight footers.
     *
     * @param array $templatecontext
     * @return void
     */
    public static function footerdata(array &$templatecontext) {
        global $OUTPUT, $CFG, $PAGE;
        $footerorders = [];
        $footerlogourl = theme_enlight_get_logo_url('footer');
        $footerstatus = theme_enlight_get_setting('footerenable');
        $footerb1order = theme_enlight_get_setting('footerb1_order');
        $footerb2order = theme_enlight_get_setting('footerb2_order');
        $footerb3order = theme_enlight_get_setting('footerb3_order');
        $footerb4order = theme_enlight_get_setting('footerb4_order');

        $footerordersinfo = [
            'footerb1order' => $footerb1order,
            'footerb2order' => $footerb2order,
            'footerb3order' => $footerb3order,
            'footerb4order' => $footerb4order,
        ];

        $footerb1status = ($footerb1order != 'none') ? 1 : 0;
        $footerb2status = ($footerb2order != 'none') ? 1 : 0;
        $footerb3status = ($footerb3order != 'none') ? 1 : 0;
        $footerb4status = ($footerb4order != 'none') ? 1 : 0;
        $footercol = $footerb1status + $footerb2status + $footerb3status + $footerb4status;
        $footermain = 1;
        switch($footercol) {
            case 4 :
                $colclass = 'col-lg-3 col-sm-6';
            break;

            case 3:
                $colclass = 'col-lg-4 col-sm-6';
            break;

            case 2:
                $colclass = 'col-lg-6 col-sm-6';
            break;

            case 1:
                $colclass = 'col-lg-12';
            break;

            case 0:
                $footermain = 0;
                $colclass = "col-lg-0";
            break;

            default:
                $colclass = 'col-lg-3 col-sm-6';
        }

        $copyright = theme_enlight_get_setting('copyright');
        $copyright = theme_enlight_lang($copyright);
        $fb1title = theme_enlight_get_setting('footerbtitle1' );
        $fb1title = theme_enlight_lang($fb1title);
        $fb2title = theme_enlight_get_setting('footerbtitle2');
        $fb2title = theme_enlight_lang($fb2title);
        $fb3title = theme_enlight_get_setting('footerbtitle3');
        $fb3title = theme_enlight_lang($fb3title);
        $fb4title = theme_enlight_get_setting('footerbtitle4');
        $fb4title = theme_enlight_lang($fb4title);
        $fb5title = theme_enlight_get_setting('footerbtitle5');
        $fb5title = theme_enlight_lang($fb5title);

        $mapadderss = theme_enlight_get_setting("mapadderss");
        $mapadderss = theme_enlight_lang($mapadderss);
        $footerblink1 = theme_enlight_get_setting('footerdesc1', 'format_html');
        $footerblink1 = theme_enlight_lang($footerblink1);
        $backtotopstatus = theme_enlight_get_setting('backToTop_status');
        $sociallinks = theme_enlight_social_links();
        $footerblink3 = theme_enlight_generate_links('footerblink3');
        $footerblink2 = theme_enlight_generate_links('footerblink2');
        $footerb4iconclass = theme_enlight_footer_address('true');
        $footericonclass = ($footerb4iconclass == "true") ? "footer-small-socials" : "";
        $footeraddress = theme_enlight_footer_address();
        $classes = theme_enlight_block_backgroundclass('footerbg_type');
        $footerbgtype = theme_enlight_get_setting("footerbg_type");
        $footerbgoverlay = (($footerbgtype == 1) || ($footerbgtype == 2)) ? true : false;
        $mobileconfig = theme_enlight_mobile_config();
        $map = theme_enlight_get_setting("footerb4displayoption") == 'map' ? true : false;
        $gallery = theme_enlight_get_setting("footerb4displayoption") == 'gallery' ? true : false;
        $galleryimages = theme_enlight_get_footer_gallery_images();
        $infoblocktitle = theme_enlight_get_setting('infoblocktitle');
        $footertemplate = [
                'output' => $OUTPUT,
            "copyright" => $copyright,
            "footerlogourl" => $footerlogourl,
                "footerstatus" => $footerstatus,
                "fb1title" => $fb1title,
                "fb2title" => $fb2title,
                "fb3title" => $fb3title,
                "fb4title" => $fb4title,
                "fb5title" => $fb5title,
            "social_links" => $sociallinks,
            "footerblink3" => $footerblink3,
            "footerblink2" => $footerblink2,
            "footerblink1" => $footerblink1,
                "colClass" => $colclass,
            "footermain" => $footermain,
        "footerAddress" => $footeraddress,
        'footericonclass' => $footericonclass,
            "backToTop" => $backtotopstatus,
            "mobileappurl" => $mobileconfig,
            "footerclasses" => $classes,
            "footerbgoverlay" => $footerbgoverlay,
            "wwwroot" => $CFG->wwwroot,
            "embedadderss" => $mapadderss,
            'galleryimages' => $galleryimages,
            "infoblocktitle" => $infoblocktitle
        ];
        $footerblocks = '';
        foreach ($footerordersinfo as $layout => $value) {
            $footertemplate[$value] = true;
            $footerblocks .= $OUTPUT->render_from_template('theme_enlight/footerinner', $footertemplate);
            unset($footertemplate[$value]);
        }
        $footertemplate['footerblocks'] = $footerblocks;
        $templatecontext += $footertemplate;
    }

    /**
     * custom enlight footer.
     *
     * @return string
     */
    public static function footer() {
        global $OUTPUT;
        $data = [];
        self::footerdata($data);
        return $OUTPUT->render_from_template('theme_enlight/footer', $data);
    }
    /**
     * Data for custom enlight dashboard
     *
     * @param array $templatecontext
     * @return void
     *
     */
    public static function dashboarddata(array &$templatecontext) {
        global $DB, $USER, $PAGE, $CFG;
        require_once($CFG->dirroot.'/theme/enlight/lib.php');
        $data = [];
        $courses = $DB->count_records_sql("SELECT COUNT(*) FROM {course} WHERE category != 0", null);
        $data['sitecourses'] = $courses;
        $enrolledcourses = enrol_get_users_courses($USER->id);
        $data['enrollcourses'] = count($enrolledcourses);
        $completedcourses = (new self)->user_completed_courses($enrolledcourses, $USER->id);
        $data['completed'] = count( $completedcourses);
        $output = $PAGE->get_renderer('core', 'badges');
        $badges = (new self)->user_badges();
        $data['badges'] = count($badges);
        $jsdata['badgesBlock'] = '';
        if (!empty($badges)) {
            $jsdata['badgesBlock'] = $output->print_badges_list($badges, $USER->id, true);
        }
        $PAGE->requires->data_for_js('dashboardData', $jsdata, true);
        $data['dashboardreports'] = theme_enlight_dashboard_reports();
        $templatecontext = $templatecontext + $data;
        return $templatecontext;
    }

    /**
     * Get the user badges
     */
    public function user_badges() {
        global $CFG, $USER;
        require_once($CFG->dirroot.'/lib/badgeslib.php');
        return badges_get_user_badges($USER->id);
    }

    /**
     * Get user completed courses.
     * @param array $courses
     * @param int $userid
     * @return array
     */
    public function user_completed_courses($courses, $userid) {
        if (!empty($courses)) {
            $completed = [];
            foreach ($courses as $k => $course) {
                $completion = new \completion_info($course);
                if ($completion->is_enabled()) {
                    if ($completion->is_course_complete($userid)) {
                        $completed[] = $course->id;
                    }
                }
            }
            return $completed;
        }
        return [];
    }
}
