<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Header content.
 * @package    theme_enlight
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

global $CFG, $PAGE;
user_preference_allow_ajax_update('drawer-open-nav', PARAM_ALPHA);
require_once($CFG->libdir . '/behat/lib.php');

if (isloggedin()) {
    if ($PAGE->pagelayout == "frontpage") {
        $navdraweropen = false;
    } else {
        $navdraweropen = (get_user_preferences('drawer-open-nav', 'false') == 'true');
    }
} else {
    $navdraweropen = false;
}

$extraclasses = [];
if ($navdraweropen) {
    $extraclasses[] = 'drawer-open-left';
}
$bodyattributes = $OUTPUT->body_attributes($extraclasses);

// Enlight custom primary menu - includes.
$primarymenu = $OUTPUT->primarymenu();
if ($primarymenu == '') {
    $class = "navbar-toggler hidden-lg-up nocontent-navbar";
} else {
    $class = "navbar-toggler hidden-lg-up";
}

$blockshtml = $OUTPUT->blocks('side-pre');
$hasblocks = strpos($blockshtml, 'data-block=') !== false;
$buildregionmainsettings = !$PAGE->include_region_main_settings_in_header_actions();
$regionmainsettingsmenu = $buildregionmainsettings ? $OUTPUT->region_main_settings_menu() : false;
// Secondary navigation included.
$secondarynavigation = false;
$tablistnav = $PAGE->has_tablist_secondary_navigation();
if (!defined('BEHAT_SITE_RUNNING')) {
    $buildsecondarynavigation = $PAGE->has_secondary_navigation();
    if ($buildsecondarynavigation) {
        $moremenu = new \core\navigation\output\more_menu($PAGE->secondarynav, 'nav-tabs', true, $tablistnav);
        $secondarynavigation = $moremenu->export_for_template($OUTPUT);
    }
}

$primary = new core\navigation\output\primary($PAGE);
$renderer = $PAGE->get_renderer('core');
$primarymenu = $primary->export_for_template($renderer);

$surl = new moodle_url('/course/search.php');
$curl = new moodle_url('/course/index.php');
$logourl = theme_enlight_get_logo_url();

$shome = get_string('home');
$scourses = get_string('courses');
$themeloader = get_theme_loader();

$headerclasses = theme_enlight_header_style();

$headerstyle = theme_enlight_get_setting('headerStyle');
$enablegobalsearch = false;
if ($headerstyle != 3) {
    $enablegobalsearch = true;
}
$searchurl = new moodle_url('/search/index.php');
$contextid = $PAGE->context->id;
$secondarynavigation = false;
if (!defined('BEHAT_SITE_RUNNING')) {
    $buildsecondarynavigation = $PAGE->has_secondary_navigation();
    if ($buildsecondarynavigation) {
        $moremenu = new \core\navigation\output\more_menu($PAGE->secondarynav, 'nav-tabs', true, $tablistnav);
        $secondarynavigation = $moremenu->export_for_template($OUTPUT);
    }
}

$templatecontext = [
    'sitename' => format_string($SITE->shortname, true, ['context' => context_course::instance(SITEID), "escape" => false]),
    'output' => $OUTPUT,
    'sidepreblocks' => $blockshtml,
    'hasblocks' => $hasblocks,
    'bodyattributes' => $bodyattributes,
    'navdraweropen' => $navdraweropen,
    'regionmainsettingsmenu' => $regionmainsettingsmenu,
    'hasregionmainsettingsmenu' => !empty($regionmainsettingsmenu),
    'primarymoremenu' => $primarymenu['moremenu'],
    'secondarymoremenu' => $secondarynavigation,
    'usermenu' => $primarymenu['user'],
    'langmenu' => $primarymenu['lang'],
    "curl" => $curl,
    "logourl" => $logourl,
    "s_home" => $shome,
    "s_courses" => $scourses,
    "theme_loader" => $themeloader,
    'headerstyle_class' => $headerclasses['headerstyle_class'],
    'transparent_class' => $headerclasses['transparent_class'],
    'centersplit' => $headerclasses['centersplit'],
    'topheaderclass' => $headerclasses['topheaderclass'],
    'topheadertransparentclass' => $headerclasses['topheadertransparentclass'],
    "primaryclass" => $class,
    "primarymenu" => $primarymenu,
    'enablegobalsearch' => $enablegobalsearch,
    'searchurl' => $searchurl,
    'contextid' => $contextid
];
$flatnavbar = $OUTPUT->render_from_template('theme_boost/nav-drawer', $templatecontext);
?>
<!--E.O.Header-->

