<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Theme functions.
 *
 * @package    theme_enlight
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

define('FRONTPAGEPOPULARCOURSES', 11);
define('FRONTPAGEMARKETING1', 12);
define('FRONTPAGEMARKETING2', 13);
define('FRONTPAGEFEATURES', 14);
define('FRONTPAGEOURTEAM', 15);
define('FRONTPAGETESTIMONIALS', 16);
define('FRONTPAGECOUNTERS', 17);
define('FRONTPAGEPARTNERS', 18);

/**
 * Load the Jquery and migration files
 * Load the our theme js file
 * @param moodle_page $page
 */
function theme_enlight_page_init(moodle_page $page) {
    global $CFG, $SESSION, $PAGE, $OUTPUT;
    // TODO: Check eduemy course format installed.
    $pagetype = $page->pagetype;
    $pathbits = explode('-', trim($pagetype));
    for ($i = 1; $i < count($pathbits); $i++) {
        $classes[] = ('path-' . join('-', array_slice($pathbits, 0, $i)));
    }
    if ($PAGE->pagelayout == 'incourse' && $PAGE->course->format == 'eduemy' && array_search('path-mod', $classes) !== false ) {
        $PAGE->set_pagelayout('edumey');
        $PAGE->add_body_class('edumey-layout');
    }
    $PAGE->add_body_class('hide');
    $PAGE->requires->js_init_code('
        if (window.self !== window.top && (document.body.classList.contains("path-mod") == false
            || document.body.classList.contains("pagelayout-edumey") == false) ) {
            window.top.location.href = window.location.href;
        } else {
            if (window.self === window.top && document.body.classList.contains("path-mod") == true
                && document.body.classList.contains("pagelayout-edumey") == true) {
                document.body.classList.remove("edumey-layout");
            }
            document.body.classList.remove("hide");
        }
        // document.body.classList.remove("hide");
    ');
    $page->requires->jquery();
    $pattern = theme_enlight_get_setting('patternselect');
    $pattern = !empty($pattern) ? 'pattern-'.$pattern : "pattern-default";
    $PAGE->add_body_class($pattern);
    $PAGE->requires->css("/theme/enlight/style/viewer.css");
    $PAGE->requires->js_call_amd("theme_enlight/base", "init");
    $PAGE->requires->js('/theme/enlight/javascript/theme.js');
    $importdemo = isset($PAGE->theme->settings->importDemo) ? $PAGE->theme->settings->importDemo : "0";
    if ( $importdemo == "1" ) {
        if (class_exists('theme_enlight\demo_import')) {
            new \theme_enlight\demo_import;
        }
    }

    if (class_exists('local_acetools\theme_sync')) {
        local_acetools\theme_sync::page_init($page);
    }
}

/**
 * Check the frontpage site news menu status
 * @param theme_config $theme The theme config object.
 * @param string $css
 * @return string $css
 */
function theme_enlight_get_pattern_color($theme, $css) {
    $patternselect = theme_enlight_get_setting('patternselect');
    $primarycolor = theme_enlight_get_setting('primarycolor');
    $secondarycolor = theme_enlight_get_setting('secondarycolor');
    $primarycolor = !(empty($primarycolor)) ? $primarycolor : '#3b82f6';
    $secondarycolor = !(empty($secondarycolor)) ? $secondarycolor : '#232323';
    if ($patternselect != '5') {
        list($primarycolor, $secondarycolor) = theme_enlight_get_patternselect_color($patternselect);
    }
    $patterncolor = array(
        "color_primary" => theme_enlight_get_rgba_color($primarycolor),
        "color_secondary" => theme_enlight_get_rgba_color($secondarycolor),
        "color_primary_10_approx" => theme_enlight_get_rgba_color($primarycolor, 1),
        "color_primary_25_approx" => theme_enlight_get_rgba_color($primarycolor, 25),
        "color_primary_50_approx" => theme_enlight_get_rgba_color($primarycolor, 5),
        "color_primary_60_approx" => theme_enlight_get_rgba_color($primarycolor, 6),
        "color_primary_70_approx" => theme_enlight_get_rgba_color($primarycolor, 7),
        "color_primary_80_approx" => theme_enlight_get_rgba_color($primarycolor, 8),
        "color_primary_90_approx" => theme_enlight_get_rgba_color($primarycolor, 9),
        "color_secondary_25_approx" => theme_enlight_get_rgba_color($secondarycolor, 25),
        "color_secondary_50_approx" => theme_enlight_get_rgba_color($secondarycolor, 5),
        "color_secondary_60_approx" => theme_enlight_get_rgba_color($secondarycolor, 6),
        "color_secondary_70_approx" => theme_enlight_get_rgba_color($secondarycolor, 7),
        "color_secondary_80_approx" => theme_enlight_get_rgba_color($secondarycolor, 8),
        "color_secondary_90_approx" => theme_enlight_get_rgba_color($secondarycolor, 9)
    );
    foreach ($patterncolor as $key => $value) {
        $tag = '[['.$key.']]';
        $replacement = $value;
        $css = str_replace($tag, $replacement, $css);
    }
    return $css;
}

/**
 * Get the theme pattern colors.
 * @param string $pattern
 * @return array $patterncolors.
 */
function theme_enlight_get_patternselect_color($pattern) {
    $patterncolors = [
        "default" => array(
             '#3b82f6',
             '#232323',
        ),
        "1" => array(
             '#7abb3b',
             '#232323',
        ),
        "2" => array(
             '#8e558e',
             '#2a2a2a',
        ),
        "3" => array(
             '#e14d43',
             '#2a2a2a',
        ),
        "4" => array(
             '#523f6d',
             '#000000',
        ),
    ];
    return $patterncolors[$pattern];
}

/**
 * Convert hex to rgba color pattern.
 * @param string $color
 * @param int $opacity
 * @return string
 */
function theme_enlight_get_rgba_color($color, $opacity = 100) {

    $color = trim($color, "#");
    $hex = hexdec($color);
    if ( strlen($color) == 6 ) {
        $r = hexdec( substr($color, 0, 2) );
        $g = hexdec( substr($color, 2, 2) );
        $b = hexdec( substr($color, 4, 2) );
        if ( $opacity > 99) {
            $opacity = 1;
        } else {
            $opacity = "0.$opacity";
        }
        $a = $opacity;
    }
    return "rgba(".$r.", ".$g.", ".$b.", ".$a.")";
}

/**
 * Create block background class form selected options.
 * @param  string $configkey Config name.
 * @return string $class available classes.
 */
function theme_enlight_block_backgroundclass($configkey) {
    $bgtype = theme_enlight_get_setting($configkey);
    $class = '';
    if (!empty($bgtype)) {
        switch($bgtype) {
            case 4:
                $class .= " background-image";
                break;
            case 2:
                $class .= ' background-image';
                $class .= ' background-overlay';
                break;
            case 1:
                $class .= ' background-overlay';
                break;
            case 0:
            default:
                $class = ' background-white';
        }
    }
    return $class;
}

/**
 * Loads the CSS Styles and replace the background images.
 * If background image not available in the settings take the default images.
 *
 * @param string $css
 * @param  theme_config $theme The theme config object.
 * @return string
 */
function theme_enlight_process_css($css, $theme) {
    global $OUTPUT, $CFG;

    $bgimgs = array(
        'testimonialsbg' => '',
        'footbgimg' => '',
        'popularcoursesbg' => '',
        'counterbg' => '',
        'availablecoursesbg' => '',
        'categoriesbg' => '',
        'enrolledcoursesbg' => '',
        'searchcoursesbg' => '',
        'sitenewsbg' => '',
        'combolistbg' => '',
        'mspot1bg' => '',
        'mspot2bg' => '',
        'sitefeaturesbg' => '',
        'ourteambg' => '',
        'ourpartnerbg' => '',
    );

    foreach ($bgimgs as $bgimg => $bgimgname) {
        $setting = $bgimg;
        $bgimage = $theme->setting_file_url($setting, $setting);
        if (empty($bgimage)) {
            $bgimage = '';
        }
        $css = theme_enlight_load_bgimg_css($css, $bgimage, $setting);
    }
    if (!empty($theme->settings->customcss)) {
        $customcss = $theme->settings->customcss;
    } else {
        $customcss = null;
    }

    $css = theme_enlight_set_customcss($css, $customcss);
    $css = theme_enlight_pre_css_set_fontwww($css, $theme);
    $css = theme_enlight_get_pattern_color($theme, $css);
    $css = theme_enlight_set_slide_opacity_css($theme, $css);
    $css = theme_enlight_set_slider_height($css, $theme);
    $css = theme_enlight_set_topheader_height($css, $theme);
    $css = theme_enlight_block_bgcolor($css, $theme);
    $css = theme_enlight_set_blocks_color_opacity_css($css, $theme);
    $css = theme_enlight_footer_soicalicon_bg($css, $theme);
    return $css;
}

/**
 * Get the Front page blocks background custom color opacity level from the settings.
 *
 * @param string $css
 * @param  theme_config $theme The theme config object.
 * @return string
 */
function theme_enlight_set_blocks_color_opacity_css($css, $theme) {
    $backtype = theme_enlight_get_background_options_settings();
    $bgoverlay = [
        'availablecolor' => 'availablecourseopacity',
        'popularcolor' => 'popularcourseopacity',
        'enrolledcoursescolor' => 'enrolledcourseopacity',
        'categoriescolor' => 'categoriesopacity',
        'combolistcolor' => 'combolistopacity',
        'sitenewscolor' => 'sitenewsopacity',
        'searchcoursecolor' => 'searchcourseopacity',
        'featureblockcolor' => 'featureblockopacity',
        'testimonialblockcolor' => 'testimonialopacity',
        'counterblockcolor' => 'counteropacity',
        'mspot1color' => 'aboutusopacity',
        'mspot2color' => 'marketingsopacity',
        'ourteamblockcolor' => 'ourteamopacity',
        'footblockcolor' => 'footerblockopacity',
        'ourpartnerblockcolor' => 'ourpartneropacity',
    ];
    foreach ($bgoverlay as $key => $value) {
        $type = $backtype[$key];
        $bgtype = $theme->settings->{$type};
        if ($bgtype == 1 || $bgtype == 2) {
            $opacity = $theme->settings->{$value};
            $css = str_replace('[['.$value.']]', $opacity, $css);
        } else {
            $css = str_replace('[['.$value.']]', 0, $css);
        }
    }
    return $css;
}

/**
 * Get the Front page blocks background type options from the settings.
 * @return array
 */
function theme_enlight_get_background_options_settings() {
    $bgbackoptions = [
        'popularcolor' => 'popularcoursesbg_type',
        'availablecolor' => 'availablecoursesbg_type',
        'enrolledcoursescolor' => 'enrolledcoursesbg_type',
        'categoriescolor' => 'categoriesbg_type',
        'combolistcolor' => 'combolistbg_type',
        'sitenewscolor' => 'sitenewsbg_type',
        'searchcoursecolor' => 'searchcoursesbg_type',
        'featureblockcolor' => 'sitefeaturesbg_type',
        'testimonialblockcolor' => 'testimonialsbg_type',
        'counterblockcolor' => 'counterbg_type',
        'mspot1color' => 'mspot1bg_type',
        'mspot2color' => 'mspot2bg_type',
        'ourteamblockcolor' => 'ourteambg_type',
        'footblockcolor' => 'footerbg_type',
        'ourpartnerblockcolor' => 'ourpartnerbg_type',
    ];
    return $bgbackoptions;
}

/**
 * Get the Front page blocks background custom color from the settings.
 *
 * @param string $css
 * @param  theme_config $theme The theme config object.
 * @return string
 */
function theme_enlight_block_bgcolor($css, $theme) {
    $backtype = theme_enlight_get_background_options_settings();
    $bgcolors = [
        'popularcolor' => 'popularcoursebgcolor',
        'availablecolor' => 'availablecoursebgcolor',
        'enrolledcoursescolor' => 'enrolledcoursebgcolor',
        'categoriescolor' => 'categoriesbgcolor',
        'combolistcolor' => 'combolistbgcolor',
        'sitenewscolor' => 'sitenewsbgcolor',
        'searchcoursecolor' => 'searchcoursebgcolor',
        'featureblockcolor' => 'featureblockbgcolor',
        'testimonialblockcolor' => 'testimonialbgcolor',
        'counterblockcolor' => 'counterbgcolor',
        'mspot1color' => 'aboutusbgcolor',
        'mspot2color' => 'marketingsbgcolor',
        'ourteamblockcolor' => 'ourteambgcolor',
        'footblockcolor' => 'footerblockbgcolor',
        'ourpartnerblockcolor' => 'ourpartnerbgcolor',
    ];
    $themecolor = theme_enlight_get_site_color();
    foreach ($bgcolors as $key => $tag) {
        $value = $theme->settings->{$key};
        if (empty($value)) {
            $type = $backtype[$key];
            $bgtype = $theme->settings->{$type};
            // Check for type is theme color or theme color and background.
            if ($bgtype == 1 || $bgtype == 2) {
                $value = $themecolor;
            }
        }
        $css = str_replace('[['.$tag.']]', $value, $css);
    }

    return $css;
}

/**
 * Load the css for background images.
 * @param string $css
 * @param string $bgimage
 * @param string $setting
 * @return string
 */
function theme_enlight_load_bgimg_css($css, $bgimage, $setting) {
    $tag = '[[' . $setting . ']]';
    if (!($bgimage)) {
        $replacement = '';
    } else {
        $replacement = $bgimage;
    }
    $css = str_replace($tag, $replacement, $css);
    return $css;
}

/**
 * Get the slider obacity level from the settings and load into scss.
 * @param theme_config $theme The theme config object.
 * @param string $css
 * @return string $css
 */
function theme_enlight_set_slide_opacity_css($theme, $css) {

    if (!empty($theme->settings->slideOverlay_opacity)) {
        $opacity = $theme->settings->slideOverlay_opacity;
    } else {
        $opacity = "0.5";
    }
    $tag = '[[color_opacity]]';
    $replacement = $opacity;
    $css = str_replace($tag, $replacement, $css);
    return $css;
}

/**
 * set the homebaner slider height.
 * @param string $css
 * @param theme_config $theme The theme config object.
 * @return string
 */
function theme_enlight_set_slider_height($css, $theme) {
    if (!empty($theme->settings->slideHeight)) {
        $height = $theme->settings->slideHeight;
        $height = intval($height);
        if ($height == "" || $height > "1300" || $height < "300") {
            $height = "550px";
        } else {
            $height = $height."px";
        }
    } else {
        $height = "600px";
    }

    $tag = '[[slideheight]]';
    $replacement = $height;
    $css = str_replace($tag, $replacement, $css);
    return $css;
}

/**
 * Set the top header height.
 * @param string $css
 * @param theme_config $theme The theme config object.
 * @return string
 */
function theme_enlight_set_topheader_height($css, $theme) {
    if (!empty($theme->settings->topheader_height)) {
        $height = $theme->settings->topheader_height;
        $height = intval($height);
        if ($height == "" || $height > "300" || $height < "5") {
            $height = "100px";
        } else {
            $height = $height."px";
        }
    } else {
        $height = "100px";
    }
    $tag = '[[topheaderheight]]';
    $replacement = $height;
    $css = str_replace($tag, $replacement, $css);
    return $css;
}

/**
 * Set the theme font.
 * @param string $css
 * @return string
 */
function theme_enlight_pre_css_set_fontwww($css) {
    global $CFG, $PAGE;
    if (empty($CFG->themewww)) {
        $themewww = $CFG->wwwroot."/theme";
    } else {
        $themewww = $CFG->themewww;
    }

    $tag = '[[setting:fontwww]]';
    $theme = theme_config::load('enlight');
    $css = str_replace($tag, $themewww.'/enlight/fonts/', $css);
    return $css;
}
/**
 * Serves any files associated with the theme settings.
 *
 * @param stdClass $course
 * @param stdClass $cm
 * @param context $context
 * @param string $filearea
 * @param array $args
 * @param bool $forcedownload
 * @param array $options
 * @return bool
 */
function theme_enlight_pluginfile($course, $cm, $context, $filearea, $args, $forcedownload, array $options = array()) {
    static $theme;
    $bgimgs = array(
        'testimonialsbg',
        'footbgimg',
        'newcoursesbg',
        'popularcoursesbg',
        'aboutbg',
        'loginbg',
        'availablecoursesbg',
        'categoriesbg',
        'enrolledcoursesbg',
        'searchcoursesbg',
        'mspot1media'
    );
    if (empty($theme)) {
        $theme = theme_config::load('enlight');
    }
    if ($context->contextlevel == CONTEXT_SYSTEM) {

        if ($filearea === 'logo') {
            return $theme->setting_file_serve('logo', $args, $forcedownload, $options);
        } else if ($filearea === 'footerlogo') {
            return $theme->setting_file_serve('footerlogo', $args, $forcedownload, $options);
        } else if ($filearea === 'style') {
            theme_enlight_serve_css($args[1]);
        } else if ($filearea === 'pagebackground') {
            return $theme->setting_file_serve('pagebackground', $args, $forcedownload, $options);
        } else if (preg_match("/slide[1-9][0-9]*image/", $filearea) !== false) {
            return $theme->setting_file_serve($filearea, $args, $forcedownload, $options);
        } else if (preg_match("/countblockimg[1-9][0-9]*/", $filearea) !== false) {
            return $theme->setting_file_serve($filearea, $args, $forcedownload, $options);
        } else if (in_array($filearea, $bgimgs)) {
            return $theme->setting_file_serve($filearea, $args, $forcedownload, $options);
        } else {
            send_file_not_found();
        }
    } else {
        send_file_not_found();
    }
}

/**
 * Serves CSS for image file updated to styles.
 *
 * @param string $filename
 * @return string
 */
function theme_enlight_serve_css($filename) {
    global $CFG;
    if (!empty($CFG->themedir)) {
        $thestylepath = $CFG->themedir . '/enlight/style/';
    } else {
        $thestylepath = $CFG->dirroot . '/theme/enlight/style/';
    }
    $thesheet = $thestylepath . $filename;

    /* http://css-tricks.com/snippets/php/intelligent-php-cache-control/ - rather than /lib/csslib.php as it is a static file who's
      contents should only change if it is rebuilt.  But! There should be no difference with TDM on so will see for the moment if
      that decision is a factor. */

    $etagfile = md5_file($thesheet);
    // File.
    $lastmodified = filemtime($thesheet);
    // Header.
    $ifmodifiedsince = (isset($_SERVER['HTTP_IF_MODIFIED_SINCE']) ? $_SERVER['HTTP_IF_MODIFIED_SINCE'] : false);
    $etagheader = (isset($_SERVER['HTTP_IF_NONE_MATCH']) ? trim($_SERVER['HTTP_IF_NONE_MATCH']) : false);

    if ((($ifmodifiedsince) && (strtotime($ifmodifiedsince) == $lastmodified)) || $etagheader == $etagfile) {
        theme_enlight_send_unmodified($lastmodified, $etagfile);
    }
    theme_enlight_send_cached_css($thestylepath, $filename, $lastmodified, $etagfile);
}

/**
 * Set browser cache used in php header.
 * @param int $lastmodified
 * @param string $etag
 * @return void
 */
function theme_enlight_send_unmodified($lastmodified, $etag) {
    $lifetime = 60 * 60 * 24 * 60;
    header('HTTP/1.1 304 Not Modified');
    header('Expires: ' . gmdate('D, d M Y H:i:s', time() + $lifetime) . ' GMT');
    header('Cache-Control: public, max-age=' . $lifetime);
    header('Content-Type: text/css; charset=utf-8');
    header('Etag: "' . $etag . '"');
    if ($lastmodified) {
        header('Last-Modified: ' . gmdate('D, d M Y H:i:s', $lastmodified) . ' GMT');
    }
    die;
}

/**
 * Cached css.
 * @param string $path
 * @param string $filename
 * @param int $lastmodified
 * @param string $etag
 * @return void
 */
function theme_enlight_send_cached_css($path, $filename, $lastmodified, $etag) {
    global $CFG;
    require_once($CFG->dirroot . '/lib/configonlylib.php'); // For min_enable_zlib_compression().
    // 60 days only - the revision may get incremented quite often.
    $lifetime = 60 * 60 * 24 * 60;

    header('Etag: "' . $etag . '"');
    header('Content-Disposition: inline; filename="'.$filename.'"');
    header('Last-Modified: ' . gmdate('D, d M Y H:i:s', $lastmodified) . ' GMT');
    header('Expires: ' . gmdate('D, d M Y H:i:s', time() + $lifetime) . ' GMT');
    header('Pragma: ');
    header('Cache-Control: public, max-age=' . $lifetime);
    header('Accept-Ranges: none');
    header('Content-Type: text/css; charset=utf-8');
    if (!min_enable_zlib_compression()) {
        header('Content-Length: ' . filesize($path . $filename));
    }
    readfile($path . $filename);
    die;
}


/**
 * Adds any custom CSS to the CSS before it is cached.
 *
 * @param string $css The original CSS.
 * @param string $customcss The custom CSS to add.
 * @return string The CSS which now contains our custom CSS.
 */
function theme_enlight_set_customcss($css, $customcss) {

    $tag = '[[setting:customcss]]';
    $replacement = $customcss;
    if (is_null($replacement)) {
        $replacement = '';
    }
    $css = str_replace($tag, $replacement, $css);
    return $css;
}

/**
 * Returns an object containing HTML for the areas affected by settings.
 *
 * Do not add Clean specific logic in here, child themes should be able to
 * rely on that function just by declaring settings with similar names.
 *
 * @param renderer_base $output Pass in $OUTPUT.
 * @param moodle_page $page Pass in $PAGE.
 * @return stdClass An object with the following properties:
 *      - navbarclass A CSS class to use on the navbar. By default ''.
 *      - heading HTML to use for the heading. A logo if one is selected or the default heading.
 *      - footnote HTML to use as a footnote. By default ''.
 */
function theme_enlight_get_html_for_settings(renderer_base $output, moodle_page $page) {
    global $CFG;
    $return = new stdClass;

    $return->navbarclass = '';
    if (!empty($page->theme->settings->invert)) {
        $return->navbarclass .= ' navbar-inverse';
    }

    if (!empty($page->theme->settings->logo)) {
        $return->heading = html_writer::link($CFG->wwwroot, '', array('title' => get_string('home'), 'class' => 'logo'));
    } else {
        $return->heading = $output->page_heading();
    }

    $return->footnote = '';
    if (!empty($page->theme->settings->footnote)) {
        $return->footnote = '<div class="footnote text-center">'.format_text($page->theme->settings->footnote).'</div>';
    }

    return $return;
}


/**
 * Load the logo url.
 * @param string $type
 * @return string url
 */
function theme_enlight_get_logo_url($type='header') {
    global $OUTPUT;
    static $theme;
    if (empty($theme)) {
        $theme = theme_config::load('enlight');
    }
    if ($type == "header") {
         $logo = $theme->setting_file_url('logo', 'logo');
         $logo = empty($logo) ? '' : $logo;
    } else if ($type == "footer") {
        $logo = $theme->setting_file_url('footerlogo', 'footerlogo');
        $logo = empty($logo) ? '' : $logo;
    }
    return $logo;
}

/**
 * Renderer the slider images.
 * @param int $p
 * @param string $sliname
 * @return string image url
 */
function theme_enlight_render_slideimg($p, $sliname) {
    global $PAGE, $OUTPUT;
    $nos = theme_enlight_get_setting('numberofslides');
    if (theme_enlight_get_setting($sliname)) {
        $slideimage = $PAGE->theme->setting_file_url($sliname, $sliname);
        return $slideimage;
    }
    return "";
}

/**
 * Get the setting values.
 * @param string $setting
 * @param bool $format
 * @param bool $reset
 * @return string value
 */
function theme_enlight_get_setting($setting, $format = true, $reset = false) {
    global $CFG, $PAGE;
    require_once($CFG->dirroot . '/lib/weblib.php');
    static $theme;
    if ($reset) {
        $theme = $PAGE->theme;
        return '';
    }
    if (empty($theme)) {
        $theme = theme_config::load('enlight');
    }
    if (isset($theme->settings->$setting)) {
        if (empty($theme->settings->$setting)) {
            return false;
        } else if (!$format) {
            $return = $theme->settings->$setting;
        } else if ($format === 'format_text') {
            $return = format_text($theme->settings->$setting, FORMAT_PLAIN);
        } else if ($format === 'format_html') {
            $return = format_text($theme->settings->$setting, FORMAT_HTML, array('trusted' => true, 'noclean' => true));
        } else if ($format === 'file') {
            $return = $PAGE->theme->setting_file_url($setting, $setting);
        } else {
            $return = format_string($theme->settings->$setting);
        }
        return (isset($return)) ? theme_enlight_lang($return) : '';
    }
}

/**
 * Render the current theme url
 * @return string
 */
function theme_enlight_theme_url() {
    global $CFG, $PAGE;
    $themeurl = $CFG->wwwroot.'/theme/'. $PAGE->theme->name;
    return $themeurl;
}


/**
 * Display Footer Block Custom Links
 * @param string $menuname Footer block link name.
 * @return string The Footer links are return.
 */
function theme_enlight_generate_links($menuname = '') {
    global $CFG, $PAGE;
    $htmlstr = '';
    $menustr = theme_enlight_get_setting($menuname);
    $menusettings = explode("\n", $menustr);
    foreach ($menusettings as $menukey => $menuval) {
        $expset = explode("|", $menuval);
        if (!empty($expset) && isset($expset[0]) && isset($expset[1])) {
            list($ltxt, $lurl) = $expset;
            $ltxt = trim($ltxt);
            $ltxt = theme_enlight_lang($ltxt);
            $lurl = trim($lurl);
            if (empty($ltxt)) {
                continue;
            }
            if (empty($lurl)) {
                $lurl = 'javascript:void(0);';
            }
            $pos = strpos($lurl, 'http');
            if ($pos === false) {
                $lurl = new moodle_url($lurl);
            }
            $htmlstr .= html_writer::start_tag('li');
            $htmlstr .= html_writer::link($lurl, $ltxt);
            $htmlstr .= html_writer::end_tag('li') . "\n";
        }
    }
    return $htmlstr;
}

/**
 * Display Footer block Social Media links.
 *
 * @return string The Footer Social Media links are return.
 */
function theme_enlight_social_links() {
    global $CFG;
    $totalicons = 4;
    $htmlstr = '';
    for ($i = 1; $i <= 4; $i++) {
        $iconenable = theme_enlight_get_setting('siconenable'.$i);
        $icon = theme_enlight_get_setting('socialicon'.$i);
        $iconcolor = theme_enlight_get_setting('siconbgc'.$i);
        $iconurl = theme_enlight_get_setting('siconurl'.$i);
        $iconstr = '';
        if ($iconenable == "1") {
            if (!empty($icon)) {
                $iconstrclass = "media0".$i;
                $iconstr .= html_writer::start_tag('li', array('class' => $iconstrclass));
                $iclass = "fa fa-". $icon;
                $iconclass = html_writer::tag('i', '', array('class' => $iclass));
                $iconstr .= html_writer::link($iconurl, $iconclass);
                $iconstr .= html_writer::end_tag('li') . "\n";
                $htmlstr .= $iconstr;
            }
        }
    }
    return $htmlstr;
}

/**
 * Remove the html special tags from course content.
 * This function used in course home page.
 *
 * @param string $text
 * @return string
 */
function theme_enlight_strip_html_tags( $text ) {
    $text = preg_replace(
        array(
            // Remove invisible content.
            '@<head[^>]*?>.*?</head>@siu',
            '@<style[^>]*?>.*?</style>@siu',
            '@<script[^>]*?.*?</script>@siu',
            '@<object[^>]*?.*?</object>@siu',
            '@<embed[^>]*?.*?</embed>@siu',
            '@<applet[^>]*?.*?</applet>@siu',
            '@<noframes[^>]*?.*?</noframes>@siu',
            '@<noscript[^>]*?.*?</noscript>@siu',
            '@<noembed[^>]*?.*?</noembed>@siu',
            // Add line breaks before and after blocks.
            '@</?((address)|(blockquote)|(center)|(del))@iu',
            '@</?((div)|(h[1-9])|(ins)|(isindex)|(p)|(pre))@iu',
            '@</?((dir)|(dl)|(dt)|(dd)|(li)|(menu)|(ol)|(ul))@iu',
            '@</?((table)|(th)|(td)|(caption))@iu',
            '@</?((form)|(button)|(fieldset)|(legend)|(input))@iu',
            '@</?((label)|(select)|(optgroup)|(option)|(textarea))@iu',
            '@</?((frameset)|(frame)|(iframe))@iu',
        ),
        array(
            ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ',
            "\n\$0", "\n\$0", "\n\$0", "\n\$0", "\n\$0", "\n\$0",
            "\n\$0", "\n\$0",
        ),
        $text
    );
    return strip_tags( $text );
}

/**
 * Cut the Course content.
 *
 * @param string $str
 * @param int $n
 * @param string $endchar
 * @return string
 */
function theme_enlight_course_trim_char($str, $n = 500, $endchar = '&#8230;') {
    if (strlen($str) < $n) {
        return $str;
    }

    $str = preg_replace("/\s+/", ' ', str_replace(array("\r\n", "\r", "\n"), ' ', $str));
    if (strlen($str) <= $n) {
        return $str;
    }

    $out = "";
    $small = substr($str, 0, $n);
    $out = $small.$endchar;
    return $out;
}

/**
 * Get Category menu.
 * @return string
 */
function theme_enlight_category_menu() {
    global $CFG, $PAGE;
    $categoryid = optional_param('categoryid', null, PARAM_INT);
    $category = core_course_category::get($categoryid);
    $html = '';
    if ($category === null) {
        $selectedparents = array();
        $selectedcategory = null;
    } else {
        $selectedparents = $category->get_parents();
        $selectedparents[] = $category->id;
        $selectedcategory = $category->id;
    }

    $catatlevel = \core_course\management\helper::get_expanded_categories('');
    $catatlevel[] = array_shift($selectedparents);
    $catatlevel = array_unique($catatlevel);

    $listing = core_course_category::get(0)->get_children();
    $html .= html_writer::start_tag('ul', array('class' => "nav"));
    foreach ($listing as $listitem) {
        $subcategories = array();
        if (in_array($listitem->id, $catatlevel)) {
            $subcategories = $listitem->get_children();
        }
        $html .= theme_enlight_category_menu_item(
        $listitem,
        $subcategories,
        $listitem->get_children_count(),
        $selectedcategory,
        $selectedparents
        );
    }
    $html .= html_writer::end_tag('ul');
    return $html;
}

/**
 * Get category menu item.
 * @param object $category
 * @param array $subcategories
 * @param int $totalsubcategories
 * @param int|null $selectedcategory
 * @param array $selectedcategories
 * @return string html
 */
function theme_enlight_category_menu_item($category, array $subcategories, $totalsubcategories,
$selectedcategory = null, $selectedcategories = array()) {

    $viewcaturl = new moodle_url('/course/index.php', array('categoryid' => $category->id));
    $text = $category->get_formatted_name();
    $isexpandable = ($totalsubcategories > 0);
    $isexpanded = (!empty($subcategories));
    $activecategory = ($selectedcategory === $category->id);
    $dataexpanded = $isexpanded ? 1 : 0;

    if ($isexpanded) {
        $cls = $activecategory ? 'has-children expanded' : 'has-children';
    } else if ($isexpandable) {
        $cls = 'has-children';
    } else {
        $cls = $activecategory ? 'expanded' : '';
    }
    $html = html_writer::start_tag('li', array('class' => $cls, 'data-expanded' => $dataexpanded));
    $html .= html_writer::link($viewcaturl, $text);
    if (!empty($subcategories)) {
        $html .= html_writer::start_tag("ul", array("class" => "nav childnav"));
        $catatlevel = \core_course\management\helper::get_expanded_categories($category->path);
        $catatlevel[] = array_shift($selectedcategories);
        $catatlevel = array_unique($catatlevel);

        foreach ($subcategories as $listitem) {
            $childcategories = (in_array($listitem->id, $catatlevel)) ? $listitem->get_children() : array();
            $html .= theme_enlight_category_menu_item(
            $listitem,
            $childcategories,
            $listitem->get_children_count(),
            $selectedcategory,
            $selectedcategories
            );
        }

        $html .= html_writer::end_tag('ul');
    }
    $html .= html_writer::end_tag("ul");

    return $html;
}

/**
 * Get the language string
 * @param string $key
 * @return string
 */
function theme_enlight_lang($key='') {
    $pos = strpos($key, 'lang:');
    if ($pos !== false) {
        list($l, $k) = explode(":", $key);
        if (get_string_manager()->string_exists($k, 'theme_enlight')) {
            $v = get_string($k, 'theme_enlight');
            return $v;
        } else {
            return $key;
        }
    } else {
        return $key;
    }
}

/**
 * Check content length.
 * @param string $value
 * @param int $length
 * @return string content
 */
function check_length($value, $length) {

    if (strlen($value) <= $length) {
        return $value;
    } else {
        $content = substr($value, 0, $length) . '...';
        return $content;
    }
}

/**
 * Check combolist type.
 * @return bool
 */
function theme_enlight_combolist_type() {
    global $PAGE;
    $type = theme_enlight_get_setting('comboListboxType');
    if ($type == 1) {
        return true;
    } else {
        return false;
    }
}

/**
 * Get enlight footer adderss.
 * @param string $check
 * @return string adderss html
 */
function theme_enlight_footer_address($check = "") {
    global $PAGE;
    $value = '';
    $address = theme_enlight_get_setting('footaddress');
    $address = theme_enlight_lang($address);
    $email = theme_enlight_get_setting('footemailid');
    $email = theme_enlight_lang($email);
    $phone = theme_enlight_get_setting('footphoneno');
    $phone = theme_enlight_lang($phone);
    if (!empty($address) || !empty($email) || !empty($phone)) {
        $status = "true";
        $value = html_writer::start_tag('div', array('class' => 'footer-address-block'));

        if (!empty($address)) {
            $value .= html_writer::start_tag('div', array('class' => 'footer-address'));
            $value .= html_writer::tag('p', "".$address);
            $value .= html_writer::end_tag('div');
        }
        if (!empty($phone)) {
            $value .= html_writer::start_tag('div', array('class' => 'footer-phone'));
            $value .= html_writer::start_tag('p');
            $value .= get_string("phone", "theme_enlight");
            $value .= $phone;
            $value .= html_writer::end_tag('p');
            $value .= html_writer::end_tag('div');
        }
        if (!empty($email)) {
            $value .= html_writer::start_tag('div', array('class' => 'footer-email'));
            $value .= html_writer::start_tag('p');
            $value .= get_string('emailid', 'theme_enlight');
            $value .= html_writer::link("mailto:".$email, $email);
            $value .= html_writer::end_tag('p');
            $value .= html_writer::end_tag('div');
        }
        $value .= html_writer::end_tag('div');
    } else {
        $status = "false";
        $value = "";
    }
    if ($check == "true") {
        return $status;
    }
    return $value;
}

/**
 * Get theme loader
 * @return string content
 */
function get_theme_loader() {
    global $OUTPUT, $PAGE;
    $loaderstatus = theme_enlight_get_setting('preloader_status');
    if ($loaderstatus == '1') {
        $loadercolor = theme_enlight_get_setting('preloaderbg_color');
        $loadercolor = (isset($loadercolor) && !empty($loadercolor)) ? $loadercolor : "#353535";
        $loaderlogo = theme_enlight_get_logo_url();

        $loaderimg = $PAGE->theme->setting_file_url('preloader', 'preloader');
        $loaderimg = (!empty($loaderimg)) ? $loaderimg : '';
        $loader = html_writer::start_tag('div', array('class' => 'theme_loader',
            'id' => 'theme_loader', 'style' => 'background-color: '.$loadercolor.';'));

        $loader .= html_writer::empty_tag('img', array('src' => $loaderlogo, 'class' => '' ))."<br>";
        if (!empty($loader)) {
            $loader .= html_writer::empty_tag('img', array('src' => $loaderimg, 'class' => 'loader-img' ));
        }
        $loader .= html_writer::end_tag('div');
    } else {
        $loader = "";
    }

    return $loader;
}

/**
 * Get enlight header style.
 * @return array
 */
function theme_enlight_header_style() {
    global $CFG, $PAGE;

    $centersplit = false;
    $headerstyle = theme_enlight_get_setting('headerStyle');
    switch ($headerstyle) {
        case 1:
            $class = ' theme-colored-bg';
            break;
        case 3:
            $class = ' bottom-menu';
            break;
        case 4:
            $class = ' bottom-center-menu';
            break;
        case 5:
            $class = 'center-split';
            $centersplit = true;
            break;
        case 2:
        default:
            $class = ' white-bg';
            break;
    }
    $transparent = theme_enlight_get_setting('header_transparent');
    switch ($transparent) {
        case 1:
            $transparentclass = 'transparent';
            break;
        case 2:
            $transparentclass = 'semi-transparent';
            break;
        default:
            $transparentclass = '';
            break;
    }
    $topheader = theme_enlight_get_setting('topheader_style');
    switch ($topheader) {
        case 1:
            $topheaderclass = 'transparent';
            break;
        case 2:
            $topheaderclass = 'semi-transparent';
            break;
        default:
            $topheaderclass = '';
            break;
    }
    $headertransparent = theme_enlight_get_setting('header_transparent');
    $enableheader = theme_enlight_get_setting('enableheader');
    if (($topheader == 1 ) && ($headertransparent == 0) && ($enableheader == 1)) {
        $topheadertransparentclass = 'top-header-transparent';
    } else {
        $topheadertransparentclass = '';
    }
    if ($PAGE->pagelayout != 'frontpage') {
        $transparentclass = '';
        $topheaderclass = '';
        $topheadertransparentclass = '';
    }
    if ($topheader == 3) {
        $topheaderclass = 'top-white-bg';
    } else if ($topheader == 0) {
        $topheaderclass = "theme-top-header";
    }

    return [
        'headerstyle_class' => $class,
        'transparent_class' => $transparentclass,
        'centersplit' => $centersplit,
        'topheaderclass' => $topheaderclass,
        'topheadertransparentclass' => $topheadertransparentclass
    ];
}

/**
 * Get the enlight course states.
 * @param object $course
 * @return array states info.
 */
function enlight_get_course_stats($course) {

    global $CFG, $DB;
    require_once($CFG->libdir."/modinfolib.php");

    $stats = ['enrols', 'activities', 'resources'];
    $coursecontext = context_course::instance($course->id);
    $enrols = get_enrolled_users($coursecontext, 'theme/enlight:studentbase', 0, 'u.id',  null, 0, 0, true);
    $courselist = get_course($course->id);
    $mods = course_modinfo::get_array_of_activities($courselist);
    $meta = \core_course\local\factory\content_item_service_factory::get_content_item_service();

    $siteadmins = explode(',', $CFG->siteadmins);

    if (!empty($siteadmins) && isset($siteadmins[0])) {
        $adminuser = \core_user::get_user($siteadmins[0]);
        $contentitemservice = core_course\local\factory\content_item_service_factory::get_content_item_service();
        $metas = $contentitemservice->get_all_content_items($adminuser);
        $list = [];
        if (!empty($metas)) {
            foreach ($metas as $meta) {
                $list[$meta->name] = $meta;
            }
        }
        $resources = array();
        $activities = array();
        if (!empty($mods)) {
            foreach ($mods as $mod) {
                if ($DB->record_exists('course_modules', array('id' => $mod->cm, 'deletioninprogress' => 0))) {
                    $metamod = $list[$mod->mod];
                    if ($metamod->name == $mod->mod) {
                        if ($metamod->archetype == 1) {
                            $resources[] = $metamod->name;
                        } else if ($metamod->archetype == 0) {
                            $num = $metamod;
                            $activities[] = $metamod->name;
                        }
                    }
                }
            }
        }
        $stats['enrols'] = !empty($enrols) ? count($enrols) : '0';
        $stats['activities'] = count($activities);
        $stats['resources'] = count($resources);
    }
    return $stats;
}

/**
 * Fetch available login page slider images added on the theme settings.
 * @return array $slideimage List of images, filename and number.
 */
function theme_enlight_get_login_slideimages() {
    global $CFG;

    $slideimages = [];
    $fs = get_file_storage(); // Create file storage object.
    $context = context_system::instance();
    // Get list of stored images on the filearea loginbg.
    $files = $fs->get_area_files($context->id, 'theme_enlight', 'loginbg');
    if (!empty($files)) {
        $i = 0;
        foreach ($files as $key => $file) {

            if ($isimage = $file->is_valid_image()) { // Is valid Image.
                // Create the file url in moodle pluginfile format.
                $component = 'theme_enlight';
                $itemid = theme_get_revision();
                $image['image'] = moodle_url::make_file_url("$CFG->wwwroot/pluginfile.php", "/" . $file->get_contextid() . "/" .
                    $component . "/" . $file->get_filearea() . "/" . $itemid . $file->get_filepath() . $file->get_filename());
                $image['name'] = $file->get_filename();
                $image['target'] = $i; // Generate target number.
                $slideimages[] = $image;
                $i++;
            }
        }
    }
    return $slideimages;
}

/**
 * Get mobile config info.
 * @return string urls.
 */
function theme_enlight_mobile_config() {
    $url = [
        'android' => theme_enlight_get_setting('android_appurl'),
        'ios' => theme_enlight_get_setting('ios_appurl'),
    ];
    return $url;
}

/**
 * Fragement for block settings via ajax
 * @param array $args
 * @return string result
 */
function theme_enlight_output_fragment_load_block_settings($args) {
    global $CFG;
    if (is_siteadmin()) {
        $block = $args['block'];
        require_once($CFG->dirroot.'/lib/adminlib.php');
        $settings = new theme_boost_admin_settingspage_tabs('themesettingenlight', get_string('enlight_settings', 'theme_enlight'));
        $frontcustomiser = true;
        require_once($CFG->dirroot.'\theme\enlight\settings.php');
        if (isset(${$block})) {
            $blocksetting = new admin_settingpage('theme_enlight_general', get_string('themegeneralsettings', 'theme_enlight'));
            array_map(function($conf) use($blocksetting) {
                $blocksetting->add($conf);
            }, ${$block});
            $output = $blocksetting->output_html();
            $blockform = new theme_enlight\blockform(null, ['adminsettings' => $output, 'block' => $block]);
            return $blockform->render();
        } else {
            $result = ['error' => 'true', 'message' => 'Block settings not available.'];
            return json_encode($result);
        }
    }
}

/**
 * Fragment for set the block settings.
 * @param array $args
 * @return string
 */
function theme_enlight_output_fragment_apply_blocksettings($args) {

    if ($formdata = $args['formdata']) {
        $context = $args['context'];
        return theme_enlight\external::apply_blocksettings($context->id, $formdata);
    }
}

/**
 * Remove items from navigation
 *
 * @param flat_navigation $flatnav
 */
function theme_enlight_extend_flat_navigation(\flat_navigation $flatnav) {

    foreach ($flatnav as $item) {
        if (isset($item->parent->key) && $item->parent->key == 'mycourses' &&
            isset($item->type) && $item->type == \navigation_node::TYPE_COURSE) {
            $flatnav->remove($item->key, \navigation_node::TYPE_COURSE);
        }
        if (isset($item->parent->key) && $item->parent->key == 'mycourses' && $item->key == 'courseindexpage'
        && isset($item->type) && $item->type == \navigation_node::TYPE_CUSTOM) {
            $flatnav->remove($item->key, \navigation_node::TYPE_CUSTOM);
        }
        if ($item->key == 'sitesettings' && isset($item->type) &&
            $item->type == \navigation_node::TYPE_SITE_ADMIN) {
            $flatnav->remove($item->key, \navigation_node::TYPE_SITE_ADMIN);
        }
    }
}
/**
 * Get the dashboard reports content.
 * @return string content.
 */
function theme_enlight_dashboard_reports() {
    global $CFG;
    $content = '';
    if (array_key_exists('genesis', core_component::get_plugin_list('local'))) {
        require_once($CFG->dirroot.'/local/genesis/lib.php');
        $content = local_genesis_display_reports();
    }
    return $content;
}

/**
 * Get cost currency symbol.
 * @param string $code
 * @return string symbol.
 */
function theme_enlight_get_currency_symbol($code) {
    $codes = array(
        'AUD' => '&#36;',
        'BRL' => '&#82;&#36;',
        'CAD' => '&#36;',
        'CHF' => '&#67;&#72;&#70;',
        'CZK' => '&#75;&#269;',
        'DKK' => '&#107;&#114;',
        'EUR' => '&#8364;',
        'GBP' => '&#163;',
        'HKD' => '&#36;',
        'HUF' => '&#70;&#116;',
        'ILS' => '&#8362;',
        'JPY' => '&#165;',
        'MXN' => '&#36;',
        'MYR' => '&#82;&#77;',
        'NOK' => '&#107;&#114;',
        'NZD' => '&#36;',
        'PHP' => '&#8369;',
        'PLN' => '&#122;&#322;',
        'RUB' => '&#8381;',
        'SEK' => '&#107;&#114;',
        'SGD' => '&#36;',
        'THB' => '&#3647;',
        'TRY' => '',
        'TWD' => '&#78;&#84;&#36;',
        'USD' => '&#36;',
    );

    return $codes[$code];
}

/**
 * Get the footer gallery images.
 * @return array images.
 */
function theme_enlight_get_footer_gallery_images() {
    $gallery = [];
    $fs = get_file_storage();
    $files = $fs->get_area_files(\context_system::instance()->id, "theme_enlight", "galleryimg", false, 'filename', false);
    if (!empty($files)) {
        foreach ($files as $file) {
            if ($file) {
                if ($fs->file_exists($file->get_contextid(), $file->get_component(),
                    $file->get_filearea(), $file->get_itemid(), $file->get_filepath(), $file->get_filename())) {
                        $gallery[]['image'] = moodle_url::make_pluginfile_url($file->get_contextid(), $file->get_component(),
                        $file->get_filearea(), $file->get_itemid(), $file->get_filepath(),
                         $file->get_filename(), false)->out(false);
                }
            }
        }
    }
    return $gallery;
}

/**
 * Get user enroll course progress info.
 */
function theme_enlight_dashboard_course_progress() {
    global $USER;
    $courses = enrol_get_my_courses();
    $actioncourse = 0;
    $progresscourse = 0;
    $coursesprogress = 0;
    if (!empty($courses)) {
        foreach ($courses as $course) {
            $progress = \core_completion\progress::get_course_progress_percentage($course);
            if (is_numeric($progress)) {
                if ($progress) {
                    $progresscourse ++;
                }
                $actioncourse ++;
            }
            $coursesprogress += $progress;
        }
    }
    $res = 0;
    if ($coursesprogress && $actioncourse && $progresscourse) {
        $totprogress = $coursesprogress * ($progresscourse * 100);
        $res = (int) $totprogress / ($actioncourse * 100);
    }
    return ($res) ? round($res) : 0;
}

/**
 * Get the theme site pattern color from the settings.
 */
function theme_enlight_get_site_color() {
    $pattern = theme_enlight_get_setting('patternselect');
    switch ($pattern) {
        case 'default':
            $loaderbgcolor = "#3b82f6";
            break;
        case '1':
            $loaderbgcolor = "#7abb3b";
            break;
        case '2':
            $loaderbgcolor = "#8e558e";
            break;
        case '3':
            $loaderbgcolor = "#e14d43";
            break;
        case '4':
            $loaderbgcolor = "#523f6d";
            break;
        case '5':
            $loaderbgcolor = theme_enlight_get_setting('primarycolor');
            break;
        default:
            $loaderbgcolor = "#3b82f6";
            break;
    }
    return $loaderbgcolor;
}

/**
 * Get the Front page combo course catagories from the settings.
 *
 * @param string $args
 * @return string
 */
function theme_enlight_output_fragment_get_combocate_courses($args) {
    global $PAGE;
    $courserenderer = $PAGE->get_renderer('core', 'course');
    if ($args['categoryid']) {
        $category = core_course_category::get($args['categoryid']);
        return $courserenderer->display_combolist_courses($category->get_courses());
    } else {
        $courses = core_course_category::top()->get_courses(array('recursive' => true));
        return $courserenderer->display_combolist_courses($courses);
    }
}

/**
 * Get the Footer block social media icon background color from the settings.
 *
 * @param string $css
 * @param  theme_config $theme The theme config object.
 * @return string
 */
function theme_enlight_footer_soicalicon_bg($css, $theme) {
    $siconbgc1 = (isset($theme->settings->siconbgc1) &&
                ($theme->settings->siconbgc1 != '')) ? $theme->settings->siconbgc1 : '#47caf6';
    $siconbgc2 = (isset($theme->settings->siconbgc2) &&
                 ($theme->settings->siconbgc2 != '')) ? $theme->settings->siconbgc2 : '#e84c3d';
    $siconbgc3 = (isset($theme->settings->siconbgc3) &&
                ($theme->settings->siconbgc3 != '')) ? $theme->settings->siconbgc3 : '#cd2129';
    $siconbgc4 = (isset($theme->settings->siconbgc4) &&
                 ($theme->settings->siconbgc4 != '')) ? $theme->settings->siconbgc4 : '#3598dc';
    $css = str_replace('[[socialiconbg1]]', $siconbgc1, $css);
    $css = str_replace('[[socialiconbg2]]', $siconbgc2, $css);
    $css = str_replace('[[socialiconbg3]]', $siconbgc3, $css);
    $css = str_replace('[[socialiconbg4]]', $siconbgc4, $css);
    return $css;
}
