<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Define enlight settings.
 *
 * @package    theme_enlight
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die;

require_once($CFG->dirroot. '/course/lib.php');

require_once($CFG->dirroot. '/theme/enlight/settings/multi_autocomplete.php');

if ($ADMIN->fulltree || isset($frontcustomiser)) {

    global $CFG, $PAGE;

    $settings = new theme_boost_admin_settingspage_tabs('themesettingenlight', get_string('enlight_settings', 'theme_enlight'));

    $animations = array(
        "NONE" => get_string('none', 'theme_enlight'),
        "flash" => get_string('flash', 'theme_enlight'),
        "bounceIn" => get_string('bounceIn', 'theme_enlight'),
        "bounceInDown" => get_string('bounceInDown', 'theme_enlight'),
        "bounceInLeft" => get_string('bounceInLeft', 'theme_enlight'),
        "bounceInRight" => get_string('bounceInRight', 'theme_enlight'),
        "bounceInUp" => get_string('bounceInUp', 'theme_enlight'),
        "fadeIn" => get_string('fadeIn', 'theme_enlight'),
        "fadeInDown" => get_string('fadeInDown', 'theme_enlight'),
        "fadeInDownBig" => get_string('fadeInDownBig', 'theme_enlight'),
        "fadeInLeft" => get_string('fadeInLeft', 'theme_enlight'),
        "fadeInLeftBig" => get_string('fadeInLeftBig', 'theme_enlight'),
        "fadeInRight" => get_string('fadeInRight', 'theme_enlight'),
        "fadeInRightBig" => get_string('fadeInRightBig', 'theme_enlight'),
        "fadeInUp" => get_string('fadeInUp', 'theme_enlight'),
        "fadeInUpBig" => get_string('fadeInUpBig', 'theme_enlight'),
        "fadeOut" => get_string('fadeOut', 'theme_enlight'),
        "flip" => get_string('flip', 'theme_enlight'),
        "flipInX" => get_string('flipInX', 'theme_enlight'),
        "flipInY" => get_string('flipInY', 'theme_enlight'),
        "flipOutX" => get_string('flipOutX', 'theme_enlight'),
        "flipOutY" => get_string('flipOutY', 'theme_enlight'),
        "lightSpeedIn" => get_string('lightSpeedIn', 'theme_enlight'),
        "rotateIn" => get_string('rotateIn', 'theme_enlight'),
        "rotateInDownLeft" => get_string('rotateInDownLeft', 'theme_enlight'),
        "rotateInDownRight" => get_string('rotateInDownRight', 'theme_enlight'),
        "rotateInUpLeft" => get_string('rotateInUpLeft', 'theme_enlight'),
        "rotateInUpRight" => get_string('rotateInUpRight', 'theme_enlight'),
        "slideInUp" => get_string('slideInUp', 'theme_enlight'),
        "slideInDown" => get_string('slideInDown', 'theme_enlight'),
        "slideInLeft" => get_string('slideInLeft', 'theme_enlight'),
        "slideInRight" => get_string('slideInRight', 'theme_enlight'),
        "zoomIn" => get_string('zoom-In', 'theme_enlight'),
        "zoomInDown" => get_string('zoomInDown', 'theme_enlight'),
        "zoomInLeft" => get_string('zoomInLeft', 'theme_enlight'),
        "zoomInRight" => get_string('zoomInRight', 'theme_enlight'),
        "zoomInUp" => get_string('zoomInUp', 'theme_enlight'),
        "hinge" => get_string('hinge', 'theme_enlight'),
        "rollIn" => get_string('rollIn', 'theme_enlight'),
    );


    /* General Settings. */
    include(dirname(__FILE__) . '/settings/general.php' );

    /* Frontpage settings. */
    include(dirname(__FILE__) . '/settings/frontpage.php' );

    /* Slideshow Settings. */
    include(dirname(__FILE__) . '/settings/homepage_slider.php' );

    /* Site Features. */
    include(dirname(__FILE__) . '/settings/site_features.php' );

    /* Marketing spot Settings. */
    include(dirname(__FILE__) . '/settings/marketing_spot.php' );

    /* Category Image. */
    include(dirname(__FILE__) . '/settings/category_img.php' );

     /* Our Team. */
    include(dirname(__FILE__) . '/settings/our_team.php' );

    /* Testimonials Start. */
    include(dirname(__FILE__) . '/settings/testimonial.php' );

    /* Counter */
    include(dirname(__FILE__) . '/settings/counter.php' );

    /* Our Partners */
    include(dirname(__FILE__) . '/settings/our_partner.php' );

    /* Footer Settings start. */
    include(dirname(__FILE__) . '/settings/footer.php' );

    $PAGE->requires->js('/theme/enlight/javascript/themesettings.js');
}
