<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Counter settings.
 * @package   theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$temp = new admin_settingpage('theme_enlight_counter', get_string('countertabheading', 'theme_enlight'));

// Counter block heading.
$name = 'theme_enlight_countBlockheading';
$heading = get_string('countBlockSetting', 'theme_enlight');
$information = '';
$setting = new admin_setting_heading($name, $heading, $information);
$temp->add($setting);

// Counter block enable/disable.
$name = 'theme_enlight/counterBlock';
$title = get_string('counterblockstatus', 'theme_enlight');
$description = get_string('counterblockstatus_desc', 'theme_enlight');
$default = 1;
$setting = new admin_setting_configcheckbox($name, $title, $description, $default);
$temp->add($setting);

// CounterBlock title.
$name = 'theme_enlight/countBlockTitle';
$title = get_string('countBlockTitle', 'theme_enlight');
$description = get_string('countBlockTitle_desc', 'theme_enlight');
$default = 'lang:countBlockTitle_default';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// CounterBlock subtitle.
$name = 'theme_enlight/countBlockSubTitle';
$title = get_string('countBlockSubTitle', 'theme_enlight');
$description = get_string('countBlockSubTitle_desc', 'theme_enlight');
$default = 'lang:countersubtitle';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Counter block description.
$name = 'theme_enlight/countBlockDesc';
$title = get_string('countBlockDesc', 'theme_enlight');
$description = get_string('countBlockDesc_desc', 'theme_enlight');
$default = 'lang:countBlockDesc_default';
$setting = new admin_setting_configtextarea($name, $title, $description, $default);
$temp->add($setting);

// Counter block Backgrond image.
$name = 'theme_enlight/counterbg_type';
$title = get_string('counterbg_type', 'theme_enlight', 'this');
$description = get_string('counterbg_typedesc', 'theme_enlight', 'this');
$overlay = get_string('overlay', 'theme_enlight');
$imgcolor = get_string('imagecolor', 'theme_enlight');
$whitecolor = get_string('bgnone', 'theme_enlight');
$backimg = get_string('backimg', 'theme_enlight');
$default = 1;
$choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Counter block color picker.
$name = 'theme_enlight/counterblockcolor';
$title = get_string('counterblockcustomcolor', 'theme_enlight');
$description = get_string('counterblockcustomcolordesc', 'theme_enlight');
$default = '';
$setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Counter block color Opacity.
$name = 'theme_enlight/counteropacity';
$title = get_string('counterblockcustom_color_opacity', 'theme_enlight');
$description = get_string('counterblockcustom_color_opacitydesc', 'theme_enlight');
$opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
$setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

/* Counter block background setting */
$name = 'theme_enlight/counterbg';
$title = get_string('counterbg', 'theme_enlight', 'this');
$description = get_string('counterbg_desc', 'theme_enlight', 'this');
$setting = new admin_setting_configstoredfile($name, $title, $description, 'counterbg');
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Counter block animation.
$name = 'theme_enlight/countersanim';
$title = get_string('counteranim', 'theme_enlight');
$description = get_string('counteranimdesc', 'theme_enlight');
$default = 'fadeInUp';
$setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
$temp->add($setting);
$count = 4;

for ($i = 1; $i <= $count; $i++) {
    // Counter inner block heading.
    $name = 'theme_enlight_countBlock'.$i;
    $heading = get_string('countBlock', 'theme_enlight', array('num' => $i));
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Counter block value.
    $name = 'theme_enlight/countBlockValue'.$i;
    $title = get_string('countBlockValue', 'theme_enlight', array('num' => $i));
    $description = get_string('countBlockValue_desc', 'theme_enlight', array('num' => $i));
    $default = "50";
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Counter block Content.
    $name = 'theme_enlight/countBlockContent'.$i;
    $title = get_string('countBlockContent', 'theme_enlight', array('num' => $i));
    $description = get_string('countBlockContent_desc', 'theme_enlight', array('num' => $i));
    $default = get_string('contentname', 'theme_enlight', array('num' => $i));
    $setting = new admin_setting_confightmleditor($name, $title, $description, $default);
    $temp->add($setting);

    // Enable/disable option for counterbackimg.
    $name = 'theme_enlight/countblockimgstatus'. $i;
    $title = get_string('counterimgstatus', 'theme_enlight');
    $description = get_string('counterimgstatus_desc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Counter block icon.
    $name = 'theme_enlight/countblockimg'. $i;
    $title = get_string('counter_img', 'theme_enlight');
    $description = get_string('counterimg_desc', 'theme_enlight');
    $default = 'countblockimg'.$i;
    $setting = new admin_setting_configstoredfile($name, $title, $description, $default, 0,
        ['accepted_types' => ['.jpg', '.png']]);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);
}

$counters = (array) $temp->settings;
$settings->add($temp);
