<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Footer settings.
 * @package   theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$temp = new admin_settingpage('theme_enlight_footer', get_string('footerheading', 'theme_enlight'));
    $footerorderchocies = array(
        'none' => get_string("none", "theme_enlight"),
        'adderss' => get_string('adderssinfo', 'theme_enlight'),
        'quicklinks' => get_string('quicklinks', 'theme_enlight'),
        'information' => get_string('informationfor', 'theme_enlight'),
        'map' => get_string('map', 'theme_enlight'),
        'gallery' => get_string('gallery', "theme_enlight")
    );

    /* Footer Block */
    $name = 'theme_enlight_footerheading';
    $heading = get_string('footergeneral', 'theme_enlight');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Activate block.
    $name = 'theme_enlight/footerenable';
    $title = get_string('footerenable', 'theme_enlight');
    $description = get_string('footerenabledesc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Footer blocks Position order.
    $name = 'theme_enlight/footerb1_order';
    $title = get_string('footerordertitle', 'theme_enlight', '1');
    $description = get_string('footerorderdesc1', 'theme_enlight');
    $default = 'adderss';
    $setting = new admin_setting_configselect($name, $title, $description, $default, $footerorderchocies);
    $temp->add($setting);

    $name = 'theme_enlight/footerb2_order';
    $title = get_string('footerordertitle', 'theme_enlight', '2');
    $description = get_string('footerorderdesc2', 'theme_enlight');
    $default = 'quicklinks';
    $setting = new admin_setting_configselect($name, $title, $description, $default, $footerorderchocies);
    $temp->add($setting);

    $name = 'theme_enlight/footerb3_order';
    $title = get_string('footerordertitle', 'theme_enlight', '3');
    $description = get_string('footerorderdesc3', 'theme_enlight');
    $default = 'information';
    $setting = new admin_setting_configselect($name, $title, $description, $default, $footerorderchocies);
    $temp->add($setting);

    $name = 'theme_enlight/footerb4_order';
    $title = get_string('footerordertitle', 'theme_enlight', '4');
    $description = get_string('footerorderdesc4', 'theme_enlight');
    $default = 'map';
    $setting = new admin_setting_configselect($name, $title, $description, $default, $footerorderchocies);
    $temp->add($setting);

    // Footer Background type.
    $name = 'theme_enlight/footerbg_type';
    $title = get_string('footerbg_type', 'theme_enlight');
    $description = get_string('footerbg_type_desc', 'theme_enlight');
    $overlay = get_string('overlay', 'theme_enlight');
    $imgcolor = get_string('imagecolor', 'theme_enlight');
    $whitecolor = get_string('bgnone', 'theme_enlight');
    $backimg = get_string('backimg', 'theme_enlight');
    $default = 4;
    $choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Footer block color picker.
    $name = 'theme_enlight/footblockcolor';
    $title = get_string('footblockcustomcolor', 'theme_enlight');
    $description = get_string('footblockcustomcolordesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Footer block color Opacity.
    $name = 'theme_enlight/footerblockopacity';
    $title = get_string('footblockcustom_color_opacity', 'theme_enlight');
    $description = get_string('footblockcustom_color_opacitydesc', 'theme_enlight');
    $opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1));
    $setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Footer background images.
    $name = 'theme_enlight/footbgimg';
    $title = get_string('footbgimg', 'theme_enlight');
    $description = get_string('footbgimg_desc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'footbgimg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    /* Footer Block1 */
    $name = 'theme_enlight_footerblock1heading';
    $heading = get_string('adderssinfo', 'theme_enlight');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Footer heading.
    $name = 'theme_enlight/infoblocktitle';
    $title = get_string('infoblocktitle', 'theme_enlight');
    $description = get_string('infoblocktitledesc', 'theme_enlight');
    $default = 'lang:infoblockdefault';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Footer Logo file setting.
    $name = 'theme_enlight/footerlogo';
    $title = get_string('footerlogotitle', 'theme_enlight');
    $description = get_string('footerlogodesc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'footerlogo');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Footer Address.
    $name = 'theme_enlight/footaddress';
    $title = get_string('address', 'theme_enlight');
    $description = get_string('address_desc', 'theme_enlight');
    $default = get_string('defaultaddress', 'theme_enlight');
    $setting = new admin_setting_confightmleditor($name, $title, $description, $default);
    $temp->add($setting);

    // Footer Email Id.
    $name = 'theme_enlight/footemailid';
    $title = get_string('emailid', 'theme_enlight');
    $description = get_string('email_desc', 'theme_enlight');
    $default = get_string('defaultemailid', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Footer phone number.
    $name = 'theme_enlight/footphoneno';
    $title = get_string('phoneno', 'theme_enlight');
    $description = get_string('phonenodesc', 'theme_enlight');
    $default = get_string('defaultphoneno', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Activate social media icon 1.
    $name = 'theme_enlight/siconenable1';
    $title = get_string('siconenable1', 'theme_enlight');
    $description = get_string('siconenable1desc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Social media icon 1 - name.
    $name = 'theme_enlight/socialicon1';
    $title = get_string('socialicon1', 'theme_enlight');
    $description = get_string('socialicon1desc', 'theme_enlight');
    $default = get_string('socialicon1default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social media icon 1 - Background color.
    $name = 'theme_enlight/siconbgc1';
    $title = get_string('siconbgc1', 'theme_enlight');
    $description = get_string('siconbgc1desc', 'theme_enlight');
    $default = get_string('siconbgc1default', 'theme_enlight');
    $previewconfig = null;
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default, $previewconfig);
    $temp->add($setting);

    // Social Media Icon Url 1.
    $name = 'theme_enlight/siconurl1';
    $title = get_string('siconurl1', 'theme_enlight');
    $description = get_string('siconurl1desc', 'theme_enlight');
    $default = get_string('siconurl1default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Activate social media icon 2.
    $name = 'theme_enlight/siconenable2';
    $title = get_string('siconenable2', 'theme_enlight');
    $description = get_string('siconenable2desc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Social media icon 2 - name.
    $name = 'theme_enlight/socialicon2';
    $title = get_string('socialicon2', 'theme_enlight');
    $description = get_string('socialicon2desc', 'theme_enlight');
    $default = get_string('socialicon2default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social media icon 2 - Background color.
    $name = 'theme_enlight/siconbgc2';
    $title = get_string('siconbgc2', 'theme_enlight');
    $description = get_string('siconbgc2desc', 'theme_enlight');
    $default = get_string('siconbgc2default', 'theme_enlight');
    $previewconfig = null;
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default, $previewconfig);
    $temp->add($setting);

    // Social Media Icon Url 2.
    $name = 'theme_enlight/siconurl2';
    $title = get_string('siconurl2', 'theme_enlight');
    $description = get_string('siconurl2desc', 'theme_enlight');
    $default = get_string('siconurl2default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Activate social media icon 3.
    $name = 'theme_enlight/siconenable3';
    $title = get_string('siconenable3', 'theme_enlight');
    $description = get_string('siconenable3desc', 'theme_enlight');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Social media icon 3 - name.
    $name = 'theme_enlight/socialicon3';
    $title = get_string('socialicon3', 'theme_enlight');
    $description = get_string('socialicon3desc', 'theme_enlight');
    $default = get_string('socialicon3default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social media icon 3 - Background color.
    $name = 'theme_enlight/siconbgc3';
    $title = get_string('siconbgc3', 'theme_enlight');
    $description = get_string('siconbgc3desc', 'theme_enlight');
    $default = get_string('siconbgc3default', 'theme_enlight');
    $previewconfig = null;
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default, $previewconfig);
    $temp->add($setting);

    // Social Media Icon Url 3.
    $name = 'theme_enlight/siconurl3';
    $title = get_string('siconurl3', 'theme_enlight');
    $description = get_string('siconurl3desc', 'theme_enlight');
    $default = get_string('siconurl3default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Activate social media icon 4.
    $name = 'theme_enlight/siconenable4';
    $title = get_string('siconenable4', 'theme_enlight');
    $description = get_string('siconenable4desc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Social media icon 4 - name.
    $name = 'theme_enlight/socialicon4';
    $title = get_string('socialicon4', 'theme_enlight');
    $description = get_string('socialicon4desc', 'theme_enlight');
    $default = get_string('socialicon4default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social media icon 4 - Background color.
    $name = 'theme_enlight/siconbgc4';
    $title = get_string('siconbgc4', 'theme_enlight');
    $description = get_string('siconbgc4desc', 'theme_enlight');
    $default = get_string('siconbgc4default', 'theme_enlight');
    $previewconfig = null;
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default, $previewconfig);
    $temp->add($setting);

    // Social Media Icon Url 4.
    $name = 'theme_enlight/siconurl4';
    $title = get_string('siconurl4', 'theme_enlight');
    $description = get_string('siconurl4desc', 'theme_enlight');
    $default = get_string('siconurl4default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    /* Footer Block1 */

    /* Footer Block2*/
    $name = 'theme_enlight_footerblock2heading';
    $heading = get_string('quicklinks', 'theme_enlight');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    $name = 'theme_enlight/footerbtitle2';
    $title = get_string('footerbtitle2', 'theme_enlight');
    $description = get_string('footerbtitle2desc', 'theme_enlight');
    $default = 'lang:community';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    $name = 'theme_enlight/footerblink2';
    $title = get_string('footerblink2', 'theme_enlight');
    $description = get_string('footerblink2_desc', 'theme_enlight', array('blockno' => '2'));
    $default = get_string('footerblink2default', 'theme_enlight');
    $setting = new admin_setting_configtextarea($name, $title, $description, $default);
    $temp->add($setting);
    /* Footer Block2 */

    /* Footer Block3 */
    $name = 'theme_enlight_footerblock3heading';
    $heading = get_string('informationfor', 'theme_enlight');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Footer block title 3.
    $name = 'theme_enlight/footerbtitle3';
    $title = get_string('footerbtitle3', 'theme_enlight');
    $description = get_string('footerbtitle3desc', 'theme_enlight');
    $default = 'lang:ourorg';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Footer block 3 link.
    $name = 'theme_enlight/footerblink3';
    $title = get_string('footerblink3', 'theme_enlight');
    $description = get_string('footerblink3_desc', 'theme_enlight', array('blockno' => '3'));
    $default = get_string('footerblink3default', 'theme_enlight');
    $setting = new admin_setting_configtextarea($name, $title, $description, $default);
    $temp->add($setting);
    /* Footer Block3 */

    /* Footer Block4 */
    $name = 'theme_enlight_footerblock4heading';
    $heading = get_string('map', 'theme_enlight');
    $information = get_string('mapfooterdesc', 'theme_enlight');
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Footer block 4 Title.
    $name = 'theme_enlight/footerbtitle4';
    $title = get_string('footerbtitle4', 'theme_enlight');
    $description = get_string('footerbtitle4desc', 'theme_enlight');
    $default = 'lang:followuson';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    $name = 'theme_enlight/mapadderss';
    $title = get_string('location', 'theme_enlight');
    $description = get_string('locationdesc', 'theme_enlight');
    $default = 'lang:mapadderss';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);
    /* Footer Block4. */

    /* Footer Block5 */
    $name = 'theme_enlight_footerblock5heading';
    $heading = get_string('gallery', 'theme_enlight');
    $information = get_string('galleryfooterdesc', 'theme_enlight');
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Footer block 5 Title.
    $name = 'theme_enlight/footerbtitle5';
    $title = get_string('footerbtitle5', 'theme_enlight');
    $description = get_string('footerbtitle5desc', 'theme_enlight');
    $default = 'lang:footerbtitle5default';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Gallery images.
    $name = 'theme_enlight/galleryimg';
    $title = get_string('galleryimg', "theme_enlight");
    $description = get_string('galleryimgdesc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, "galleryimg", 0, ['maxfiles' => 9]);
    $temp->add($setting);

    // Copyright.
    $name = 'theme_enlight_copyrightheading';
    $heading = get_string('copyrightheading', 'theme_enlight');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Copyright setting.
    $name = 'theme_enlight/copyright';
    $title = get_string('copyright', 'theme_enlight');
    $description = get_string('copyrightdesc', 'theme_enlight');
    $default = 'lang:copyrightdefault';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    $footer = (array) $temp->settings;

    $settings->add($temp);
