<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Frontpage settings.
 * @package   theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();
    global $PAGE, $CFG;
    $temp = new admin_settingpage('theme_enlight_frontpage', get_string('themefrontpagesettings', 'theme_enlight'));

    // This is the descriptor for Slide One.
    $name = 'theme_enlight/theme_enlight_managefrontpage';
    $heading = get_string('managefrontpage_items', 'theme_enlight');
    $information = "";
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    $blocks = [];
    $name = 'theme_enlight/titleanimation';
    $title = get_string('titleanimation', 'theme_enlight');
    $description = get_string('titleanimationdesc', 'theme_enlight');
    $default = 'fadeInRight';
    $setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
    $temp->add($setting);


     // Non-loggedin version of the setting (that's what the parameter is for :) ).
    $temp->add(new admin_setting_frontpageblocks(false));
    $temp->add(new admin_setting_frontpageblocks(true)); // Loggedin version of the setting.

    // This is the descriptor for Popular course block One.
    $name = 'theme_enlight/theme_enlight_popularcourseblock';
    $heading = get_string('popularcourseblock', 'theme_enlight');
    $information = "";
    $popularcourses[] = new admin_setting_heading($name, $heading, $information);

    // Popular Course Display Title.
    $name = 'theme_enlight/popularcourses_title';
    $title = get_string('pcourse_title' , 'theme_enlight');
    $description = get_string('pcourse_titledesc', 'theme_enlight');
    $default = 'lang:popularcourses';
    $popularcourses[] = new admin_setting_configtext($name, $title, $description, $default);

    // Popular Course Display Sub title.
    $name = 'theme_enlight/popularcourses_subtitle';
    $title = get_string('pcourse_subtitle' , 'theme_enlight');
    $description = get_string('pcourse_subtitledesc', 'theme_enlight');
    $default = 'lang:pcourse_subtitledefault';
    $popularcourses[] = new admin_setting_configtext($name, $title, $description, $default);

    // Popular course description.
    $name = 'theme_enlight/popularcourses_desc';
    $title = get_string('pcourse_desc' , 'theme_enlight');
    $description = get_string('pcoursedesc_desc', 'theme_enlight');
    $default = "lang:description";
    $popularcourses[] = new admin_setting_configtext($name, $title, $description, $default);

    // Popular Course Display Status.
    $name = 'theme_enlight/popularCourse_type';
    $title = get_string('popularCourse_type', 'theme_enlight');
    $description = get_string('popularCourse_typedesc', 'theme_enlight');
    $enrolbase = get_string('no_enrol', 'theme_enlight');
    $idbase = get_string('id_base', 'theme_enlight');
    $default = 1;
    $choices = array(1 => $enrolbase , 2 => $idbase);
    $popularcourses[] = new admin_setting_configselect($name, $title, $description, $default, $choices);

    // Display Popular Courses by ID.
    $name = 'theme_enlight/popularCourse_id';
    $title = get_string('popularCourse_id', 'theme_enlight');
    $description = get_string('popularCourse_iddesc', 'theme_enlight');
    $default = "";
    $popularcourses[] = new admin_setting_configtext($name, $title, $description, $default);

    // Popular courses background type.
    $name = 'theme_enlight/popularcoursesbg_type';
    $title = get_string('popularcoursesbg_type', 'theme_enlight');
    $description = get_string('popularcoursesbg_typedesc', 'theme_enlight');
    $overlay = get_string('overlay', 'theme_enlight');
    $imgcolor = get_string('imagecolor', 'theme_enlight');
    $whitecolor = get_string('bgnone', 'theme_enlight');
    $backimg = get_string('backimg', 'theme_enlight');
    $default = 2;
    $choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $popularcourses[] = $setting;

    // Popular course block background color.
    $name = 'theme_enlight/popularcolor';
    $title = get_string('popularcustomcolor', 'theme_enlight');
    $description = get_string('popularcustomcolordesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $popularcourses[] = $setting;

    // Popular course block background color Opacity.
    $name = 'theme_enlight/popularcourseopacity';
    $title = get_string('popularcoursecustom_color_opacity', 'theme_enlight');
    $description = get_string('popularcoursecustom_color_opacitydesc', 'theme_enlight');
    $opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
    $setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $popularcourses[] = $setting;

    // Popular course block background image.
    $name = 'theme_enlight/popularcoursesbg';
    $title = get_string('popularcoursesbg', 'theme_enlight');
    $description = get_string('popularcoursesbg_desc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'popularcoursesbg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $popularcourses[] = $setting;

    // Popular course block animation effects.
    $name = 'theme_enlight/popularcoursesanim';
    $title = get_string('popularcoursesanim', 'theme_enlight');
    $description = get_string('popularcoursesanimdesc', 'theme_enlight');
    $default = 'fadeInUp';
    $popularcourses[] = new admin_setting_configselect($name, $title, $description, $default, $animations);

    array_map(function($conf) use($temp) {
        $temp->add($conf);
    }, $popularcourses);

    // This is the descriptor for Available course block One.
    $name = 'theme_enlight/theme_enlight_availablecourseblock';
    $heading = get_string('availablecourseblock', 'theme_enlight');
    $information = "";
    $availablecourses[] = new admin_setting_heading($name, $heading, $information);

    // Available course block title.
    $name = 'theme_enlight/availablecourse_title';
    $title = get_string('acourse_title' , 'theme_enlight');
    $description = get_string('acourse_titledesc', 'theme_enlight');
    $default = 'lang:availablecourses';
    $availablecourses[] = new admin_setting_configtext($name, $title, $description, $default);

    // Available course block subtitle.
    $name = 'theme_enlight/availablecourse_subtitle';
    $title = get_string('acourse_subtitle' , 'theme_enlight');
    $description = get_string('acourse_subtitledesc', 'theme_enlight');
    $default = 'lang:acourse_subtitledefault';
    $availablecourses[] = new admin_setting_configtext($name, $title, $description, $default);

    // Available course description.
    $name = 'theme_enlight/availablecourse_desc';
    $title = get_string('acourse_desc' , 'theme_enlight');
    $description = get_string('acoursedesc_desc', 'theme_enlight');
    $default = "lang:description";
    $availablecourses[] = new admin_setting_configtext($name, $title, $description, $default);

    // Available course display type.
    $name = 'theme_enlight/availablecourse_displaytype';
    $title = get_string('acourse_displaytype' , 'theme_enlight');
    $description = get_string('acourse_displaytypedesc', 'theme_enlight');
    $default = '1';
    $choices = array(
        '0' => get_string('default_type', 'theme_enlight'),
        '1' => get_string('slider_type', 'theme_enlight'),

    );
    $availablecourses[] = new admin_setting_configselect($name, $title, $description, $default, $choices);

    // Available course info display type.
    $name = 'theme_enlight/avilablecourseinfo_displaytype';
    $title = get_string('availablecourse_info', 'theme_enlight');
    $description = get_string('availablecourse_infodesc', 'theme_enlight');
    $default = 1;
    $availablecourses[] = new admin_setting_configcheckbox($name, $title, $description, $default);

    // Enable teacher.
    $name = 'theme_enlight/avilablecourse_teacherinfo';
    $title = get_string('showteacher_info', 'theme_enlight');
    $description = get_string('showteacherinfo_desc', 'theme_enlight');
    $default = 1;
    $availablecourses[] = new admin_setting_configcheckbox($name, $title, $description, $default);

    // Available course block Background type.
    $name = 'theme_enlight/availablecoursesbg_type';
    $title = get_string('availablecoursesbg_type', 'theme_enlight');
    $description = get_string('availablecoursesbg_typedesc', 'theme_enlight');
    $overlay = get_string('overlay', 'theme_enlight');
    $imgcolor = get_string('imagecolor', 'theme_enlight');
    $whitecolor = get_string('bgnone', 'theme_enlight');
    $backimg = get_string('backimg', 'theme_enlight');
    $default = 4;
    $choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $availablecourses[] = $setting;

    // Available course block colorpicker.
    $name = 'theme_enlight/availablecolor';
    $title = get_string('availablecustomcolor', 'theme_enlight');
    $description = get_string('availablecustomcolordesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $availablecourses[] = $setting;

    // Available course block color Opacity.
    $name = 'theme_enlight/availablecourseopacity';
    $title = get_string('availablecoursecustom_color_opacity', 'theme_enlight');
    $description = get_string('availablecoursecustom_color_opacitydesc', 'theme_enlight');
    $opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
    $setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $availablecourses[] = $setting;

    // Available courses block bgimages.
    $name = 'theme_enlight/availablecoursesbg';
    $title = get_string('availablecoursesbg', 'theme_enlight');
    $description = get_string('availablecoursesbg_desc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'availablecoursesbg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $availablecourses[] = $setting;

    // Available courses block animation.
    $name = 'theme_enlight/availablecoursesanim';
    $title = get_string('availablecoursesanim', 'theme_enlight');
    $description = get_string('availablecoursesanimdesc', 'theme_enlight');
    $default = 'fadeInUp';
    $availablecourses[] = new admin_setting_configselect($name, $title, $description, $default, $animations);

    array_map(function($conf) use($temp) {
        $temp->add($conf);
    }, $availablecourses);

    // This is the descriptor for Mycourse block One.
    $name = 'theme_enlight/theme_enlight_mycourseblock';
    $heading = get_string('mycourseblock', 'theme_enlight');
    $information = "";
    $enrolledcourses[] = new admin_setting_heading($name, $heading, $information);

    // My courses title.
    $name = 'theme_enlight/mycourse_title';
    $title = get_string('mycourse_title' , 'theme_enlight');
    $description = get_string('mycourse_titledesc', 'theme_enlight');
    $default = 'lang:enrolledcourses';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $enrolledcourses[] = $setting;

    // My Courses sub title.
    $name = 'theme_enlight/mycourse_subtitle';
    $title = get_string('mycourse_subtitle' , 'theme_enlight');
    $description = get_string('mycourse_subtitledesc', 'theme_enlight');
    $default = 'lang:mycourse_subtitledefault';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $enrolledcourses[] = $setting;

    // My course description.
    $name = 'theme_enlight/mycourse_desc';
    $title = get_string('mycourse_desc' , 'theme_enlight');
    $description = get_string('mycoursedesc_desc', 'theme_enlight');
    $default = "lang:description";
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $enrolledcourses[] = $setting;

    // Mycourse Course Display Type.
    $name = 'theme_enlight/mycourse_displaytype';
    $title = get_string('mycourse_displaytype' , 'theme_enlight');
    $description = get_string('mycourse_displaytypedesc', 'theme_enlight');
    $default = '1';
    $choices = array(
        '0' => get_string('default_type', 'theme_enlight'),
        '1' => get_string('slider_type', 'theme_enlight'),
    );

    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $enrolledcourses[] = $setting;

    // Enrolled(Mycourses) courses backgrond type.
    $name = 'theme_enlight/enrolledcoursesbg_type';
    $title = get_string('enrolledcoursesbg_type', 'theme_enlight');
    $description = get_string('enrolledcoursesbg_typedesc', 'theme_enlight');
    $overlay = get_string('overlay', 'theme_enlight');
    $imgcolor = get_string('imagecolor', 'theme_enlight');
    $whitecolor = get_string('bgnone', 'theme_enlight');
    $backimg = get_string('backimg', 'theme_enlight');
    $default = 4;
    $choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $enrolledcourses[] = $setting;

    // Enrolled Course Block color picker.
    $name = 'theme_enlight/enrolledcoursescolor';
    $title = get_string('enrolledcoursescustomcolor', 'theme_enlight');
    $description = get_string('enrolledcoursescustomcolordesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $enrolledcourses[] = $setting;

    // Enrolled course block color Opacity.
    $name = 'theme_enlight/enrolledcourseopacity';
    $title = get_string('enrolledcoursecustom_color_opacity', 'theme_enlight');
    $description = get_string('enrolledcoursecustom_color_opacitydesc', 'theme_enlight');
    $opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
    $setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $enrolledcourses[] = $setting;

    // Enrolled courses setting bgimages.
    $name = 'theme_enlight/enrolledcoursesbg';
    $title = get_string('enrolledcoursesbg', 'theme_enlight');
    $description = get_string('enrolledcoursesbg_desc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'enrolledcoursesbg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $enrolledcourses[] = $setting;

    // Enrolled courses block animation.
    $name = 'theme_enlight/enrolledcoursesanim';
    $title = get_string('enrolledcoursesanim', 'theme_enlight');
    $description = get_string('enrolledcoursesanimdesc', 'theme_enlight');
    $default = 'fadeInUp';
    $enrolledcourses[] = new admin_setting_configselect($name, $title, $description, $default, $animations);

    array_map(function($conf) use($temp) {
        $temp->add($conf);
    }, $enrolledcourses);

    // This is the descriptor for Course Categories block One.
    $name = 'theme_enlight/theme_enlight_coursecatblock';
    $heading = get_string('coursecatblock', 'theme_enlight');
    $information = "";
    $categorynews[] = new admin_setting_heading($name, $heading, $information);

    // Course category block title.
    $name = 'theme_enlight/coursecat_title';
    $title = get_string('coursecat_title' , 'theme_enlight');
    $description = get_string('coursecat_titledesc', 'theme_enlight');
    $default = 'lang:course_categories';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $categorynews[] = $setting;

    // Course category subtitle.
    $name = 'theme_enlight/coursecat_subtitle';
    $title = get_string('coursecat_subtitle' , 'theme_enlight');
    $description = get_string('coursecat_subtitledesc', 'theme_enlight');
    $default = 'lang:coursecat_subtitledefault';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $categorynews[] = $setting;

    // Course category description.
    $name = 'theme_enlight/coursecat_desc';
    $title = get_string('coursecat_desc' , 'theme_enlight');
    $description = get_string('coursecatdesc_desc', 'theme_enlight');
    $default = "lang:description";
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $categorynews[] = $setting;

    // Course category display type.
    $name = 'theme_enlight/categories_displaytype';
    $title = get_string('categories_displaytype' , 'theme_enlight');
    $description = get_string('categories_displaytypedesc', 'theme_enlight');
    $default = '1';
    $choices = array(
        '0' => get_string('default_type', 'theme_enlight'),
        '1' => get_string('slider_type', 'theme_enlight'),

    );
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $categorynews[] = $setting;

    // Course category display option.
    $name = 'theme_enlight/categories_displaytypeoption';
    $title = get_string('categories_displaytypeoption' , 'theme_enlight');
    $description = get_string('categories_displaytypeoptiondesc', 'theme_enlight');
    $default = 'random';
    $choices = array(
        'random' => get_string('random', 'theme_enlight'),
        'custom' => get_string('custom', 'theme_enlight'),

    );
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $categorynews[] = $setting;

    // Custom categories id.
    $name = 'theme_enlight/customcategories_ids';
    $title = get_string('customcategories_ids', 'theme_enlight');
    $description = get_string('customcategories_ids_desc', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, '');
    $categorynews[] = $setting;

    // Course Category block Background type.
    $name = 'theme_enlight/categoriesbg_type';
    $title = get_string('categoriesbg_type', 'theme_enlight');
    $description = get_string('categoriesbg_typedesc', 'theme_enlight');
    $overlay = get_string('overlay', 'theme_enlight');
    $imgcolor = get_string('imagecolor', 'theme_enlight');
    $whitecolor = get_string('bgnone', 'theme_enlight');
    $backimg = get_string('backimg', 'theme_enlight');
    $default = 3;
    $choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor,  4 => $backimg);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $categorynews[] = $setting;

    // Course Category block color picker.
    $name = 'theme_enlight/categoriescolor';
    $title = get_string('categoriescustomcolor', 'theme_enlight');
    $description = get_string('categoriescustomcolordesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $categorynews[] = $setting;

    // Course Category  block color Opacity.
    $name = 'theme_enlight/categoriesopacity';
    $title = get_string('categoriescustom_color_opacity', 'theme_enlight');
    $description = get_string('categoriescustom_color_opacitydesc', 'theme_enlight');
    $opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
    $setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $categorynews[] = $setting;

    // Course category block bgimages.
    $name = 'theme_enlight/categoriesbg';
    $title = get_string('categoriescoursesbg', 'theme_enlight');
    $description = get_string('categoriesbg_desc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'categoriesbg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $categorynews[] = $setting;

    // Course category block Animation.
    $name = 'theme_enlight/categorynewsanim';
    $title = get_string('categoryanim', 'theme_enlight');
    $description = get_string('categoryanimdesc', 'theme_enlight');
    $default = 'fadeInUp';
    $categorynews[] = new admin_setting_configselect($name, $title, $description, $default, $animations);

    array_map(function($conf) use($temp) {
        $temp->add($conf);
    }, $categorynews);


    // This is the descriptor for combo list block one.
    $name = 'theme_enlight/theme_enlight_combolistblock';
    $heading = get_string('combolistblock', 'theme_enlight');
    $information = "";
    $categorycombo[] = new admin_setting_heading($name, $heading, $information);

    // Combolist Title.
    $name = 'theme_enlight/combolist_title';
    $title = get_string('combolist_title' , 'theme_enlight');
    $description = get_string('combolist_titledesc', 'theme_enlight');
    $default = 'lang:combocourses';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $categorycombo[] = $setting;

    // Combolist SubTitle.
    $name = 'theme_enlight/combolist_subtitle';
    $title = get_string('combolist_subtitle' , 'theme_enlight');
    $description = get_string('combolist_subtitledesc', 'theme_enlight');
    $default = 'lang:listofcoursecate';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $categorycombo[] = $setting;

    // Combolist Description.
    $name = 'theme_enlight/combolist_desc';
    $title = get_string('combolist_desc' , 'theme_enlight');
    $description = get_string('combolistdesc_desc', 'theme_enlight');
    $default = "lang:description";
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $categorycombo[] = $setting;

    // Combo list box type.
    $name = 'theme_enlight/comboListboxType';
    $title = get_string('comboListboxType', 'theme_enlight');
    $description = get_string('comboListboxType_desc', 'theme_enlight');
    $expand = get_string('expand', 'theme_enlight');
    $collapse = get_string('collapse', 'theme_enlight');
    $default = 1;
    $choices = array(0 => $expand, 1 => $collapse);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $categorycombo[] = $setting;

    // Combolist block Backgrond type.
    $name = 'theme_enlight/combolistbg_type';
    $title = get_string('combolistbg_type', 'theme_enlight', 'combo list');
    $description = get_string('combolistbg_typedesc', 'theme_enlight', 'combo list');
    $overlay = get_string('overlay', 'theme_enlight');
    $imgcolor = get_string('imagecolor', 'theme_enlight');
    $whitecolor = get_string('bgnone', 'theme_enlight');
    $backimg = get_string('backimg', 'theme_enlight');
    $default = 3;
    $choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $categorycombo[] = $setting;

    // Combolist color picker.
    $name = 'theme_enlight/combolistcolor';
    $title = get_string('combolistcustomcolor', 'theme_enlight');
    $description = get_string('combolistcustomcolordesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $categorycombo[] = $setting;

    // Combolist block color Opacity.
    $name = 'theme_enlight/combolistopacity';
    $title = get_string('combolistcustom_color_opacity', 'theme_enlight');
    $description = get_string('combolistcustom_color_opacitydesc', 'theme_enlight');
    $opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
    $setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $categorycombo[] = $setting;

    // Combolist background setting.
    $name = 'theme_enlight/combolistbg';
    $title = get_string('combolistbackgroundbg', 'theme_enlight', 'combo list');
    $description = get_string('combolistbackgroundbg_desc', 'theme_enlight', 'combo list');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'combolistbg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $categorycombo[] = $setting;

    // Combo list block animation.
    $name = 'theme_enlight/categorycomboanim';
    $title = get_string('combolistanim', 'theme_enlight');
    $description = get_string('combolistanimdesc', 'theme_enlight');
    $default = 'fadeInUp';
    $categorycombo[] = new admin_setting_configselect($name, $title, $description, $default, $animations);

    array_map(function($conf) use($temp) {
        $temp->add($conf);
    }, $categorycombo);

    // This is the descriptor for site news block one.
    $name = 'theme_enlight/theme_enlight_sitenewsblock';
    $heading = get_string('sitenewsblock', 'theme_enlight');
    $information = "";
    $sitenews[] = new admin_setting_heading($name, $heading, $information);

    // Sitenews title.
    $name = 'theme_enlight/sitenews_title';
    $title = get_string('sitenews_title' , 'theme_enlight');
    $description = get_string('sitenews_titledesc', 'theme_enlight');
    $default = 'lang:sitenews';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $sitenews[] = $setting;

    // Sitenews subtitle.
    $name = 'theme_enlight/sitenews_subtitle';
    $title = get_string('sitenews_subtitle' , 'theme_enlight');
    $description = get_string('sitenews_subtitledesc', 'theme_enlight');
    $default = 'lang:sitenews_default';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $sitenews[] = $setting;

    // Sitenews Description.
    $name = 'theme_enlight/sitenews_desc';
    $title = get_string('sitenews_desc' , 'theme_enlight');
    $description = get_string('sitenewsdesc_desc', 'theme_enlight');
    $default = "lang:description";
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $sitenews[] = $setting;

     // Site news type.
    $name = 'theme_enlight/sitenewsType';
    $title = get_string('sitenewsType', 'theme_enlight');
    $description = get_string('sitenewsType_desc', 'theme_enlight');
    $yes = get_string('enlight_type', 'theme_enlight');
    $no = get_string('default_type', 'theme_enlight');
    $default = 1;
    $choices = array( 0 => $no , 1 => $yes );
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $sitenews[] = $setting;

    // Sitenews Backgrond image.
    $name = 'theme_enlight/sitenewsbg_type';
    $title = get_string('sitenewsbg_type', 'theme_enlight', 'sitenews');
    $description = get_string('sitenewsbg_typedesc', 'theme_enlight', 'sitenews');
    $overlay = get_string('overlay', 'theme_enlight');
    $imgcolor = get_string('imagecolor', 'theme_enlight');
    $whitecolor = get_string('bgnone', 'theme_enlight');
    $backimg = get_string('backimg', 'theme_enlight');
    $default = 2;
    $choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $sitenews[] = $setting;

    // Sitenews color picker.
    $name = 'theme_enlight/sitenewscolor';
    $title = get_string('sitenewscustomcolor', 'theme_enlight');
    $description = get_string('sitenewscustomcolordesc', 'theme_enlight');
    $default = '#000';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $sitenews[] = $setting;

    // Sitenews  block color Opacity.
    $name = 'theme_enlight/sitenewsopacity';
    $title = get_string('sitenewscustom_color_opacity', 'theme_enlight');
    $description = get_string('sitenewscustom_color_opacitydesc', 'theme_enlight');
    $opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
    $setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $sitenews[] = $setting;

    // Sitenews background setting.
    $name = 'theme_enlight/sitenewsbg';
    $title = get_string('sitenewsbg', 'theme_enlight', 'sitenews');
    $description = get_string('sitenewsbg_desc', 'theme_enlight', 'sitenews');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'sitenewsbg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $sitenews[] = $setting;

    // Sitenews block animation.
    $name = 'theme_enlight/sitenewsanim';
    $title = get_string('sitenewsanim', 'theme_enlight');
    $description = get_string('sitenewsanimdesc', 'theme_enlight');
    $default = 'fadeInUp';
    $sitenews[] = new admin_setting_configselect($name, $title, $description, $default, $animations);

    array_map(function($conf) use($temp) {
        $temp->add($conf);
    }, $sitenews);

    // This is the descriptor for Course search block one.
    $name = 'theme_enlight/theme_enlight_coursesearchblock';
    $heading = get_string('coursesearchblock', 'theme_enlight');
    $information = "";
    $search[] = new admin_setting_heading($name, $heading, $information);

     // Course search title.
     $name = 'theme_enlight/csearch_title';
     $title = get_string('csearch_title' , 'theme_enlight');
     $description = get_string('csearch_titledesc', 'theme_enlight');
     $default = 'lang:searchyourcourses';
     $search[] = new admin_setting_configtext($name, $title, $description, $default);

    // Course search subtitle.
    $name = 'theme_enlight/csearch_subtitle';
    $title = get_string('csearch_subtitle' , 'theme_enlight');
    $description = get_string('csearch_subtitledesc', 'theme_enlight');
    $default = 'lang:defaultsubtitle';
    $search[] = new admin_setting_configtext($name, $title, $description, $default);

    // Course search description.
    $name = 'theme_enlight/csearch_desc';
    $title = get_string('csearch_desc' , 'theme_enlight');
    $description = get_string('csearchdesc_desc', 'theme_enlight');
    $default = 'lang:description';
    $search[] = new admin_setting_configtext($name, $title, $description, $default);

    // Search courses backgrond type.
    $name = 'theme_enlight/searchcoursesbg_type';
    $title = get_string('searchcoursebg_type', 'theme_enlight');
    $description = get_string('searchcoursebg_typedesc', 'theme_enlight');
    $overlay = get_string('overlay', 'theme_enlight');
    $imgcolor = get_string('imagecolor', 'theme_enlight');
    $whitecolor = get_string('bgnone', 'theme_enlight');
    $backimg = get_string('backimg', 'theme_enlight');
    $default = 1;
    $choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $search[] = $setting;

    // Search course color picker.
    $name = 'theme_enlight/searchcoursecolor';
    $title = get_string('searchcoursecustomcolor', 'theme_enlight');
    $description = get_string('searchcoursecustomcolordesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $search[] = $setting;

    // Search course block color Opacity.
    $name = 'theme_enlight/searchcourseopacity';
    $title = get_string('searchcoursecustom_color_opacity', 'theme_enlight');
    $description = get_string('searchcoursecustom_color_opacitydesc', 'theme_enlight');
    $opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
    $setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $search[] = $setting;

    // Search courses background setting.
    $name = 'theme_enlight/searchcoursesbg';
    $title = get_string('searchcoursesbg', 'theme_enlight');
    $description = get_string('searchcoursesbg_desc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'searchcoursesbg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $search[] = $setting;

    // Search courses block animation.
    $name = 'theme_enlight/searchanim';
    $title = get_string('csearchanim', 'theme_enlight');
    $description = get_string('csearchanimdesc', 'theme_enlight');
    $default = 'fadeInUp';
    $setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
    $search[] = $setting;

    array_map(function($conf) use($temp) {
        $temp->add($conf);
    }, $search);

    $settings->add($temp);
