<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * General settings.
 * @package   theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();
    global $PAGE, $CFG;
    $temp = new admin_settingpage('theme_enlight_general', get_string('themegeneralsettings', 'theme_enlight'));

    // This is the descriptor for Slide One.
    $name = 'theme_enlight/theme_enlight_generalsub1';
    $heading = get_string('generallogo_menu', 'theme_enlight');
    $information = "";
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Logo file setting.
    $name = 'theme_enlight/logo';
    $title = get_string('logo', 'theme_enlight');
    $description = get_string('logodesc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'logo');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    $pimg = array();
    $cp = $CFG->wwwroot.'/theme/enlight/pix/color/';
    $pimg = array($cp.'default.jpg', $cp.'pattern-1.jpg', $cp.'pattern-2.jpg',
            $cp.'pattern-3.jpg', $cp.'pattern-4.jpg'
    );

    $themepattern = '<ul class="thumbnails theme-color-schemes">
        <li id="patterncolor-default" class="thumbnail">
        <div>
            <img src="'.$pimg[0].'" alt="default" width="50" height="50" />
        </div>
        </li>

        <li id="patterncolor-1" class="thumbnail" >
        <div>
            <img src="'.$pimg[1].'" alt="pattern1" width="50" height="50" />
        </div>
        </li>

        <li  id="patterncolor-2" class="thumbnail">
        <div>
            <img src="'.$pimg[2].'" alt="pattern2" width="50" height="50" />
        </div>
        </li>

        <li id="patterncolor-3" class="thumbnail">
        <div>
            <img src="'.$pimg[3].'" alt="pattern3" width="50" height="50" />
        </div>
        </li>

        <li id="patterncolor-4" class="thumbnail">
        <div>
            <img src="'.$pimg[4].'" alt="pattern4" width="50" height="50" />
        </div>
        </li>
    </ul>';

    $name = 'theme_enlight/patternselect';
    $title = get_string('patternselect' , 'theme_enlight');
    $description = $themepattern."".get_string('patternselectdesc', 'theme_enlight');
    $default = 'default';
    $choices = array(
        'default' => get_string("blue", "theme_enlight"),
        '1' => get_string("green", "theme_enlight"),
        '2' => get_string("lavender", "theme_enlight"),
        '3' => get_string("red", "theme_enlight"),
        '4' => get_string("purple", "theme_enlight"),
        '5' => get_string('customcolor', "theme_enlight"),
    );
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Primary color.
    $name = 'theme_enlight/primarycolor';
    $title = get_string('primarycolor', 'theme_enlight');
    $description = get_string('primarycolordesc', 'theme_enlight');
    $default = '#3b82f6';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Secondary color.
    $name = 'theme_enlight/secondarycolor';
    $title = get_string('secondarycolor', 'theme_enlight');
    $description = get_string('secondarycolordesc', 'theme_enlight');
    $default = '#3b82f6';
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Top header.

    // Top header height.
    $name = 'theme_enlight/topheader_height';
    $title = get_string('topheader_height', 'theme_enlight');
    $description = get_string('topheader_heightdesc', 'theme_enlight');
    $default = "55px";
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Top header style.
    $choices = [
      // 1. full transparent background header.
      1 => get_string('transparent', 'theme_enlight'),
      // 2. semi transparent background header.
      2 => get_string('semitransparent', 'theme_enlight'),

      3 => get_string('whitebackground', 'theme_enlight'),
      // NONE.
      0 => get_string('themecolored', 'theme_enlight'),
    ];
    $name = 'theme_enlight/topheader_style';
    $title = get_string('topheader_style', 'theme_enlight');
    $description = get_string('topheader_styledesc', 'theme_enlight');
    $default = 0;
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    // Enable header option.
    $name = 'theme_enlight/enableheader';
    $title = get_string('enableheader', 'theme_enlight');
    $description = get_string('enableheaderdesc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Header styles.
    $name = 'theme_enlight/headerStyle';
    $title = get_string('headerStyle', 'theme_enlight');
    $description = get_string('headerStyle_desc', 'theme_enlight');
    $choices = [
        // 1. theme-colored-bg
        1 => get_string('header', 'theme_enlight', array('no' => '1')),
        // 2. white-bg
        2 => get_string('header', 'theme_enlight', array('no' => '2')),
        // 3. bottom-menu
        3 => get_string('header', 'theme_enlight', array('no' => '3')),
        // 4. bottom-center-menu
        4 => get_string('header', 'theme_enlight', array('no' => '4')),
        // 5. center-split
        5 => get_string('header', 'theme_enlight', array('no' => '5')),
    ];

    $default = 2; // Style 2 is default.
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    $pstyle = array();
    $cp = $CFG->wwwroot.'/theme/enlight/pix/style/';
    $pstyle = array($cp.'header-style-1.png', $cp.'header-style-2.png', $cp.'header-style-3.png',
            $cp.'header-style-4.png', $cp.'header-style-5.png'
    );
    $stylepattern = '<div class="headerstyle-image">

     <div id="styletype-1" class= "colors">
       <div class="header-thumbnail">
      <img src="'.$pstyle[0].'" alt="default" width="" height="" /><br><br>
        <h6>'.get_string("style-1", "theme_enlight").'</h6><br>
        </div>
    </div>
     <div id="styletype-2" class = "colors">
       <div class="header-thumbnail">
      <img src="'.$pstyle[1].'" alt="pattern1" width="" height="" /><br><br>
       <h6>'.get_string("style-2", "theme_enlight").'</h6><br>
        </div>
     </div>
     <div id="styletype-3" class = "colors">
       <div class="header-thumbnail">
      <img src="'.$pstyle[2].'" alt="pattern2" width="" height="" /><br><br>
       <h6>'.get_string("style-3", "theme_enlight").'</h6><br>
        </div>
    </div>
      <div id="styletype-4" class = "colors">
       <div class="header-thumbnail">
      <img src="'.$pstyle[3].'" alt="pattern3" width="" height="" /><br><br>
      <h6>'.get_string("style-4", "theme_enlight").'</h6><br>
        </div>
    </div>

      <div id="styletype-5" class= "colors">
       <div class="header-thumbnail">
      <img src="'.$pstyle[4].'" alt="pattern4" width="" height=""/><br><br>
       <h6>'.get_string("style-5", "theme_enlight").'</h6><br>
        </div>
      </div>
    </div>';

    $temp->add(new admin_setting_heading('theme_enlight_headerstyleheading', '', $stylepattern));

    // Header styles.
    $name = 'theme_enlight/header_transparent';
    $title = get_string('header_transparent', 'theme_enlight');
    $description = get_string('header_transparentdesc', 'theme_enlight');
    $choices = [
        // 1. full transparent background header.
        1 => get_string('transparent', 'theme_enlight'),
        // 2. semi transparent background header.
        2 => get_string('semitransparent', 'theme_enlight'),
        // NONE.
        0 => get_string('none'),
    ];

    $default = 0; // Style 2 is default.
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    // Course menu.
    $name = 'theme_enlight/cmenushow';
    $title = get_string('cmenushow', 'theme_enlight');
    $description = get_string('cmenushowdesc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Display course menu.

    $name = "theme_enlight/cmenudisplay";
    $title = get_string('cmenudisplay', 'theme_enlight');
    $description = get_string('cmenudisplaydesc', 'theme_enlight');
    $default = 'header';
    $options = [
      'top' => get_string('topheader', 'theme_enlight'),
      'header' => get_string('strheader', 'theme_enlight'),
    ];
    $setting = new admin_setting_configselect($name, $title, $description, $default, $options);
    $temp->add($setting);


    // Course menu position.
    $name = 'theme_enlight/cmenuPosition';
    $title = get_string('cmenuPosition', 'theme_enlight');
    $description = get_string('cmenuPosition_desc', 'theme_enlight');
    $default = '2';
    $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
    $temp->add($setting);

    // Primary menu position.
    $name = 'theme_enlight/primarymenu';
    $title = get_string('primarymenu', 'theme_enlight');
    $description = get_string('primarymenudesc', 'theme_enlight');
    $default = get_string('primary_menu', 'theme_enlight');
    $setting = new admin_setting_configtextarea($name, $title, $description, $default);
    $temp->add($setting);

    /*********************************** End of titles *****************/
    // This is the descriptor for Slide One.
    $name = 'theme_enlight/theme_enlight_miscellaneous';
    $heading = get_string('miscellaneous', 'theme_enlight');
    $information = "";
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Setting: Favicon.
    $name = 'theme_enlight/favicon';
    $title = get_string('faviconsetting', 'theme_enlight', null, true);
    $description = get_string('faviconsetting_desc', 'theme_enlight', null, true);
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'favicon', 0);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Enable Dashboard reports.
    $name = 'theme_enlight/enabledashboardreports';
    $title = get_string('enabledashboardreports', 'theme_enlight');
    $description = '';
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    /* Course Layout */
    $name = 'theme_enlight/courselayout';
    $title = get_string('courselayout' , 'theme_enlight');
    $description = get_string('courselayoutdesc', 'theme_enlight');
    $default = 'layout1';
    $choices = array(
        'default' => get_string('default_layout', 'theme_enlight'),
        'layout1' => get_string('custom_layout', 'theme_enlight').'-1',
        'layout2' => get_string('custom_layout', 'theme_enlight').'-2'
    );
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);
    /* Course Layout */

    // Preloader Status.
    $name = 'theme_enlight/preloader_status';
    $title = get_string('preloader_status', 'theme_enlight');
    $description = get_string('preloader_statusdesc', 'theme_enlight');
    $yes = get_string('yes');
    $no = get_string('no');
    $default = 1;
    $choices = array( 1 => $yes, 0 => $no);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    // Preloader Color.
    $name = 'theme_enlight/preloaderbg_color';
    $title = get_string('preloaderbg_color', 'theme_enlight');
    $description = get_string('preloaderbg_colordesc', 'theme_enlight');
    $default = "#f4f4f4";
    $previewconfig = null;
    $setting = new admin_setting_configcolourpicker($name, $title, $description, $default, $previewconfig);
    $temp->add($setting);

    // Preloader Image.
    $name = 'theme_enlight/preloader';
    $title = get_string('preloader', 'theme_enlight');
    $description = get_string('preloader_desc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'preloader');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Loginpage Type.
    $name = 'theme_enlight/loginpageType';
    $title = get_string('loginpageType', 'theme_enlight');
    $description = get_string('loginpageType_desc', 'theme_enlight');
    $no = get_string('default_type', 'theme_enlight')." " .get_string('style', 'theme_enlight');
    $yes = get_string('logintheme', 'theme_enlight');
    $default = 1;
    $choices = array( 0 => $no , 1 => $yes );
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    // Login show as popup.
    $name = 'theme_enlight/loginshowpopup';
    $title = get_string('loginshowpopup', 'theme_enlight');
    $description = get_string('loginshowpopup_desc', 'theme_enlight');
    $setting = new admin_setting_configcheckbox($name, $title, $description, 0);
    $temp->add($setting);

    /* Login BG Image file setting */
    $name = 'theme_enlight/loginbg';
    $title = get_string('loginbg', 'theme_enlight');
    $description = get_string('loginbgdesc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'loginbg', 0, ['maxfiles' => 4]);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Back to top button.
    $name = 'theme_enlight/backToTop_status';
    $title = get_string('backToTop_status', 'theme_enlight');
    $description = get_string('backToTop_statusdesc', 'theme_enlight');
    $yes = get_string('yes');
    $no = get_string('no');
    $default = 1;
    $choices = array(1 => $yes , 0 => $no);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    // Custom CSS file.
    $name = 'theme_enlight/customcss';
    $title = get_string('customcss', 'theme_enlight');
    $description = get_string('customcssdesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configtextarea($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Import Demo Content.
    $name = 'theme_enlight/importDemo';
    $title = get_string('importDemo', 'theme_enlight');
    $description = get_string('importDemo_desc', 'theme_enlight');
    $default = 0;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);
    $settings->add($temp);
