<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Marketing spot settings.
 * @package   theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$temp = new admin_settingpage('theme_enlight_marketingspot', get_string('frontpageheading', 'theme_enlight'));

/* Marketing Spot 1*/
$name = 'theme_enlight_mspot1heading';
$heading = get_string('marketingspot', 'theme_enlight').' 1 ('.get_string('aboutustxt', 'theme_enlight').')';
$information = '';
$setting = new admin_setting_heading($name, $heading, $information);
$temp->add($setting);

// Marketing Spot 1 Title.

// Marketing Spot 1 Enable or disable.
$name = 'theme_enlight/marketingSpot1_status';
$title = get_string('marketingSpot1_status', 'theme_enlight');
$description = get_string('marketingSpot1_statusdesc', 'theme_enlight');

$default = 1;

$setting = new admin_setting_configcheckbox($name, $title, $description, $default);
$temp->add($setting);
// Marketing Spot 1 Enable or disable.

// Marketing Spot 1 Title.
$name = 'theme_enlight/mspot1title';
$title = get_string('mspot1title', 'theme_enlight');
$description = get_string('mspottitledesc', 'theme_enlight', array('msno' => '1'));
$default = 'lang:marketingabout';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Marketing Spot 1 subtitle.
$name = 'theme_enlight/mspot1subtitle';
$title = get_string('mspot1subtitle', 'theme_enlight');
$description = get_string('mspotsubtitledesc', 'theme_enlight');
$default = 'lang:mspotsubtitledefault';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Marketing Spot 1 Description.
$name = 'theme_enlight/mspot1desc';
$title = get_string('mspot1desc', 'theme_enlight');
$description = get_string('mspotdescdesc', 'theme_enlight', array('msno' => '1'));
$default = 'lang:aboutusdesc';
$setting = new admin_setting_confightmleditor($name, $title, $description, $default, PARAM_RAW);
$temp->add($setting);

// Marketing spot 1 Media content.
$name = 'theme_enlight/mspot1media';
$title = get_string('media', 'theme_enlight');
$description = get_string('mspotmediadesc', 'theme_enlight', array('msno' => '1'));
$setting = new admin_setting_configstoredfile($name, $title, $description, 'mspot1media');
$temp->add($setting);

// Mspot Backgrond image.
$name = 'theme_enlight/mspot1bg_type';
$title = get_string('mspot1bg_type', 'theme_enlight', 'this');
$description = get_string('mspot1bg_typedesc', 'theme_enlight', 'this');
$overlay = get_string('overlay', 'theme_enlight');
$imgcolor = get_string('imagecolor', 'theme_enlight');
$whitecolor = get_string('bgnone', 'theme_enlight');
$backimg = get_string('backimg', 'theme_enlight');
$default = 4;
$choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Marketing spot 1 color picker.
$name = 'theme_enlight/mspot1color';
$title = get_string('mspot1customcolor', 'theme_enlight');
$description = get_string('mspot1customcolordesc', 'theme_enlight');
$default = '';
$setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Marketing spot 1 color Opacity.
$name = 'theme_enlight/aboutusopacity';
$title = get_string('mspot1custom_color_opacity', 'theme_enlight');
$description = get_string('mspot1custom_color_opacitydesc', 'theme_enlight');
$opacity = array();
$opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
$setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

/* mspot background setting */
$name = 'theme_enlight/mspot1bg';
$title = get_string('mspot1bg', 'theme_enlight', 'this');
$description = get_string('mspot1bg_desc', 'theme_enlight', 'this');
$setting = new admin_setting_configstoredfile($name, $title, $description, 'mspot1bg');
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Marketing Spot 1 Animation.
$name = 'theme_enlight/mspot1descanim';
$title = get_string('mspot1descanim', 'theme_enlight');
$description = get_string('mspot1descanimdesc', 'theme_enlight');
$default = 'fadeInUp';
$setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
$temp->add($setting);


/* Marketing Spot 1*/

$marketingaboutus = (array) $temp->settings;
/* Marketing Spot 2*/
$name = 'theme_enlight_mspot2heading';
$heading = get_string('marketingspot', 'theme_enlight').' 2 ( '.get_string('learntitle', 'theme_enlight')." )";
$information = '';
$setting = new admin_setting_heading($name, $heading, $information);
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing Spot 2 status.
$name = 'theme_enlight/marketingSpot2_status';
$title = get_string('marketingSpot2_status', 'theme_enlight');
$description = get_string('marketingSpot2_statusdesc', 'theme_enlight');
$default = 1;
$setting = new admin_setting_configcheckbox($name, $title, $description, $default);
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing Spot 2 Title.
$name = 'theme_enlight/mspot2title';
$title = get_string('mspot2title', 'theme_enlight');
$description = get_string('mspot2titledesc', 'theme_enlight', array('msno' => '2'));
$default = 'lang:learnanytime';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing Spot 2 Description.
$name = 'theme_enlight/mspot2desc';
$title = get_string('mspot2desc', 'theme_enlight');
$description = get_string('mspot2descdesc', 'theme_enlight', array('msno' => '2'));
$default = 'lang:learnanytimedesc';
$setting = new admin_setting_configtextarea($name, $title, $description, $default, PARAM_TEXT);
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing spot 2 Backgrond image.
$name = 'theme_enlight/mspot2bg_type';
$title = get_string('mspot2bg_type', 'theme_enlight', 'this');
$description = get_string('mspot2bg_typedesc', 'theme_enlight', 'this');
$overlay = get_string('overlay', 'theme_enlight');
$imgcolor = get_string('imagecolor', 'theme_enlight');
$whitecolor = get_string('bgnone', 'theme_enlight');
$backimg = get_string('backimg', 'theme_enlight');
$default = 1;
$choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing spot 2 color picker.
$name = 'theme_enlight/mspot2color';
$title = get_string('mspot2customcolor', 'theme_enlight');
$description = get_string('mspot2customcolordesc', 'theme_enlight');
$default = '';
$setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing spot 2  color Opacity.
$name = 'theme_enlight/marketingsopacity';
$title = get_string('mspot2custom_color_opacity', 'theme_enlight');
$description = get_string('mspot2custom_color_opacitydesc', 'theme_enlight');
$opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
$setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);
$marketinglearn[] = $setting;

/* Sitenews background setting */
$name = 'theme_enlight/mspot2bg';
$title = get_string('mspot2bg', 'theme_enlight', 'this');
$description = get_string('mspot2bg_desc', 'theme_enlight', 'this');
$setting = new admin_setting_configstoredfile($name, $title, $description, 'mspot2bg');
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing Spot 2 Animation.
$name = 'theme_enlight/mspot2urlanim';
$title = get_string('mspot2urlanim', 'theme_enlight');
$description = get_string('mspot2urlanimdesc', 'theme_enlight');
$default = 'fadeInUp';
$setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing Spot 2 Link Text.
$name = 'theme_enlight/mspot2urltext';
$title = get_string('button', 'theme_enlight').' '.get_string('text', 'theme_enlight');
$description = get_string('mspot2urltxtdesc', 'theme_enlight', array('msno' => '2'));
$default = 'lang:viewallcourses';
$setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing Spot 2 Link.
$name = 'theme_enlight/mspot2url';
$title = get_string('button', 'theme_enlight').' '.get_string('link', 'theme_enlight');
$description = get_string('mspot2urldesc', 'theme_enlight');
$default = 'http://www.example.com/';
$setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_URL);
$temp->add($setting);
$marketinglearn[] = $setting;

// Marketing Spot 2 url target.
$name = 'theme_enlight/mspot2urltarget';
$title = get_string('button', 'theme_enlight').' '.get_string('target', 'theme_enlight');
$description = get_string('mspot2urltarget_desc', 'theme_enlight');
$same = get_string('sameWindow', 'theme_enlight');
$new = get_string('newWindow', 'theme_enlight');
$default = 1;
$choices = array(0 => $same , 1 => $new);
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$temp->add($setting);
$marketinglearn[] = $setting;

// Android app url setting.
$name = 'theme_enlight/android_appurl';
$title = get_string('android_app', 'theme_enlight');
$description = get_string('android_appdesc', 'theme_enlight');
$default = 'https://play.google.com/store/apps/details?id=com.moodle.moodlemobile';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);
$marketinglearn[] = $setting;

// Ios app url setting.
$name = 'theme_enlight/ios_appurl';
$title = get_string('ios_app', 'theme_enlight');
$description = get_string('ios_appdesc', 'theme_enlight');
$default = 'https://itunes.apple.com/app/moodle-mobile/id633359593?mt=8';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);
$marketinglearn[] = $setting;


/* Marketing Spot 2*/
$settings->add($temp);
