<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Ourpartnert settings.
 * @package   theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();


$temp = new admin_settingpage('theme_enlight_ourPartners', get_string('ourpartnerheading', 'theme_enlight'));

// Our partners heading.
$name = 'theme_enlight_ourPartners';
$heading = get_string('partnersGeneral', 'theme_enlight');
$information = '';
$setting = new admin_setting_heading($name, $heading, $information);
$temp->add($setting);

// Our partner status.
$name = "theme_enlight/ourPartner_status";
$title = get_string('ourPartner_status', 'theme_enlight');
$description = get_string('ourPartner_statusdesc', 'theme_enlight');
$default = 0;
$setting = new admin_setting_configcheckbox($name, $title, $description, $default);
$temp->add($setting);

// Show number of partner.
$name = "theme_enlight/ourPartner_number";
$title = get_string('ourPartnernum', 'theme_enlight');
$description = get_string('ourPartnernum_desc', 'theme_enlight');
$default = "0";
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Our partner autoplay.
$name = "theme_enlight/ourPartner_autoplay";
$title = get_string('autoplay', 'theme_enlight');
$description = get_string('ourPartnerAutoplay_desc', 'theme_enlight');
$choices = array(1 => $yes , 0 => $no);
$default = 1;
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$temp->add($setting);

// Our partner autotime.
$name = "theme_enlight/ourPartner_autotime";
$title = get_string('ourPartner_autoTime', 'theme_enlight');
$description = get_string('ourPartnerAutotime_desc', 'theme_enlight');
$default = 1400;
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Our partner title.
$name = "theme_enlight/ourPartner_title";
$title = get_string('ourPartner_title', 'theme_enlight');
$description = get_string('ourPartnertitle_desc', 'theme_enlight');
$default = 'lang:ourPartner_titledefault';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Our partner sub title.
$name = "theme_enlight/ourPartner_subtitle";
$title = get_string('ourPartner_subtitle', 'theme_enlight');
$description = get_string('ourPartner_subtitle_desc', 'theme_enlight');
$default = '';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Our partner description.
$name = "theme_enlight/ourPartner_desc";
$title = get_string('ourPartner_desc', 'theme_enlight');
$description = get_string('ourPartnerdesc_desc', 'theme_enlight');
$default = 'lang:description';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Our partner block Backgrond image.
$name = 'theme_enlight/ourpartnerbg_type';
$title = get_string('ourpartnerbg_type', 'theme_enlight', 'this');
$description = get_string('ourpartnerbg_typedesc', 'theme_enlight', 'this');
$overlay = get_string('overlay', 'theme_enlight');
$imgcolor = get_string('imagecolor', 'theme_enlight');
$whitecolor = get_string('bgnone', 'theme_enlight');
$backimg = get_string('backimg', 'theme_enlight');
$default = 1;
$choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Our partner block color picker.
$name = 'theme_enlight/ourpartnerblockcolor';
$title = get_string('ourpartnerblockcustomcolor', 'theme_enlight');
$description = get_string('ourpartnerblockcustomcolordesc', 'theme_enlight');
$default = '';
$setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Our partner block color Opacity.
$name = 'theme_enlight/ourpartneropacity';
$title = get_string('ourpartnerblockcustom_color_opacity', 'theme_enlight');
$description = get_string('ourpartnerblockcustom_color_opacitydesc', 'theme_enlight');
$opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
$setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

/* Our partner block background setting */
$name = 'theme_enlight/ourpartnerbg';
$title = get_string('ourpartnerbg', 'theme_enlight', 'this');
$description = get_string('ourpartnerbg_desc', 'theme_enlight', 'this');
$setting = new admin_setting_configstoredfile($name, $title, $description, 'ourpartnerbg');
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Our partner animation.
$name = 'theme_enlight/ourpartnersanim';
$title = get_string('ourPartneranim', 'theme_enlight');
$description = get_string('ourPartneranimdesc', 'theme_enlight');
$default = 'fadeInUp';
$setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
$temp->add($setting);

$numberofpartners = get_config('theme_enlight', 'ourPartner_number');
if (!empty($numberofpartners)) {
    $numpartners = intval($numberofpartners);
    for ($key = 1; $key <= $numpartners; $key++) {

        $name = 'theme_enlight/partner' . $key . 'info';
        $heading = get_string('partner', 'theme_enlight')." ".$key;
        $information = '';
        $setting = new admin_setting_heading($name, $heading, $information);
        $temp->add($setting);

        $name = "theme_enlight/partner".$key."title";
        $title = get_string('partnertitle', 'theme_enlight');
        $description = get_string('partnertitle_desc', 'theme_enlight');
        $default = get_string('partner', 'theme_enlight') . $key;
        $setting = new admin_setting_configtext($name, $title, $description, $default);

        $temp->add($setting);

        $name = 'theme_enlight/partner'. $key . 'img';
        $title = get_string('partnerimg', 'theme_enlight');
        $description = get_string('partnerimg_desc', 'theme_enlight');
        $default = 'partner'. $key . 'img';
        $setting = new admin_setting_configstoredfile($name , $title, $description, $default);
        $setting->set_updatedcallback('theme_reset_all_caches');
        $temp->add($setting);

        $name = 'theme_enlight/partner'. $key . 'link';
        $title = get_string('partnerlink', 'theme_enlight');
        $description = get_string('partnerlink_desc', 'theme_enlight');
        $default = 'http://www.example.com';
        $setting = new admin_setting_configtext($name , $title, $description, $default);
        $setting->set_updatedcallback('theme_reset_all_caches');
        $temp->add($setting);
    }
}

$ourpartners = (array) $temp->settings;
$settings->add($temp);
