<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Ourteam settings.
 * @package   theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();
$temp = new admin_settingpage('theme_enlight_ourTeam', get_string('ourTeam', 'theme_enlight'));
$temp->add(new admin_setting_heading('theme_enlight_ourTeam', get_string('ourTeamhead_sub', 'theme_enlight'),
format_text(get_string('ourTeamdesc', 'theme_enlight'), FORMAT_MARKDOWN)));

// Our team status.
$name = 'theme_enlight/ourteamStatus';
$title = get_string('ourteamStatus', 'theme_enlight');
$description = get_string('ourteamStatus_desc', 'theme_enlight');
$default = 0;
$setting = new admin_setting_configcheckbox($name, $title, $description, $default);
$temp->add($setting);

// Number of member.
$name = 'theme_enlight/numberofpersons';
$title = get_string('numberofpersons', 'theme_enlight');
$description = get_string('numberofpersons_desc', 'theme_enlight');
$default = 1;
$choices = array(
    1 => '1',
    2 => '2',
    3 => '3',
    4 => '4',
    5 => '5',
    6 => '6',
    7 => '7',
    8 => '8',
    9 => '9',
    10 => '10',
    11 => '11',
    12 => '12',
    13 => '13',
    14 => '14',
    15 => '15',
    16 => '16'
);
$temp->add(new admin_setting_configselect($name, $title, $description, $default, $choices));

// Auto Scroll.
$name = 'theme_enlight/ourteamAutoplay';
$title = get_string('ourteamAutoplay', 'theme_enlight');
$description = get_string('ourteamAutoplay_desc', 'theme_enlight');
$yes = get_string('yes');
$no = get_string('no');
$default = 0;
$choices = array(1 => $yes , 0 => $no);
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$temp->add($setting);

// Our team title.
$name = 'theme_enlight/ourteamTitle';
$title = get_string('ourteamTitle', 'theme_enlight');
$description = get_string('ourteamTitle_desc', 'theme_enlight');
$default = 'lang:ourTeam';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Ourteam subtitle.
$name = 'theme_enlight/ourteamSubTitle';
$title = get_string('ourteamSubTitle', 'theme_enlight');
$description = '';
$default = 'lang:ourteamsubtitledefault';
$setting = new admin_setting_configtext($name, $title, $description, $default);
$temp->add($setting);

// Our team description.
$name = "theme_enlight/ourteam_desc";
$title = get_string('ourteam_desc', 'theme_enlight');
$description = get_string('ourteam_desc_desc', 'theme_enlight');
$default = 'lang:description';
$setting = new admin_setting_configtextarea($name, $title, $description, $default);
$temp->add($setting);

// Feature block Backgrond image.
$name = 'theme_enlight/ourteambg_type';
$title = get_string('ourteambg_type', 'theme_enlight', 'this');
$description = get_string('ourteambg_typedesc', 'theme_enlight', 'this');
$overlay = get_string('overlay', 'theme_enlight');
$imgcolor = get_string('imagecolor', 'theme_enlight');
$whitecolor = get_string('bgnone', 'theme_enlight');
$backimg = get_string('backimg', 'theme_enlight');
$default = 2;
$choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Our team block color picker.
$name = 'theme_enlight/ourteamblockcolor';
$title = get_string('ourteamblockcustomcolor', 'theme_enlight');
$description = get_string('ourteamblockcustomcolordesc', 'theme_enlight');
$default = '';
$setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Our team block color Opacity.
$name = 'theme_enlight/ourteamopacity';
$title = get_string('ourteamblockcustom_color_opacity', 'theme_enlight');
$description = get_string('ourteamblockcustom_color_opacitydesc', 'theme_enlight');
$opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
$setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

/* Feature block background setting */
$name = 'theme_enlight/ourteambg';
$title = get_string('ourteambg', 'theme_enlight', 'this');
$description = get_string('ourteambg_desc', 'theme_enlight', 'this');
$setting = new admin_setting_configstoredfile($name, $title, $description, 'ourteambg');
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Our team Animation.
$name = 'theme_enlight/ourteamanim';
$title = get_string('ourteamanim', 'theme_enlight');
$description = get_string('ourteamanimdesc', 'theme_enlight');
$default = 'fadeInUp';
$setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
$temp->add($setting);

// No of testimonials.
$numberofpersons = get_config('theme_enlight', 'numberofpersons');
for ($i = 1; $i <= $numberofpersons; $i++) {

    $name = 'theme_enlight/team' . $i . 'info';
    $heading = get_string('team', 'theme_enlight', array('team' => $i));
    $information = get_string('teamdesc', 'theme_enlight', array('team' => $i));
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Name of the member.
    $name = 'theme_enlight/team' . $i . 'pname';
    $title = get_string('name', 'theme_enlight');
    $description = get_string('teamunamedesc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
    $temp->add($setting);

    // Team position.
    $name = 'theme_enlight/team' . $i . 'position';
    $title = get_string('teamposition', 'theme_enlight');
    $description = get_string('teamposition_desc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
    $temp->add($setting);

    // Description.
    $name = 'theme_enlight/team' . $i . 'description';
    $title = get_string('teamdesc', 'theme_enlight');
    $description = get_string('teamDesc_desc', 'theme_enlight');
    $default = '';
    $setting = new admin_setting_configtextarea($name, $title, $description, $default, PARAM_TEXT);
    $temp->add($setting);

    // Upload member image.
    $name = 'theme_enlight/team'.$i.'img';
    $title = get_string('teamImg', 'theme_enlight');
    $description = get_string('teamImg_desc', 'theme_enlight');
    $default = 'team'.$i.'img';
    $setting = new admin_setting_configstoredfile($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Social media icon 1.
    $name = 'theme_enlight/team'.$i.'socialIcon1';
    $title = get_string('teamSocialicon', 'theme_enlight').' 1 ';
    $description = get_string('teamSocialicon_desc', 'theme_enlight', array('icon' => 'facebook'));
    $default = get_string('team_socialicon1default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social Media Icon 1 Url.
    $name = 'theme_enlight/team'.$i.'sIconurl1';
    $title = get_string('teamSocialicon', 'theme_enlight').' 1 '.get_string('url', 'theme_enlight');
    $description = get_string('team_siconurl_desc', 'theme_enlight', array('icon' => 'facebook'));
    $default = get_string('siconurl4default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Scoial media icon 2.
    $name = 'theme_enlight/team'.$i.'socialIcon2';
    $title = get_string('teamSocialicon', 'theme_enlight').' 2 ';
    $description = get_string('teamSocialicon_desc', 'theme_enlight', array('icon' => 'twitter'));
    $default = get_string('team_socialicon2default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social Media Icon 2 Url.
    $name = 'theme_enlight/team'.$i.'sIconurl2';
    $title = get_string('teamSocialicon', 'theme_enlight').' 2 '.get_string('url', 'theme_enlight');
    $description = get_string('team_siconurl_desc', 'theme_enlight', array('icon' => 'twitter'));
    $default = get_string('siconurl1default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social Media Icon 3.
    $name = 'theme_enlight/team'.$i.'socialIcon3';
    $title = get_string('teamSocialicon', 'theme_enlight').' 3 ';
    $description = get_string('teamSocialicon_desc', 'theme_enlight', array('icon' => 'google-plus'));
    $default = get_string('team_socialicon3default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social Media Icon Url 3.
    $name = 'theme_enlight/team'.$i.'sIconurl3';
    $title = get_string('teamSocialicon', 'theme_enlight').' 3 '.get_string('url', 'theme_enlight');
    $description = get_string('team_siconurl_desc', 'theme_enlight', array('icon' => 'google'));
    $default = get_string('team_siconurl3default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social Media icon 4.
    $name = 'theme_enlight/team'.$i.'socialIcon4';
    $title = get_string('teamSocialicon', 'theme_enlight').' 4 ';
    $description = get_string('teamSocialicon_desc', 'theme_enlight', array('icon' => 'pinterest-p'));
    $default = get_string('team_socialicon4default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Social Media Icon Url 4.
    $name = 'theme_enlight/team'.$i.'sIconurl4';
    $title = get_string('teamSocialicon', 'theme_enlight').' 4 '.get_string('url', 'theme_enlight');
    $description = get_string('team_siconurl_desc', 'theme_enlight', array('icon' => 'pinterest'));
    $default = get_string('team_siconurl4default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);
}

$ourteam = (array) $temp->settings;
$settings->add($temp);
