<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Site features settings.
 * @package   theme_enlight
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();


$temp = new admin_settingpage('theme_enlight_sitefeatures', get_string('sitefeature_tabhead', 'theme_enlight'));
/*SITE FEATURE BLOCK*/
$name = 'theme_enlight_sitefeatureheading';
$heading = get_string('sitefeatureheading', 'theme_enlight');
$information = '';
$setting = new admin_setting_heading($name, $heading, $information);
$temp->add($setting);

// Feature block status.
$name = 'theme_enlight/togglesitefeatures';
$title = get_string('activateblock', 'theme_enlight');
$description = get_string('activateblock_desc', 'theme_enlight');
$default = 1;
$setting = new admin_setting_configcheckbox($name, $title, $description, $default);
$temp->add($setting);

// Number of slides.
$name = 'theme_enlight/numberofsitef';
$title = get_string('numberofsitef', 'theme_enlight');
$description = get_string('numberofsitef_desc', 'theme_enlight');
$default = 6;
$choices = array_combine( range(0, 9), range(0, 9) );
$temp->add(new admin_setting_configselect($name, $title, $description, $default, $choices));

// Featured course title.
$name = 'theme_enlight/sitefblocktitle';
$title = get_string('sitefblocktitle', 'theme_enlight');
$description = get_string('sitefblocktitledesc', 'theme_enlight');
$default = 'lang:sitefeature_tabhead';
$setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
$temp->add($setting);

// Featured course subtitle.
$name = 'theme_enlight/sitefblocksubtitle';
$title = get_string('sitefblocksubtitle', 'theme_enlight');
$description = get_string('sitefblocksubtitle_desc', 'theme_enlight');
$default = 'lang:sitefblockdesc_tabhead';
$setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
$temp->add($setting);

// Featured course desc.
$name = 'theme_enlight/sitefblockdesc';
$title = get_string('sitefblockdesc_title', 'theme_enlight');
$description = get_string('sitefblockdesc_desc', 'theme_enlight');
$default = 'lang:description';
$setting = new admin_setting_configtextarea($name, $title, $description, $default, PARAM_TEXT);
$temp->add($setting);

// Featured display style.
$name = 'theme_enlight/sitefblockstyle';
$title = get_string('sitefblockstyle', 'theme_enlight');
$description = get_string('sitefblockstyle_desc', 'theme_enlight');
$default = 'style2';
$blocks = [
    'style1' => get_string('strstyle', 'theme_enlight', 1),
    'style2' => get_string('strstyle', 'theme_enlight', 2)
];
$setting = new admin_setting_configselect($name, $title, $description, $default, $blocks);
$temp->add($setting);

// Feature block Backgrond image.
$name = 'theme_enlight/sitefeaturesbg_type';
$title = get_string('sitefeaturesbg_type', 'theme_enlight', 'feature');
$description = get_string('sitefeaturesbg_typedesc', 'theme_enlight', 'feature');
$overlay = get_string('overlay', 'theme_enlight');
$imgcolor = get_string('imagecolor', 'theme_enlight');
$whitecolor = get_string('bgnone', 'theme_enlight');
$backimg = get_string('backimg', 'theme_enlight');
$default = 4;
$choices = array( 1 => $overlay, 2 => $imgcolor, 3 => $whitecolor, 4 => $backimg);
$setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Feature block color picker.
$name = 'theme_enlight/featureblockcolor';
$title = get_string('featureblockcustomcolor', 'theme_enlight');
$description = get_string('featureblockcustomcolordesc', 'theme_enlight');
$default = '';
$setting = new admin_setting_configcolourpicker($name, $title, $description, $default);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Feature block color Opacity.
$name = 'theme_enlight/featureblockopacity';
$title = get_string('featureblockcustom_color_opacity', 'theme_enlight');
$description = get_string('featureblockcustom_color_opacitydesc', 'theme_enlight');
$opacity = array_combine(range(0.1, 1, 0.1 ), range(0.1, 1, 0.1 ));
$setting = new admin_setting_configselect($name, $title, $description, '0.7', $opacity);
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

/* Feature block background setting */
$name = 'theme_enlight/sitefeaturesbg';
$title = get_string('sitefeaturesbg', 'theme_enlight', 'feature');
$description = get_string('sitefeaturesbg_desc', 'theme_enlight', 'feature');
$setting = new admin_setting_configstoredfile($name, $title, $description, 'sitefeaturesbg');
$setting->set_updatedcallback('theme_reset_all_caches');
$temp->add($setting);

// Feature block animation.
$name = 'theme_enlight/sitefeaturesanim';
$title = get_string('sitefblockanim', 'theme_enlight');
$description = get_string('sitefblockanimdesc', 'theme_enlight');
$default = 'fadeInUp';
$setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
$temp->add($setting);

$sitefeatures = get_config('theme_enlight', 'numberofsitef');

for ($i = 1; $i <= $sitefeatures; $i++) {

    /* First Block */
    $name = 'theme_enlight_sitefblock'.$i.'heading';
    $heading = get_string('sitefblock', 'theme_enlight', array('block' => $i) );
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Sitefeatured block enable/disable.
    $name = 'theme_enlight/sitefblock'.$i.'status';
    $title = get_string('activateblock', 'theme_enlight');
    $description = get_string('activateblock_desc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    /* First Block Title */
    $name = 'theme_enlight/sitefblock'.$i.'title';
    $title = get_string('sitefblocktitle', 'theme_enlight');
    $description = get_string('sitefblocktitledesc', 'theme_enlight');
    $default = 'lang:sb'.$i.'_default_title';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    /* First Block Content */
    $name = 'theme_enlight/sitefblock'.$i.'content';
    $title = get_string('sitefblockcontent', 'theme_enlight');
    $description = get_string('sitefblockcontentdesc', 'theme_enlight');
    $default = 'lang:sb'.$i.'_default_cnt';
    $setting = new admin_setting_configtextarea($name, $title, $description, $default);
    $temp->add($setting);

    /* First Block Image */
    $name = 'theme_enlight/sitefblock'.$i.'image';
    $title = get_string('sitefblockimage', 'theme_enlight');
    $description = get_string('sitefblockimagedesc', 'theme_enlight');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'sitefblock'.$i.'image');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Site Featured Block 1 Link.
    $name = 'theme_enlight/sitefblock'.$i.'link';
    $title = get_string('sitefblocklink', 'theme_enlight', array('n' => $i));
    $description = get_string('sitefblocklinkdesc', 'theme_enlight', array('n' => $i) );
    $default = "http://www.example.com";
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

}

$sitefeatures = (array) $temp->settings;
$settings->add($temp);
