define(["jquery"], (function() {

    var scrolLeft = 0,
    scrolTop = 0;

    const panBtn = document.getElementsByClassName('level-pan-btn');

    const docElement = document.body.classList.contains('mapsize-fitwidth')
        ? document.documentElement : document.querySelector('#page-wrapper');

    const pageElement = document.querySelector('#page');

    let isDown = false;
    let startX, startY;
    let scrollLeft, scrollTop;
    let velX, velY;

    // Momentum.
    var momentumID;

    /**
     *  Initiate the Mouse click and drag.
     */
    const initDragMove = () => {
        docElement.addEventListener('mousemove', (e) => {
            if (!isDown) {
                return;
            }

            if (!clickedOnContent(e)) {
                return;
            }
            e.preventDefault();
            e.stopPropagation();
            var link = e.target.closest('a');
            if (link != undefined && !link.getAttribute('onclick')) {
                link.classList.add('pan-click-prevent');
                link.setAttribute('onclick', 'return false');
            }

            const x = e.clientX - docElement.offsetLeft;
            const walk = (x - startX);

            const y = e.clientY - docElement.offsetTop;
            const walkTop = (y - startY);

            var prevScrollLeft = docElement.scrollLeft;
            docElement.scrollLeft = scrollLeft - walk;

            var prevScrollTop = docElement.scrollTop;
            docElement.scrollTop = scrollTop - walkTop;

            // Compare change in position to work out drag speed.
            velX = docElement.scrollLeft - prevScrollLeft;
            velY = docElement.scrollTop - prevScrollTop;

        });

        docElement.addEventListener('mouseup', (e) => {
            isDown = false;
            if (!clickedOnContent(e)) {
                return;
            }

            docElement.classList.remove('active');
            beginMomentumTracking(); // Start a frame loop to continue drag momentum
            e.stopPropagation();
        });

        docElement.addEventListener('mousedown', (e) => {
            isDown = true;
            if (!clickedOnContent(e)) {
                return;
            }

            docElement.classList.add('active');
            startX = e.clientX - docElement.offsetLeft;
            scrollLeft = docElement.scrollLeft;

            startY = e.clientY - docElement.offsetTop;
            scrollTop = docElement.scrollTop;


            cancelMomentumTracking(); // Stop the drag momentum loop.
            var link = e.target.closest('a');
            if (link != undefined) {
                if (link.classList.contains('pan-click-prevent')) {
                    link.classList.remove('pan-click-prevent');
                    link.removeAttribute('onclick');
                }
            }
        });

        // Listen for mouse wheel events
        docElement.addEventListener('wheel', () => {
            cancelMomentumTracking(); // Stop the drag momentum loop
        });
    };

    const clickedOnContent = function(e) {
        if ((e.target.id == 'topofscroll' ||
            (!document.body.classList.contains('setup-module-position') && e.target.closest('#topofscroll') != undefined))
            && !e.target.closest('#panzoombtn')) {
            return true;
        }
        return false;
    };

    const beginMomentumTracking = () => {
        cancelMomentumTracking();
        momentumID = requestAnimationFrame(momentumLoop);
    };

    const cancelMomentumTracking = () => {
        cancelAnimationFrame(momentumID);
    };

    const momentumLoop = () => {
        if (!velX && !velY) {
            return;
        }

        docElement.scrollLeft += velX; // Apply the velocity to the scroll position
        docElement.scrollTop += velY; // Apply the velocity to the scroll position

        velX *= 0.90; // Slow the velocity slightly
        velY *= 0.90; // Slow the velocity slightly

        if (Math.abs(velX) > 0.15 || Math.abs(velY) > 0.15) { // Still moving?
            momentumID = requestAnimationFrame(momentumLoop); // Keep looping
        }
    };

    const initialPosition = function() {
        var xLeft = 0;
        var xRight = pageWidth();
        var xCenter = pageWidth() / 2;
        var yTop = 0;
        var yCenter = pageHeight() / 2;
        var yBottom = pageHeight();

        return {
            'lefttop': [xLeft, yTop],
            'leftcenter': [xLeft, yCenter],
            'leftbottom': [xLeft, yBottom],
            'righttop': [xRight, yTop],
            'rightbottom': [xRight, yBottom],
            'rightcenter': [xRight, yCenter],
            'centerbottom': [xCenter, yBottom],
            'centertop': [xCenter, yTop],
            'centercenter': [xCenter, yCenter],
        };
    };

    const limitHeight = () => Math.max(document.body.scrollHeight, document.body.offsetHeight,
        document.documentElement.clientHeight, document.documentElement.scrollHeight, document.documentElement.offsetHeight,
        pageElement !== null ? pageElement.scrollHeight : 0
    );

    const limitWidth = () => Math.max(document.body.scrollWidth, document.body.offsetWidth,
        document.documentElement.clientWidth, document.documentElement.scrollWidth, document.documentElement.offsetWidth,
        pageElement !== null ? pageElement.scrollWidth : 0
    );

    const pageHeight = () => limitHeight() - document.documentElement.clientHeight;

    const pageWidth = () => limitWidth() - document.documentElement.clientWidth;

    const currentTopPos = () => Math.abs(window.pageYOffset || document.documentElement.scrollTop
        || pageElement !== null ? pageElement.getBoundingClientRect().top : 0);

    const currentLeftPos = () => Math.abs(window.pageXOffset || document.documentElement.scrollLeft
        || pageElement !== null ? pageElement.getBoundingClientRect().left : 0);

    const yIncrease = () => document.querySelector('.pan-y-increase button');
    const yDecrease = () => document.querySelector('.pan-y-decrease button');
    const xIncrease = () => document.querySelector('.pan-x-increase button');
    const xDecrease = () => document.querySelector('.pan-x-decrease button');

    const disableButton = function(button) {
        button.disabled = true;
    };

    const enableButton = function(button) {
        button.disabled = false;
    };

    const delayedExec = function(after, fn) {
        var timer;
        return function() {
            var cleartime = timer && clearTimeout(timer);
            timer = setTimeout(fn, after);
            return cleartime;
        };
    };

    var buttonStateDetect = delayedExec(200, function() {
        disableButtons();
    });

    const disableButtons = () => {
        // Remove the height of header.
        if (pageHeight() == 0 || ((docElement.scrollHeight - docElement.clientHeight) == docElement.scrollTop)) {
            disableButton(yIncrease());
        } else {
            enableButton(yIncrease());
        }

        if (!docElement.scrollTop) {
            disableButton(yDecrease());
        } else {
            enableButton(yDecrease());
        }

        if (pageWidth() == 0 || ((docElement.scrollWidth - docElement.clientWidth) == docElement.scrollLeft)) {
            disableButton(xIncrease());
        } else {
            enableButton(xIncrease());
        }

        if (!docElement.scrollLeft) {
            disableButton(xDecrease());
        } else {
            enableButton(xDecrease());
        }
    };

    const levelLeft = (method) => {
        var steps = document.documentElement.clientWidth;
        var size;
        if (method > 0) {
            size = currentLeftPos() + steps;
            scrolLeft = (size < limitWidth()) ? size : pageWidth();
        } else {
            size = currentLeftPos() - steps;
            scrolLeft = (size >= 0) ? size : 0;
        }

        return scrolLeft;
    };

    const levelTop = (method) => {
        var size;
        var steps = document.documentElement.clientHeight;
        if (method > 0) {
            size = currentTopPos() + steps;
            scrolTop = (size < limitHeight()) ? size : pageHeight();
        } else {
            size = currentTopPos() - steps;
            scrolTop = (size >= 0) ? size : 0;
        }

        return scrolTop;
    };


    const panLevelMap = (direction, method) => {
        if (direction == 'vertical') {
            var top = levelTop(method);
            if (!(document.documentElement.scrollHeight - document.documentElement.clientHeight) && pageHeight() > 0) {
                document.querySelector('#page-wrapper').scroll({
                    top: top,
                    behavior: 'smooth'
                });
            } else {
                window.scroll({
                    top: top,
                    behavior: 'smooth'
                });
            }
        } else {
            var left = levelLeft(method);
            // Only for mobile view.
            if (!(document.documentElement.scrollWidth - document.documentElement.clientWidth) && pageWidth() > 0) {
                document.querySelector('#page-wrapper').scroll({
                    left: left,
                    behavior: 'smooth'
                });
            } else {
                window.scroll({
                    left: levelLeft(method),
                    behavior: 'smooth'
                });
            }

        }
    };

    return {

        init: function(position) {
            [...panBtn].forEach(element => {
                element.addEventListener('click', function(e) {
                    e.preventDefault();
                    var btn = e.target.closest('.level-pan-btn');
                    var direction = btn.dataset.direction;
                    var method = btn.dataset.method == 'increase' ? 1 : 0;
                    panLevelMap(direction, method);
                });
            });

            window.addEventListener("load", function() {
                setTimeout(function() {
                    var iniPos = initialPosition();
                    var pos = iniPos[position];

                    if (pos == undefined) {
                        return true;
                    }
                    window.scrollTo({
                        left: pos[0],
                        top: pos[1],
                        behavior: 'smooth'
                    });
                    return true;
                }, 100);
                // Disable the scrolling buttons.
                buttonStateDetect();
                window.addEventListener('scroll', buttonStateDetect);
                document.getElementById('page').addEventListener('scroll', buttonStateDetect);
                document.getElementById('page-wrapper').addEventListener('scroll', buttonStateDetect);
            });

            initDragMove();
        },
        delayedExec: delayedExec
    };

}));


// # sourceMappingURL=panning.min.js.map
