<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Event observer class definition.
 *
 * @package   local_reminder
 * @copyright 2021, bdecent gmbh bdecent.de
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace local_reminder;
use local_reminder\reminder_handler;

require_once($CFG->dirroot . "/local/reminder/lib.php");

/**
 * Observer class for the course enrollment created.
 */
class observer {

    /**
     * course enrollment created event observer.
     *
     * @param  stdclass $event
     * @return void
     */
    public static function created_user_enrolment($event) {
        global $DB;
        $eventdata = $event->get_data();
        if (get_config('local_reminder', 'statusnotifienrol')) {
            $course = $DB->get_record('course', array('id' => $event->courseid));
            $user =  $DB->get_record('user', array('id' => $event->relateduserid));
            reminder_handler::process_send_notification($user, 'notifienrol', $course);
        }
    }

    /**
     * user deleted event observer.
     *
     * @param  stdclass $event
     * @return void
     */
    public static function created_user_deleted($event) {
        global $DB;
        local_reminder_delete_event_times($event->relateduserid);
    }

    /**
     * user enrollment deleted event observer.
     *
     * @param  stdclass $event
     * @return void
     */
    public static function deleted_user_enrolment($event) {
        global $DB;
        local_reminder_delete_event_times($event->relateduserid, $event->courseid);
    }
}