
define(['jquery', 'core/templates', 'core/fragment', 'core/str', 'core/modal_factory', 'core/modal_events', 'core/toast', 'core/storagewrapper'],
	function($, Templates, Fragment, Str, Modal, ModalEvents, Toast, Storagewrapper) {


	const permissionID = '[data-event="enable-web-notification"]';

	var webPush;

	/**
	 * Verify the user current browser supports the service worker and push manager.
	 */
	const checkPushApi = () => {
		if (!('serviceWorker' in navigator)) {
			throw new Error('No Service Worker support!');
		}
		if (!('PushManager' in window)) {
			throw new Error('No Push API Support!');
		}
	};

	const isNotificationCancelled = () => {
		return sessionStorage.getItem('notificationcanceled');
	}

	/**
	 * Set the notification canceled flag in session to prevent call on each page loads.
	 */
	const setNotificationCancelled = () => {
		sessionStorage.setItem('notificationcanceled', true);
	}

	const isNotificationGranted = () => {
		return sessionStorage.getItem('notificationgranted');
	}

	/**
	 * Set the notification canceled flag in session to prevent call on each page loads.
	 */
	const setNotificationGranted = () => {
		sessionStorage.setItem('notificationgranted', true);
	}

	// Display the notification to allow the LMS to send push notifications.
	const display_information = () => {

		if (isNotificationCancelled()) {
			return;
		}

		Templates.render('message_webpush/enablenotification', {}).then(async (html, js) => {

			var xhtml = new DOMParser().parseFromString(html, 'text/xml');
			console.log(xhtml);

			await Toast.add(html, {
				type: 'info',
				autohide: false,
				closeButton: true
			});

			document.querySelector(permissionID).addEventListener('click', function(e) {
				e.preventDefault();
				requestNotificationPermission();
				document.querySelector('.toast-info.show [data-dismiss="toast"]').click();
			});

			document.querySelector('.toast-wrapper').addEventListener('hidden.bs.toast', function(e) {
				alert("toast-hide");
			})

			$('.toast-wrapper').on('hidden.bs.toast', function (e) {
				setNotificationCancelled();
			});

		});

		// TODO: Implement toast method.
		/* Modal.create({
            title: Str.get_string('enablenotification', 'message_webpush'),
            body: Templates.render('message_webpush/enablenotification', {}),
            large: true,
            draggable: true,
			type: Modal.types.SAVE_CANCEL
        }).done((modal) => {
			modal.setButtonText('save', Str.get_string('enable'));

            modal.getRoot().on(ModalEvents.save, function(e) {
                requestNotificationPermission();
				modal.hide();
            });

			modal.getRoot().on(ModalEvents.cancel, function(e) {
                // showAlternateMethod();
				sessionStorage.setItem('notificationcanceled', true);
            });

			modal.show();
        }); */
	};

	const urlB64ToUint8Array = strBase64 => {
		var strPadding = '='.repeat((4 - (strBase64.length % 4)) % 4);
		var strBase64 = (strBase64 + strPadding).replace(/\-/g, '+').replace(/_/g, '/');
		var rawData = atob(strBase64);
		var aOutput = new Uint8Array(rawData.length);
		for (var i = 0; i < rawData.length; ++i) {
			aOutput[i] = rawData.charCodeAt(i);
		}
		return aOutput;
	};

	const registerServiceWorker = async() => {
		const swRegistration = await navigator.serviceWorker.register(M.cfg.wwwroot + '/message/output/webpush/js/service.js')
		.then((registration) => {
			return registration;
		});
		return swRegistration;
	};

	/**
	 * Subscribe the user to receive the notifications.
	 *
	 * @returns
	 */
	const subscribeUserPush = async(restored=false) => {
		return registerServiceWorker().then(function(registration) {
			const subscribeOptions = {
				userVisibleOnly: true,
				applicationServerKey: urlB64ToUint8Array(
					webPush.publickey
				)
			};
			return registration.pushManager.subscribe(subscribeOptions);
		})
		.then(async(subscription) => {
			// Console.log('Received PushSubscription: ', JSON.stringify(pushSubscription));
			subscription = JSON.parse(JSON.stringify(subscription));
			subscription.userAgent = navigator.userAgent;

			var msg = Str.get_string('subscribedsuccess', 'message_webpush');
			var data = JSON.stringify(subscription);

			Fragment.loadFragment('message_webpush', 'store_subscription', webPush.context, {subscription: data}).then(function(response) {

				if (!restored) { // Show success message only for new subscriptions.

					Toast.add(msg, {
						type: 'info',
						closeButton: true
					});
				}

				return true;
			})
		});
	};

	/**
	 * REquest the notificationpermission to user.
	 */
	const requestNotificationPermission = async() => {
		const permission = await window.Notification.requestPermission();
		// Value of permission can be 'granted', 'default', 'denied'
		// granted: user has accepted the request
		// default: user has dismissed the notification permission popup by clicking on x
		// denied: user has denied the request.
		if (permission == 'granted') {
			try {
				// Subscribe the user to received the notifications.
				subscribeUserPush();
			} catch (err) {
				throw new Error('Permission not granted for Notification');
			}
		} else if (permission == 'denied') {
			// TODO: if needed send the error to LMS admin.
			console.log('Browser push notification denied by user');
		}
	};

	// Init the push notification
	// Check the push api is available
	// Check the notification permission is granted.
	const main = async(webpush) => {

		// Notification cancelled in this session, no need to go further.
		if (isNotificationCancelled() || isNotificationGranted()) {
			return;
		}

		checkPushApi();
		// Store global value.
		webPush = webpush
		const swRegistration = await registerServiceWorker();
		console.log(window.Notification.permission);
		// Display the notification enable message.
		if (window.Notification.permission != 'granted' && window.Notification.permission != 'denied') {
			// Show the enable notification toast before request the permission.
			// It prevents get prevent in notification api.
			display_information();
		} else if (window.Notification.permission == 'granted') {
			await subscribeUserPush(true);
			// Set the flag to stop the store the subscription again for this session.
			setNotificationGranted();
		}
	};

	return {
		init: (webpush) => {
			if (webpush.initservice) {
				main(webpush);

				window.Notification.onclick = (event) => {
					console.log(event);
				}
			}
		}
	};

});
