<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Message Webpush
 *
 * @package   message_webpush
 * @copyright 2023 lmsace.com <https://lmsace.com>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace message_webpush;

/**
 * Manage the logs of user subscription and reports.
 */
class logs {

    /**
     * Log class isntance.
     *
     * @var \message_webpush\logs
     */
    protected static $instance;

    /**
     * Notification send successfully.
     */
    public const USER_NOTIFIED = 'notification_sent';

    /**
     * User subscribed to receive notification.
     */
    public const USER_SUBSCRIBED = 'user_subscribed';

    /**
     * Removed the user subscription deleted.
     */
    public const USER_ENDPOINT_REMOVED = 'user_endpoint_removed';

    /**
     * Create the instance of the message webpush logs
     *
     * @return \message_webpush\logs
     */
    public static function get() {

        if (self::$instance == null) {
            self::$instance = new self();
        }

        return self::$instance;
    }


    public function add(int $userid, int $method, int $subscriptionid) {
        global $DB;

        $record = [
            'userid'      => $userid,
            'method'      => $method,
            'subscriptionid'    => $subscriptionid,
            'timecreated' => time()
        ];

        return $DB->insert_record('message_webpush_logs', $record);
    }


    public function delete_user_log(int $userid) {
        global $DB;

        $DB->delete_records('message_webpush_logs', ['userid' => $userid]);
    }



    public function add_notification_report($endpoint, $status) {
        global $DB;

        // End point.
        $like = $DB->sql_like('endpoint', ':endpoint');

        // Get the subscription for the endpoint.
        $sql = "SELECT * FROM {message_webpush_subs} WHERE {$like} ";
        if ($record = $DB->get_record_sql($sql, array('endpoint' => $endpoint))) {
            // Add the log of user notified.
            $this->add($record->userid, $status, $record->id);
        }
    }

    public function remove_subscription($subscription) {
        global $DB;

        if (empty($subscription)) {
            return;
        }

        $DB->delete_records('message_webpush_logs', ['id' => $subscription->id]);

        // Add the log of user notified.
        $this->add($subscription->userid, self::USER_ENDPOINT_REMOVED, $subscription->id);

    }
}
