<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Popup message processor
 *
 * @package   message_popup
 * @copyright 2008 Luis Rodrigues
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v2 or later
 */


/**
 * The popup message processor
 *
 * @package   message_popup
 * @copyright 2008 Luis Rodrigues and Martin Dougiamas
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
require_once($CFG->dirroot.'/message/output/lib.php');
require_once($CFG->dirroot.'/course/classes/list_element.php');

class message_output_webpush extends message_output {

    /**
     * Processes the message
     *
     * @param object $eventdata the event data submitted by the message sender plus $eventdata->savedmessageid
     */
   	function send_message($eventdata) {

        global $CFG;

        $notification = new stdClass();

        if (!empty($eventdata)) {

            // Course data.
            $course = get_course($eventdata->courseid);
            $course =  new core_course_list_element($course);
            $notification->courseid = $eventdata->courseid;
            $notification->coursename = $course->get_formatted_name();
            $notification->courseurl = new moodle_url('/course/view.php',['id' => $course->id]);

            // Mod name.
            $notification->mod = $eventdata->modulename;
            $notification->contexturl = $eventdata->contexturl;
            $notification->contexturlname = $eventdata->contexturlname;
            $notification->eventname = $eventdata->name;

            // Event user to receive notification.
            $userto = $eventdata->userto;
            $userto->url = new moodle_url('/user/profile.php', ['id' => $userto->id]);
            $notification->userto = $userto;

            // From user.
            $userfrom = $eventdata->userfrom;
            $userfrom->url = new moodle_url('/user/profile.php', ['id' => $userfrom->id]);
            $notification->userfrom = $userfrom;

            // Notification data.
            $notification->subject = $eventdata->subject;
            $notification->pushmessage = $eventdata->subject; // TODO: SET custom push message.
            $notification->fullmessage = $eventdata->fullmessage;
            $notification->fullmessagehtml = $eventdata->fullmessagehtml;
            $notification->fullmessage = $eventdata->fullmessage;
            $notification->smallmessage = $eventdata->smallmessage;
            $notification->timecreated = $eventdata->timecreated;

            // Setup the subject.
            // Notification message data.
            $messagemethod = get_config('message_webpush', 'message');
            if ($messagemethod == \message_webpush\webpushserver::MESSAGESMALL) {
                $notification->pushmessage = $eventdata->smallmessage;
            } else if ($messagemethod == \message_webpush\webpushserver::MESSAGEFULL) {
                $notification->pushmessage = $eventdata->fullmessage;
            } else {
                $notification->pushmessage = $eventdata->subject;
            }

            // Add notification actions.
            // if ()
        }

        if (!empty($notification) ) {

        /* file_put_contents($CFG->dirroot.'/message/output/webpush/data.txt', json_encode($notification) );

            $file = fopen($CFG->dirroot.'/message/output/webpush/data1.txt', 'w');
            fwrite($file, json_encode($notification));
            fclose($file);
        */
            // Web push server handler instance.
            $pushserver = new \message_webpush\webpushserver();
            // Generate and queue the notifications for user subscribed user browsers.
            $pushserver->create_user_notification($notification);
            $pushserver->send_notifications(); // Flush the queued notifications.
        }

        return true;
	}

    /**
     * Creates necessary fields in the messaging config form.
     * @param object $mform preferences form class
     */
    function config_form($preferences) {
        global $USER;
        $string = get_string('myfield','message_webpush').': <input size="30" name="webpush_myfield" value="'.$preferences->webpush_myfield.'" />';
        return $string;
    }

     /**
     * Parses the form submitted data and saves it into preferences array.
     *
     * @param object $mform preferences form class
     * @param array $preferences preferences array
     */
    function process_form($form, &$preferences) {
        if (isset($form->webpush_myfield)) {
            $preferences['message_processor_webpush_myfield'] = $form->webpush_myfield;
        }
    }

	/**
     * Loads the config data from database to put on the form (initial load)
     *
     * @param array $preferences preferences array
     * @param int $userid the user id
     */
    function load_data(&$preferences, $userid) {
        $preferences->webpush_myfield = get_user_preferences('message_processor_webpush_myfield', '', $userid);
    }

}
