<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * @package   message_webpush
 * @copyright @2024 LMSACE Dev Team <lmsace.com>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

use message_webpush\webpushserver;

defined('MOODLE_INTERNAL') || die();


if ($hassiteconfig) {

    global $CFG;

    // require_once($CFG->dirroot.'/local/webpush/lib.php');

    $settings = new theme_boost_admin_settingspage_tabs('message_webpush', get_string('pluginname', 'message_webpush'));


    if ($ADMIN->fulltree) {

        $settingspage = new admin_settingpage('managemessagewebpush', new lang_string('pluginname', 'message_webpush'));

        if (optional_param('genaratevapid', 0, PARAM_BOOL)) {
            $keys = webpushserver::generate_vapid_keys();
            $setting = new admin_setting_description("generatedkeys", "",
                get_string('keysgenerated', 'message_webpush', $keys));
            $settingspage->add($setting);
        }

        $name = 'message_webpush/mailto';
        $title = get_string('mailto', 'message_webpush');
        $description = get_string('mailto_description', 'message_webpush');
        $setting = new admin_setting_configtext($name, $title, $description, '', PARAM_RAW);
        $settingspage->add($setting);

        $name = 'message_webpush/publickey';
        $title = get_string('publickey', 'message_webpush');
        // Generate vapid key here.
        $url = $PAGE->url;
        $url->params(['genaratevapid' => true]);
        $description = get_string('publickey_description', 'message_webpush', ['url' => $url->out(false)]);
        $setting = new admin_setting_configtext($name, $title, $description, '', PARAM_RAW);
        $settingspage->add($setting);

        $name = 'message_webpush/privatekey';
        $title = get_string('privatekey', 'message_webpush');
        $description = get_string('privatekey_description', 'message_webpush');
        $setting = new admin_setting_configtext($name, $title, $description, '', PARAM_RAW);
        $settingspage->add($setting);

        /* $libraries = \message_webpush\webpushserver::verify_libraries();
        if ($libraries !== true) {
            $setting = new admin_setting_description("librarymissing", "", get_string('missinglibraries', 'message_webpush', implode(',', $libraries)) );
            $settingspage->add($setting);
        } */
        $settings->add($settingspage);

        $settingspage = new admin_settingpage('message_webpush_displayinfo', new lang_string('tabdisplayinfo', 'message_webpush'));

        $name = 'message_webpush/actions';
        $title = get_string('actionbuttons', 'message_webpush');
        $description = get_string('actionbuttons_description', 'message_webpush');

        $actions = [
            '1' => get_string('actiongoto', 'message_webpush'),
            '2' => get_string('actionopen', 'message_webpush'),
        ];
        $setting = new admin_setting_configmulticheckbox($name, $title, $description, '1, 2', $actions);
        $settingspage->add($setting);

        // Title.
        $name = 'message_webpush/title';
        $title = get_string('title', 'message_webpush');
        $description = get_string('title_description', 'message_webpush');

        $actions = [
            \message_webpush\webpushserver::TITLESUBJECT => get_string('usesubject', 'message_webpush'),
            \message_webpush\webpushserver::TITLECUSTOM => get_string('customtitle', 'message_webpush'),
        ];
        $setting = new admin_setting_configselect($name, $title, $description, '1', $actions);
        $settingspage->add($setting);

        // Custom Title.
        $name = 'message_webpush/customtitle';
        $title = get_string('customtitle', 'message_webpush');
        $description = get_string('customtitle_description', 'message_webpush');
        $setting = new admin_setting_configtext($name, $title, $description, '');
        $settingspage->add($setting);

        // Message.
        $name = 'message_webpush/message';
        $message = get_string('message', 'message_webpush');
        $description = get_string('message_description', 'message_webpush');

        $actions = [
            \message_webpush\webpushserver::MESSAGESUBJECT => get_string('msgusesubject', 'message_webpush'),
            \message_webpush\webpushserver::MESSAGESMALL => get_string('msgsmall', 'message_webpush'),
            \message_webpush\webpushserver::MESSAGEFULL => get_string('msgfull', 'message_webpush'),
        ];
        $setting = new admin_setting_configselect($name, $message, $description, '1', $actions);
        $settingspage->add($setting);


        $settings->add($settingspage);
    }


    // $ADMIN->add('localacetools', $settings);

  /*   $manageevents = new \moodle_url('/local/webpush/events.php');
    $ADMIN->add(
        'localacetools',
        new admin_externalpage('message_webpush_events', get_string('eventslist', 'message_webpush'), $manageevents)
    ); */
}
