// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Question element - Module to resize the question embeded frame.
 *
 * @module    element_question/question
 * @copyright  2024 bdecent gmbh <https://bdecent.de>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

import DynamicForm from 'core_form/dynamicform';
import ContentDesigner from 'mod_contentdesigner/elements';

/**
 * REsize the question element frame height.
 *
 * @param {HTMLElement} questionFrame
 */
const resizeQuestionFrame = (questionFrame) => {
    var height = questionFrame.contentWindow.document.documentElement.scrollHeight;
    height += 20;
    questionFrame.style.minHeight = height + 'px';
    console.log(height, 'height');

};

/**
 * Update the warning message and referesh the question frame content when the question is submitted.
 *
 * @param {Integer} instanceID
 * @returns
 */
export const questionSubmitted = (instanceID) => {

    var question = document.querySelector('.element-question .element-content[data-instanceid="' + instanceID + '"]');

    if (question === null) {
        return false;
    }

    const questionFrame = question.querySelector('iframe');

    questionFrame.onload = () => {
        var responseFrom = questionFrame.contentDocument.querySelector('form#responseform');
        resizeQuestionFrame(questionFrame);
        responseFrom.addEventListener('contentdesigner.questionformsubmitted', function (e) {
            ContentDesigner.removeWarning();
            ContentDesigner.refreshContent();
        });
    }

}
