define([], function () {

    const SELECTORS = {
        actionbutton: ".toc-action-block .cta-action-btn",
        tablecontent: ".element-tableofcontents",
        tocblock: ".toc-list-block",
        cdprogressbar: ".contentdesigner-progress",
        tocprogressbar: ".toc-progressbar",
        tocchaptertitle: ".toc-chapter-title",
        tocmodtitle: ".toc-mod-title-block",
        tocblockelem: ".toc-block",
        chaptertitlelist: '.element-tableofcontents .toc-chapter-block .toc-chapter-title',
        contentWrapper: '.contentdesigner-wrapper',
        generaloptions: '.topinstance .item-tableofcontents .general-options',
    };

    const tableofcontent = () => document.querySelector(SELECTORS.tocblock);
    const cdprogressbar = () => document.querySelector(SELECTORS.cdprogressbar);
    const tocprogressbar = () => document.querySelectorAll(SELECTORS.tocprogressbar);
    const tocblock = () => document.querySelector(SELECTORS.tocblockelem);
    const actionbutton = () => document.querySelector(SELECTORS.actionbutton);
    const contentWrapper = () => document.querySelector(SELECTORS.contentWrapper);
    const generaloptionwrapper = () => document.querySelector(SELECTORS.generaloptions);

    /**
     * Initialize the table of content element actions.
     */
    const inittableofcontents = () => {
        // Sticky scroll actions.
        var contentElem = document.querySelector(SELECTORS.tablecontent);

        // Add min height for the parent to avoid height adjustment during the sticky.
        if (tocblock() != null) {
            var height = tocblock().getBoundingClientRect().height;
            if (height) {
                tocblock().parentNode.style.minHeight = height + 'px';
            }
        }

        if (contentElem && contentElem.classList.contains('stickycontent')) {

            document.querySelector('#page').addEventListener('scroll', () => {
                stickycontents();
            });
            window.addEventListener('scroll', () => {
                stickycontents();
            });
            stickycontents();
        } else if (contentElem && contentElem.classList.contains('scrollup-stickycontent')) {
            scrollupstickycontents();
        }

        // Listen the event form the element update.
        contentWrapper().addEventListener('elementupdate', () => {
            ctaaction();
        });

        // CTA Actions.
        ctaaction();
    }

    const stickycontents = () => {

        const navbar = document.querySelector('nav.navbar.fixed-top');
        const navbarSize = navbar !== null ? navbar.clientHeight : 50;
        // const isHide = boundSize.top
        if (tocblock() != undefined && tocblock().parentNode.getBoundingClientRect().bottom < navbarSize) {
            displayelementsonsticky();
        } else {
            hideelementsonsticky();
        }
    }

    const scrollupstickycontents = () => {
        var oldScrollY = window.scrollY;
        window.onscroll = function (e) {
            if (oldScrollY > window.scrollY) {
                stickycontents();
            } else {
                hideelementsonsticky();
            }
            oldScrollY = window.scrollY;
        }
    }

    const hideelementsonsticky = () => {
        tocblock().classList.remove('fixed-top');
        tableofcontent().classList.remove('header-maxwidth');
        tocprogressbar().forEach((progressbar) => {
            progressbar.classList.add('d-none');
        })
        cdprogressbar().style.display = "block";
        hidechaptertitle(false);
        hidemodtitle(false);
        hideactionbutton(false);
        hidegeneralstyle(false);
    }

    const displayelementsonsticky = () => {
        tocblock().classList.add('fixed-top');
        tableofcontent().classList.add('header-maxwidth');
        tocprogressbar().forEach((progressbar) => {
            progressbar.classList.remove('d-none');
        })
        cdprogressbar().style.display = "none";
        hidechaptertitle(true);
        hidemodtitle(true);
        hideactionbutton(true);
        hidegeneralstyle(true);
    }

    const hidechaptertitle = (display) => {
        var chaptertitle = document.querySelectorAll(SELECTORS.tocchaptertitle);
        chaptertitle.forEach((title) => {
            if (display) {
                if (title.classList.contains('hideonsticky')) {
                    title.style.display = "none";
                }
            } else {
                if (title.classList.contains('hideonsticky')) {
                    title.style.display = "block";
                }
            }
        });
    }

    const hidemodtitle = (display) => {
        var modtitle = document.querySelectorAll(SELECTORS.tocmodtitle);
        modtitle.forEach((title) => {
            if (display) {
                if (title.classList.contains('hideonsticky')) {
                    title.style.display = "none";
                }
            } else {
                if (title.classList.contains('hideonsticky')) {
                    title.style.display = "block";
                }
            }
        });
    }

    const hideactionbutton = (status) => {
        var actionbutton = document.querySelector('.toc-action-block');
        if (actionbutton != undefined) {
            if (status) {
                actionbutton.style.display = "none";
            } else {
                actionbutton.style.display = "block";
            }
        }
    }

    const ctaaction = () => {
        // CTA actions.
        if (actionbutton() != undefined) {
            actionbutton().addEventListener('click', (e) => {
                var chapterid = e.target.dataset.actionid;
                viewtochapter(chapterid);
            });
        }

        // Chapter title linked.
        var chaptertitlelist = document.querySelectorAll(SELECTORS.chaptertitlelist);
        if (chaptertitlelist != undefined) {
            chaptertitlelist.forEach((title) => {
                title.addEventListener('click', (e) => {
                    var chapterid = e.target.dataset.chapter;
                    viewtochapter(chapterid);
                });
            });
        }
    }

    const viewtochapter = (chapterid) => {
        var chapterSelector = document.querySelector('li.chapters-list[data-id="' + chapterid + '"]');
        if (chapterSelector != undefined) {
            chapterSelector.scrollIntoView(true);
        }
    }

    const hidegeneralstyle = (status) => {
        if (generaloptionwrapper() !== undefined) {
            var margin = generaloptionwrapper().dataset.margin;
            var padding = generaloptionwrapper().dataset.padding;
            if (status) {
                generaloptionwrapper().style.margin = "0px";
                generaloptionwrapper().style.padding = "0px";
            } else {
                generaloptionwrapper().style.margin = margin;
                generaloptionwrapper().style.padding = padding;
            }
        }
    }

    return {
        init: function () {
            inittableofcontents();
        },
    };
});
