<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Test cases for contentdesigner external service methods.
 *
 * @package    mod_contentdesigner
 * @copyright  2022 bdecent gmbh <https://bdecent.de>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace mod_contentdesigner;

use externallib_advanced_testcase;
use mod_contentdesigner\external as mod_contentdesigner_external;

defined('MOODLE_INTERNAL') || die();

global $CFG;

require_once($CFG->dirroot . '/webservice/tests/helpers.php');

/**
 * External mod_contentdesigner functions unit tests
 * @runTestsInSeparateProcesses

 * @package    mod_contentdesigner
 * @copyright  2022 bdecent gmbh <https://bdecent.de>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
final class externallib_test extends externallib_advanced_testcase {

    /**
     * Test update completion.
     * @covers ::update_completion
     * @runInSeparateProcess
     */
    public function test_update_completion(): void {
        global $DB;

        $this->resetAfterTest(true);

        // Setup test data.
        $course = $this->getDataGenerator()->create_course();
        $user = $this->getDataGenerator()->create_user();
        $this->setUser($user);
        $contentdesigner1 = $this->getDataGenerator()->create_module('contentdesigner', ['course' => $course->id]);
        $contentdesigner2 = $this->getDataGenerator()->create_module('contentdesigner', ['course' => $course->id]);
        $this->assertTrue(mod_contentdesigner_external::update_completion($contentdesigner1->id, 'completionendreach'));
        $this->assertTrue($DB->record_exists('contentdesigner_completion', ['contentdesignerid' => $contentdesigner1->id,
            'userid' => $user->id]));
        $this->assertFalse($DB->record_exists('contentdesigner_completion', ['contentdesignerid' => $contentdesigner2->id,
            'userid' => $user->id]));
    }
}
