define(['jquery', 'core/ajax', 'core/loadingicon', 'core/chartjs'], function($, AJAX, LoadIcon){

  var filter = null;
  var visitchart = null;
  var loadiconElement = $(".site-visits-block .loadiconElement");

  function init() {

      if (typeof sitevisits === 'undefined') {
          return null;
      }

      var label = sitevisits.label;
      var datavalue = sitevisits.value;
      show_visit_chart(label, datavalue);

      $(".site-visits-block .dropdown-menu a").click(function() {
        var selText = $(this).text();
        var filter = $(this).attr("value");
        $(this).parents('.dropdown').find('#dropdownMenuLink').html(selText+' <span class="caret"></span>');
        $(this).parents('.dropdown').find('#dropdownMenuLink').attr("data-filter", filter);
        get_visits_records(filter);
      });
  }

  /**
   * show chart
   * @param array label
   * @param array value
   *
   */
  var show_visit_chart = function(label, datavalue) {
    let ctx =  document.getElementById('site-visits-chart');
    if (ctx) {
      let config = {
        type: 'line',
        data: {
          labels: label,
          datasets: [
            {
              label: ctx.dataset.sitevisits,
              data: datavalue.sitevisits,
              backgroundColor : ['rgba(153, 102, 255, 1)'],
              showTooltips : false,
              tension: 1
            },
            {
              label: ctx.dataset.coursevisits,
              data: datavalue.coursevisits,
              backgroundColor : ['rgba(15, 242, 25, 1)'],
              showTooltips : false,
              tension: 1
            },
            {
              label: ctx.dataset.modulevisits,
              data: datavalue.modulevisits,
              backgroundColor : ['rgba(25, 12, 155, 1)'],
              showTooltips : false,
              tension: 1
            },
            ]
        },
        options: {
          responsive: true,
          plugins: {
            legend: {
              position: '',
            },
            title: {
              display: true,
              text: '',
            }
          },
          scales: {
              y: {
                beginAtZero: true
              }
          }
        },
        };
      visitchart = new Chart(ctx,config);
    }
  };

  var get_visits_records = function(filter) {
      if (!filter) {
          filter = 'week';
      }

      var request = {
        methodname : 'report_lmsace_reports_site_visits',
        args : {
          filter : filter,
          chartid : 'sitevisitswidget'
        }
      };
      var promise = AJAX.call([request])[0];
      promise.done( function(result) {
        update_chart_data(result);
      });
      LoadIcon.addIconToContainerRemoveOnCompletion(loadiconElement, promise);
  }

  var update_chart_data = function(data) {

     visitchart.data.labels = data.label;
     visitchart.data.datasets[0].data = data.value.sitevisits;
     visitchart.data.datasets[1].data = data.value.coursevisits;
     visitchart.data.datasets[2].data = data.value.modulevisits;
     visitchart.update();
  }

  return {
     init : init
  };
});
