<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Table class that contains the list of learners overview report.
 *
 * @package    report_lmsace_reports
 * @copyright  LMSACE
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace report_lmsace_reports\widgets;

use \report_lmsace_reports\output\widgets_info;

/**
 * Class modules grades report.
 *
 * @package    report_lmsace_reports
 * @copyright  LMSACE
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class coursemodulegradeswidget extends widgets_info {

    /**
     * @var array $records
     */
    private $records;

    /**
     * @var string $context
     */
    public $context = "course";

    public $quizlist;

    private $assignmentlist = [];

    /**
     * Implemented the constructor.
     * @param string $filter
     */
    public function __construct($courseid, $filter = '') {

        parent::__construct();

        if (!$filter) {
            $filter = 'all';
        }

        $this->course = get_course($courseid);
        $this->filter = $filter;
        $this->get_report_data();
    }

    /**
     * Get chart type.
     * @return string
     */
    public function get_charttype() {
        return "bar";
    }

    /**
     * Report is chart or not.
     * @return bool
     */
    public function is_chart() {
        return true;
    }

    /**
     * Get the cache key.
     * @return string
     */
    public function get_cache_key() {
        return "modulesattempts" . $this->filter . "-" . $this->course->id;
    }

    /**
     * Set the report data.
     * @return void
     */
 /*    private function param_sql() {
        global $DB;
        if ($this->cache == null) {
            $this->load_cache();
        }
        if (!$this->cache->get($this->get_cache_key())) {

            $sql = "SELECT c.id, c.name, COUNT(cm.id) AS members
                FROM {cohort} c
                LEFT JOIN {cohort_members} cm ON cm.cohortid = c.id
                GROUP BY cm.cohortid";

            $records = $DB->get_records_sql($sql, null);
            $this->cache->set($this->get_cache_key(), $records);
        }
        $this->records = $this->cache->get($this->get_cache_key());
        $this->prepare_chartdata();
        $this->get_report_table();
    } */

    /**
     * Prepare chartdata.
     */
 /*     private function prepare_chartdata() {
        $label = [];
        $value = [];
        if (!empty($this->records)) {
            foreach ($this->records as $record) {
                $label[] = $record->name;
                $value[] = $record->members;
            }
        }
        $labelcount = count($label);
        $this->reportdata['background'] = report_lmsace_reports_get_random_back_color($labelcount);
        $this->reportdata['label'] = $label;
        $this->reportdata['value'] = $value;
    }
*/

    /**
     * Get the report data.
     */
    public function get_data() {

        if (empty(array_filter($this->reportdata))) {
            $this->reportdata['noresult'] = true;
        }

        return $this->reportdata;
    }

    /**
     * Prepare report data.
     */
    private function get_report_data() {
        // if (!$this->cache->get($this->get_cache_key())) {

            $data = $this->module_activities();
            // print_object($data);exit;
            $data['courseid'] = $this->course->id;
            $this->cache->set($this->get_cache_key(), $data);
        // }
        $this->reportdata = $this->cache->get($this->get_cache_key());
    }

    public function module_activities() {

        $daterange = report_lmsace_reports_get_duration_info($this->filter, 'all');

        $quizattempts =  $this->getquizattempts($daterange);
        $submission = $this->assignment_submissions($daterange);
        $grades = $this->grades($daterange);
        $result = ['attempts' => $quizattempts, 'submission' => $submission];

        return ['label' => [
            get_string('pluginname', 'mod_quiz'), get_string('pluginname', 'mod_assign')
        ], 'value' => array_values($result), 'grades' => $grades];
	}

    public function getquizattempts($daterange) {
		global $DB;

        $report = [];


        $durationsql = isset($daterange['timestart']) ? " AND timemodified BETWEEN :timestart AND :timeend " : '';

        $sql = ' SELECT id, quiz, count(*) AS count FROM {quiz_attempts}
            WHERE quiz IN (
                SELECT instance from {course_modules} WHERE course=:courseid AND module IN (
                    SELECT id from {modules} where name = "quiz"
                )
            ) '. $durationsql;

        $daterange['courseid'] = $this->course->id;
        $records = $DB->get_records_sql($sql, $daterange);
        foreach ($records as $id => $record) {
            $report[$record->quiz] = $record->count;
            $this->quizlist[] = $record->quiz;
        }

        return array_sum(array_values($report));
	}


	public function assignment_submissions($daterange) {
		global $DB;

		$sql = 'SELECT id, assignment, COUNT(*) AS count, userid FROM {assign_submission} WHERE status="submitted" ';

		if ($daterange) {
			$sql .= ' AND timemodified BETWEEN :timestart AND :timeend ';
		}

        $sql .= ' AND assignment IN ( select instance from {course_modules} WHERE course=:courseid AND module IN (select id from {modules} where name = "assign") ) ';
        $daterange['courseid'] = $this->course->id;

		$sql .= ' GROUP BY assignment ';

		$records = $DB->get_records_sql($sql, $daterange);

		if ($records) {
            foreach ($records as $id => $record) {
                $report[$record->assignment] = $record->count;
				$this->assignmentlist[] = $record->assignment;
			}
            // print_object($report);exit;
			return array_sum(array_values($report));
		}
		return [];
	}


	public function grades($daterange) {

        $assigngrades = $this->get_assign_grades($daterange);

		$quizgrades = $this->get_quiz_grades($daterange);

		return [$quizgrades, $assigngrades];
	}

	public function get_assign_grades($daterange) {
		global $DB;

		$sql = ' SELECT assignment, COUNT(*) AS count FROM {assign_grades} WHERE grader >= "1" ';
        // Daterange selections query contiditon.
        $sql .= isset($daterange['timestart']) ? " AND ( timemodified BETWEEN :timestart AND :timeend )  " : '';

		if (!empty($this->course) && !empty($this->assignmentlist)) {
            list($insql, $inparams) = $DB->get_in_or_equal($this->assignmentlist, SQL_PARAMS_NAMED, 'asg');
			$sql .= ' AND assignment '.$insql;
			$daterange = array_merge($daterange, $inparams);
		}
		$sql .= ' GROUP BY assignment ';
		$records = $DB->get_records_sql($sql, $daterange);

		if ($records) {
			foreach ($records as $id => $record) {
				$report[$record->assignment] = $record->count;
			}
			return array_sum(array_values($report));
		}
		return 0;
	}

	public function get_quiz_grades($daterange) {
		global $DB;

		$sql = ' SELECT quiz, COUNT(*) AS count FROM {quiz_grades} WHERE 1=1 ';

        $sql .= isset($daterange['timestart']) ? " AND timemodified BETWEEN :timestart AND :timeend " : '';

		if (!empty($this->course)) {
			$sql .= ' AND quiz IN (:quizlist) ';
			$daterange['quizlist'] = implode(',', $this->quizlist);
		}

		$sql .= ' GROUP BY quiz ';

		$records = $DB->get_records_sql($sql, $daterange);

		return $this->get_count_records($records, 'quiz');
	}

    public function get_count_records($records, $key) {
		if ($records) {
			foreach ($records as $id => $record) {
				$report[$record->{$key}] = $record->count;
			}
			return array_sum(array_values($report));
		}
		return [];
	}


}
