<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Plugin functions.
 *
 * @package    report_lmsace_reports
 * @copyright  2021 lmsace_reports
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

// Site reports - site information stack report.
define("REPORT_LMSACE_REPORTS_SITESTATE", "stacksitereports");

// Site reports - site user visits report.
define("REPORT_LMSACE_REPORTS_SITEVISITS", "sitevisits");

// Site report - Users registrations status counts.
define("REPORT_LMSACE_REPORTS_SITEUSERS", "siteusers");

// Site report - Site overview reports.
define("REPORT_LMSACE_REPORTS_SITEACTIVITIES", "overallsiteinfo");

// Site report - Unique active users report.
define("REPORT_LMSACE_REPORTS_SITEACTIVEUSERS", "siteactiveusers");

// Site report - Registered users enrolment status.
define("REPORT_LMSACE_REPORTS_SITEENROLLMENTSTATUS", "siteresourceofcourses");

// Site report - Enrolments completion by month.
define("REPORT_LMSACE_REPORTS_SITEENROLLMENTSCOMPLETIONMONTH", "enrolcompletionmonth");

// Site report - Enrolment methods usages.
define("REPORT_LMSACE_REPORTS_SITEENROLLMENTMETHOD", "enrolmethodusers");

// Site report - Top courses by enrollments.
define("REPORT_LMSACE_REPORTS_SITETOPCOURSEBYENROLLMENT", "topcourseenrolment");

// Site report - Top courses by completion.
define("REPORT_LMSACE_REPORTS_SITETOPCOURSEBYCOMPLETION", "topcoursecompletion");

// Site report - Cohorts information.
define("REPORT_LMSACE_REPORTS_SITECOHORTSINFO", "cohortsinfo");

// Site report - Overview stats information.
define("REPORT_LMSACE_REPORTS_SITESTATEINFO", "sitestateinfo");

define("REPORT_LMSACE_REPORTS_COURSESTATE", "stackcoursereports");
define("REPORT_LMSACE_REPORTS_COURSEENROLMENTCOMPLETION", "courseenrolcompletion");
define("REPORT_LMSACE_REPORTS_COURSEACTIVEINACTIVEUSERS", "courseactiveinactiveusers");
define("REPORT_LMSACE_REPORTS_COURSEACTIVITY", "courseresources");
define("REPORT_LMSACE_REPORTS_COURSEVISTITS", "coursevisits");
define("REPORT_LMSACE_REPORTS_COURSEHIGHSCORE", "coursehighscore");
// Course module grades.
define("REPORT_LMSACE_REPORTS_COURSEMODULEGRADES", 'coursemodulegrades');

define("REPORT_LMSACE_REPORTS_USERSTATE", "stackuserreports");
define("REPORT_LMSACE_REPORTS_USERMYACTIVITIES", "usermyactivities");
define("REPORT_LMSACE_REPORTS_USERMYQUIZZES", "usermyquizzes");
define("REPORT_LMSACE_REPORTS_USERMYASSIGNMENTS", "usermyassignments");
define("REPORT_LMSACE_REPORTS_USERCOHORTSGROUPS", "usergroupcohorts");
define("REPORT_LMSACE_REPORTS_USERLOGINS", "userlogins");
define("REPORT_LMSACE_REPORTS_USERMOSTVISITCOURSES", "mostvisitcourse");
define("REPORT_LMSACE_REPORTS_USERSCORES", "userscore");



/**
 * This function extends the navigation with the report items
 *
 * @param navigation_node $navigation The navigation node to extend
 * @param stdClass        $course     The course to object for the report
 * @param context         $context    The context of the course
 */
function report_lmsace_reports_extend_navigation_course($navigation, $course, $context) {
    $url = new moodle_url('/report/lmsace_reports/index.php', array('report' => 'coursereport', 'courseinfo' => $course->id));
    $navigation->add(get_string('lmsacecoursereports', 'report_lmsace_reports'), $url, navigation_node::TYPE_SETTING, null, null,
            new pix_icon('i/report', ''));
}


/**
 * This function extends the course navigation with the report items
 *
 * @param navigation_node $navigation The navigation node to extend
 * @param stdClass $user
 * @param stdClass $course The course to object for the report
 */
function report_lmsace_reports_extend_navigation_user($navigation, $user, $course) {
    global $USER;
    $url = new moodle_url('/report/lmsace_reports/index.php', array('report' => 'userreport', 'userinfo' => $user->id));
    $navigation->add(get_string('lmsaceuserreports', 'report_lmsace_reports'), $url);
}

/**
 * Add nodes to myprofile page.
 *
 * @param \core_user\output\myprofile\tree $tree Tree object
 * @param stdClass $user user object
 * @param bool $iscurrentuser
 * @param stdClass $course Course object
 *
 * @return bool
 */
function report_lmsace_reports_myprofile_navigation(core_user\output\myprofile\tree $tree, $user, $iscurrentuser, $course) {
    global $USER;
    $url = new moodle_url('/report/lmsace_reports/index.php',
        array('report' => 'userreport', 'userinfo' => $user->id));
    $node = new core_user\output\myprofile\node('reports', 'userlmsacereport',
        get_string('lmsaceuserreports', 'report_lmsace_reports'), null, $url);
    $tree->add_node($node);
    if (report_lmsace_is_currentuser_has_teacherrole()) {
        $teachercourse = report_lmsace_get_teacher_courses($USER->id);
        $courseid = current($teachercourse)->courseid;
        $url = new moodle_url('/report/lmsace_reports/index.php', array('report' => 'coursereport', 'courseinfo' => $courseid));
        /* $navigation->add(get_string('lmsacecoursereports', 'report_lmsace_reports'), $url, navigation_node::TYPE_SETTING, null, null,
                new pix_icon('i/report', '')); */
        $node = new core_user\output\myprofile\node('reports', 'courselmsacereport',
        get_string('lmsacecoursereports', 'report_lmsace_reports'), null, $url);
        $tree->add_node($node);
    }
    return true;
}


/**
 * Get courses.
 * @param int $selectid
 * @param bool $getcourse
 * @return array list of courses.
 */
function report_lmsace_reports_get_course($selectid = 0, $getcourse = false) {
    global $CFG;
    $data = [];
    $courses = core_course_category::get(0)->get_courses(array('recursive' => true));
    if ($getcourse) {
        return $courses;
    }
    if (!empty($courses)) {
        foreach ($courses as $course) {
            $list['id'] = $course->id;
            $list['coursename'] = $course->get_formatted_name();
            if ($selectid == $course->id) {
                $list['selected'] = "selected";
            } else {
                $list['selected'] = '';
            }
            $data[] = $list;
        }
    }
    return $data;
}


/**
 * Get courses.
 * @param int $selectid
 * @param bool $getcourse
 * @return array list of courses.
 */
function report_lmsace_generate_course_chooser_data($courseids, $currentcourse) {
    global $CFG;
    $data = [];
    if (!empty($courseids)) {
        foreach ($courseids as $courseid) {
            $course = new core_course_list_element(get_course($courseid));
            $list['id'] = $course->id;
            $list['coursename'] = $course->get_formatted_name();
            if ($currentcourse == $course->id) {
                $list['selected'] = "selected";
            } else {
                $list['selected'] = '';
            }
            $data[] = $list;
        }
    }
    return $data;
}


/**
 * Get users.
 * @param int $selectid
 * @param bool $getusers
 */
function report_lmsace_reports_get_users($selectid = 0, $getusers = false) {
    global $CFG, $OUTPUT, $PAGE;
    $data = [];
    $context = \context_system::instance();
    $users = get_users_listing();
    if (!empty($users)) {
        foreach ($users as $user) {

            $list['id'] = $user->id;
            $report['fullname'] = $user->firstname.$user->lastname;
            $report['email'] = $user->email;
            $list['usertext'] = $OUTPUT->render_from_template('report_lmsace_reports/lmsace_reports_select_user', $report);
            if ($selectid == $user->id) {
                $list['selected'] = "selected";
            } else {
                $list['selected'] = '';
            }
            $data[] = $list;
        }
    }

    return $data;
}

/**
 * Get default display course in course blocks.
 * @return int courseid
 */
function report_lmsace_reports_get_first_course() {
    global $DB;
    $sql = "SELECT * FROM {course} WHERE category != 0 ORDER BY id LIMIT 1";
    $course = $DB->get_record_sql($sql, null);
    return !empty($course) ? $course->id : 0;
}

/**
 * Get default display user in user blocks.
 * @return int courseid
 */
function report_lmsace_reports_get_first_user() {
    global $DB;
    $sql = "SELECT * FROM {user} WHERE id > 2 AND deleted = 0 ORDER BY id LIMIT 1";
    $user = $DB->get_record_sql($sql, null);
    return !empty($user) ? $user->id : 0;
}

/**
 * Get the site admin
 * @return object user object
 */
function report_lmsace_reports_site_admin_user() {
    global $CFG;
    $adminuser = '';
    $siteadmins = explode(',', $CFG->siteadmins);
    if (!empty($siteadmins) && isset($siteadmins[0])) {
        $adminuser = \core_user::get_user($siteadmins[0]);
    }
    return $adminuser;
}

/**
 * get list of activities info details
 * @return array activities info.
 *
 */
function report_lmsace_reports_activities_info_details() {
    $adminuser = report_lmsace_reports_site_admin_user();
    $contentitemservice = \core_course\local\factory\content_item_service_factory::get_content_item_service();
    $meta = $contentitemservice->get_all_content_items($adminuser);
    $activityinfos = [];
    foreach ($meta as $mod) {
        $activityinfos[$mod->name] = $mod;
    }
    return $activityinfos;
}

/**
 * Load js data
 * @param array $reports
 */
function report_lmsace_reports_load_js_data($reports) {
    global $PAGE;
    if (!empty($reports)) {
        foreach ($reports as $var => $data) {
            $PAGE->requires->data_for_js($var, $data);
        }
    }
}

/**
 * Get site visits.
 * @param string $filter
 * @param bool $details
 * @param int $userid
 * @return array list of visits reports
 *
 */
function report_lmsace_get_site_visits($filter = '', $details = false, $userid = 0) {
    global $CFG, $DB;
    if (!$filter) {
        $filter = 'week';
    }
    if ($filter == 'month') {
        $labelcount = 30;
        $groupby = 604800;
    } else if ($filter == 'year') {
        $labelcount = 365;
        $groupby = 86400 * 30;
    } else {
        $labelcount = 7;
        $groupby = 86400;
    }

    $timestart = strtotime("-1". $filter);
    $timeend = time();
    $usersql = '';
    $userparams = [];
    if ($userid) {
        $usersql = 'AND ls.userid = :userid';
        $userparams = ['userid' => $userid];
    }

    $sql = "SELECT FLOOR(ls.timecreated / 86400) AS userdate, count(ls.id) AS visits
    FROM {logstore_standard_log} ls
    WHERE ls.action = 'loggedin' AND ls.target = 'user' AND ls.userid > 2 $usersql
    AND ls.timecreated BETWEEN :timestart AND :timeend
    GROUP BY FLOOR(ls.timecreated / 86400)";

    $params = [
        'timestart' => $timestart,
        'timeend' => $timeend
    ];
    $params = array_merge($params, $userparams);
    $records = $DB->get_records_sql($sql, $params);

    if ($details) {
        return $records;
    }

    $labels = [];
    $dates = [];
    $values = [];

    for ($i = 0; $i < $labelcount; $i++) {
        $time = time() - $i * 24 * 60 * 60;
        $values[floor($time / (24 * 60 * 60))] = 0;
        $labels[] = date("d M y", $time);
    }
    if (!empty($records)) {
        foreach (array_keys($values) as $key) {
            if (!isset($records[$key])) {
                continue;
            }
            $values[$key] = $records[$key]->visits;
        }
    }
    $data['label'] = array_reverse($labels);
    $data['value'] = array_reverse($values);
    return $data;
}

/**
 * spareate the chart values using chart
 * @param array $reports
 * @return array chart labels,values
 */
function report_lmsace_reports_chart_values($reports) {
    $data = [];

    if (!empty($reports)) {
        foreach ($reports as $key => $value) {
            if ($key == 'id') {
                continue;
            }
            $data['label'][] = get_string($key, 'report_lmsace_reports');
            $data['value'][] = !empty($value) ? $value : 0;
        }
    }
    // Create flag for the empty data.
    $data['noresult'] = empty(array_filter((array) $reports));

    return $data;
}



/**
 * Get chart reports values
 * @param string $filter
 * @param string $classname
 * @param int $relatedid
 * @param string $function
 */
function report_lmsace_reports_ajax_chart_reports($filter, $classname, $relatedid = 0, $function = '') {
    global $CFG, $PAGE;
    $classfile = $CFG->dirroot . '/report/lmsace_reports/classes/widgets/' . $classname . '.php';
    if (!file_exists($classfile)) {
        debugging("Class file dosn't exist " . $classname);
    }
    require_once($classfile);
    $classname = '\\report_lmsace_reports\\widgets\\' . $classname;
    if ($relatedid) {
        $widgetinstance = new $classname($relatedid, $filter);
    } else {
        $widgetinstance = new $classname($filter);
    }
    if (empty($function)) {
        return $widgetinstance->get_data();
    } else {
        return $widgetinstance->{$function}();
    }
}

/**
 * get duration info
 * @param string $filter
 * @param string $default
 * @return array duration.
 */
function report_lmsace_reports_get_duration_info($filter, $default = 'all') {
    $duration = [];
    if (!$filter) {
        $filter = $default;
    }
    // Check the over all config.
    if ($filter != 'all') {
        $duration['timestart'] = strtotime('-1'.$filter);
        $duration['timeend'] = time();
    }
    return $duration;
}

/**
 * get random colors
 * @param int $count
 * @return array list of colors
 */
function report_lmsace_reports_get_random_back_color($count) {
    $colors = [];
    if (!empty($count)) {
        for ($i = 0; $i <= $count; $i++) {
            $r = rand(10, 255);
            $g = rand(10, 255);
            $b = rand(10, 255);
            $colors[] = "rgb(".$r.",".$g.",".$b.")";
        }
    }
    return $colors;
}

/**
 * Get course info
 * @param int $courseid
 * @return object course info object
 *
 */
function report_lmsace_reports_get_course_info($courseid) {
    global $DB;
    $course = $DB->get_record('course', array('id' => $courseid));
    $course = new core_course_list_element($course);
    return $course;
}

/**
 * Get the last 12 months.
 */
function report_lmsace_get_current_last_12months() {
    $len = 12;
    $months = [];
    for ($i = 0; $i <= 12; $i++) {
        $record = [];
        $seconds = strtotime( date( 'Y-m-01' )." -$i months");
        $record['month'] = date("F Y", $seconds);
        $months[] = $record;
    }
    return $months;
}

/**
 * Get the report widgets.
 */
function report_lmsace_reports_get_default_widgets() {
    global $DB;
    $sort = 0;
    $widgets = array(
        'sitevisits' => array(
            'instance' => 'sitevisitswidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'siteusers' => array(
            'instance' => 'siteuserswidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'overallsiteinfo' => array(
            'instance' => 'overallsiteinfowidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'siteresourceofcourses' => array(
            'instance' => 'siteresourceofcourseswidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'siteactiveusers' => array(
            'instance' => 'siteactiveuserswidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'enrolcompletionmonth' => array(
            'instance' => 'enrolcompletionmonthwidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'enrolmethodusers' => array(
            'instance' => 'enrolmethoduserswidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'topcourseenrolment' => array(
            'instance' => 'topcourseenrolmentwidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'topcoursecompletion' => array(
            'instance' => 'topcoursecompletionwidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'stacksitereports' => array(
            'instance' => 'stacksitereportswidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'cohortsinfo' => array(
            'instance' => 'cohortsinfowidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'sitestateinfo' => array(
            'instance' => 'sitestateinfowidget',
            'context' => 'site',
            'sort' => $sort++,
            'visible' => true,
        ),
        'stackcoursereports' => array(
            'instance' => 'stackcoursereportswidget',
            'context' => 'course',
            'sort' => $sort++,
            'visible' => true,
        ),
        'coursemodulegrades' => array(
            'instance' => 'coursemodulegradeswidget',
            'context' => 'course',
            'sort' => $sort++,
            'visible' => true,
        ),
        'courseenrolcompletion' => array(
            'instance' => 'courseenrolcompletionwidget',
            'context' => 'course',
            'sort' => $sort++,
            'visible' => true,
        ),
        'courseactiveinactiveusers' => array(
            'instance' => 'courseactiveinactiveuserswidget',
            'context' => 'course',
            'sort' => $sort++,
            'visible' => true,
        ),
        'courseresources' => array(
            'instance' => 'courseresourceswidget',
            'context' => 'course',
            'sort' => $sort++,
            'visible' => true,
        ),
        'coursevisits' => array(
            'instance' => 'coursevisitswidget',
            'context' => 'course',
            'sort' => $sort++,
            'visible' => true,
        ),
        'coursehighscore' => array(
            'instance' => 'coursehighscorewidget',
            'context' => 'course',
            'sort' => $sort++,
            'visible' => true,
        ),
        'stackuserreports' => array(
            'instance' => 'stackuserreportswidget',
            'context' => 'user',
            'sort' => $sort++,
            'visible' => true,
        ),
        'usermyactivities' => array(
            'instance' => 'usermyactivitieswidget',
            'context' => 'user',
            'sort' => $sort++,
            'visible' => true,
        ),
        'usermyquizzes' => array(
            'instance' => 'usermyquizzeswidget',
            'context' => 'user',
            'sort' => $sort++,
            'visible' => true,
        ),
        'usermyassignments' => array(
            'instance' => 'usermyassignmentswidget',
            'context' => 'user',
            'sort' => $sort++,
            'visible' => true,
        ),
        'usergroupcohorts' => array(
            'instance' => 'usergroupcohortswidget',
            'context' => 'user',
            'sort' => $sort++,
            'visible' => true,
        ),
        'userlogins' => array(
            'instance' => 'userloginswidget',
            'context' => 'user',
            'sort' => $sort++,
            'visible' => true,
        ),
        'mostvisitcourse' => array(
            'instance' => 'mostvisitcoursewidget',
            'context' => 'user',
            'sort' => $sort++,
            'visible' => true,
        ),
        'userscore' => array(
            'instance' => 'userscorewidget',
            'context' => 'user',
            'sort' => $sort++,
            'visible' => true,
        ),
    );
    return $widgets;
}

/**
 * Intialize the reports widgets.
 */
function report_lmsace_reports_load_widgets() {
    global $DB;
    $widgets = report_lmsace_reports_get_default_widgets();
    foreach ($widgets as $report => $widget) {
        $widgetdata = new stdClass();
        if (!$DB->record_exists('report_lmsace_widgets', ['widget' => $report])) {
            $widgetdata->widget = $report;
            $widgetdata->instance = $widget['instance'];
            $widgetdata->context = $widget['context'];
            $widgetdata->sort = $widget['sort'];
            $widgetdata->visible = $widget['visible'];
            $widgetdata->timecreated = time();
            $DB->insert_record('report_lmsace_widgets', $widgetdata);
        }
    }
}

/**
 * Get the user overall courseinfo.
 * @param int $userid
 * @return int
 */
function report_lmsace_reports_get_user_overall_courseinfo($userid) {
    $progress = 0;
    $target = 0;
    $courses = enrol_get_users_courses($userid, true, '*');
    foreach ($courses as $course) {
        if (completion_can_view_data($userid, $course)) {
            $progress += \core_completion\progress::get_course_progress_percentage($course, $userid);
            $target ++;
        }
    }
    return round($progress / ($target * 100) * 100);
}


/**
 * Get the most activities in course.
 * @param int $courseid
 * @return int
 */

function report_lmsace_reports_get_most_activities_in_course($courseid) {
    global $DB;
    $sql = "SELECT cm.module, count(cm.id) AS count, m.name  FROM {course_modules} cm
        LEFT JOIN {modules} m ON  m.id = cm.module
        WHERE cm.course = :courseid AND cm.deletioninprogress = 0
        GROUP BY module ORDER BY COUNT(cm.id) DESC";

    $data = $DB->get_records_sql($sql, ['courseid' => $courseid], 0, 3);
    return $data;
}


function report_lmsace_get_block_report() {
    global $USER, $OUTPUT, $PAGE, $USER;
    // Site related show the report.
    if (has_capability("report/lmsace_reports:viewsitereports", context_system::instance())) {
        $classname = '\\report_lmsace_reports\\widgets\\stacksitereportswidget';
        $widgetinstance = new $classname();
        $templatename = "report_lmsace_reports/siteblocks";
        $reporturl = new moodle_url('/report/lmsace_reports/index.php');
    } else if ($PAGE->context->contextlevel == CONTEXT_COURSE) {
        $classname = '\\report_lmsace_reports\\widgets\\stackcoursereportswidget';
        $widgetinstance = new $classname($PAGE->course->id);
        $templatename = "report_lmsace_reports/courseblocks";
        $reporturl = new moodle_url('/report/lmsace_reports/index.php', ['report' => 'coursereport', 'courseinfo' => $PAGE->course->id]);
    } else if (report_lmsace_is_currentuser_has_teacherrole()) {
        $classname = '\\report_lmsace_reports\\widgets\\stackcoursereportswidget';
        $teachercourse = report_lmsace_get_teacher_courses($USER->id);
        $courseid = current($teachercourse)->courseid;
        $widgetinstance = new $classname($courseid);
        $templatename = "report_lmsace_reports/courseblocks";
        $reporturl = new moodle_url('/report/lmsace_reports/index.php', ['report' => 'coursereport', 'courseinfo' => $courseid]);
    } else { // User related the report.
        $classname = '\\report_lmsace_reports\\widgets\\stackuserreportswidget';
        $widgetinstance = new $classname($USER->id);
        $templatename = "report_lmsace_reports/userblocks";
        $reporturl = new moodle_url('/report/lmsace_reports/index.php', ['report' => 'userreport', 'userinfo' => $USER->id]);
    }
    $template = $widgetinstance->get_data();
    //print_object($template);exit;
    $template['stacksitereports'] = true;
    $template['enableuserblock'] = true;
    $template['enablecourseblock'] = true;
    $template['stackcoursereports'] = true;
    $template['stackuserreports'] = true;
    $template['reportbase'] = true;
    $header = $OUTPUT->render_from_template($templatename, $template);
    $footer = html_writer::link($reporturl->out(false), get_string('viewreport', 'block_lmsace_reports'));
    return [$header, $footer];
}

/**
 * Check the current user has teacher role.
 *
 * @return void
 */
function report_lmsace_is_currentuser_has_teacherrole() {
    global $DB, $USER;
    $roles = get_roles_with_capability("report/lmsace_reports:viewcoursereports");
    $roleids = array_keys($roles);
    $params = ['userid' => $USER->id, 'contextlevel' => CONTEXT_COURSE];
    list($rolesql, $roleparams) = $DB->get_in_or_equal($roleids, SQL_PARAMS_NAMED);
    $params = array_merge($params, $roleparams);
    $sql = "SELECT * FROM {role_assignments} WHERE userid = :userid AND roleid $rolesql";
    if ($DB->record_exists_sql($sql, $params)) {
        return true;
    }
    return false;
}

function report_lmsace_get_teacher_courses($userid) {
    global $DB;
    $roles = get_roles_with_capability("report/lmsace_reports:viewcoursereports");
    $roleids = array_keys($roles);
    $params = ['userid' => $userid, 'contextlevel' => CONTEXT_COURSE];
    list($rolesql, $roleparams) = $DB->get_in_or_equal($roleids, SQL_PARAMS_NAMED);
    $params = array_merge($params, $roleparams);
    $sql = "SELECT c.id, c.instanceid as courseid FROM {role_assignments} ra
    JOIN {context} c ON c.id = ra.contextid
    WHERE c.contextlevel = :contextlevel AND ra.userid = :userid AND ra.roleid $rolesql";
    $record = $DB->get_records_sql($sql, $params);
    return $record;
}

function report_lmsace_get_addtional_plugins() {
    $pluginman = core_plugin_manager::instance();
    $plugininfo = $pluginman->get_plugins();
    $numextension = 0;
    foreach ($plugininfo as $type => $plugins) {
        foreach ($plugins as $name => $plugin) {
            if (!$plugin->is_standard() && $plugin->get_status() !== core_plugin_manager::PLUGIN_STATUS_MISSING) {
                $numextension++;
            }
        }
    }
    return $numextension;
}

function report_lmsace_get_foldersize($path) {
    $totalSize = 0;
    $iterator = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($path));

    foreach ($iterator as $file) {
        if ($file->isFile()) {
            $totalSize += $file->getSize();
        }
    }

    return report_lmsace_get_formatSize($totalSize);
}

function report_lmsace_get_moodle_spaces() {
    global $CFG;

    $cache = cache::make('report_lmsace_reports', 'reportwidgets');
    // Get total size and free space of the folder
    if (!$cache->get('sizemoodlesrc')) {
        $cache->set('sizemoodlesrc', report_lmsace_get_foldersize($CFG->dirroot));
    }

    $moodlesrc = $cache->get('sizemoodlesrc');

    if (!$cache->get('sizemoodledata')) {
        $cache->set('sizemoodledata', report_lmsace_get_foldersize($CFG->dataroot));
    }

    $moodledata = $cache->get('sizemoodledata');
    return ['moodlesrc' => $moodlesrc, 'moodledata' => $moodledata];
}

function  report_lmsace_get_formatSize($size) {
    $units = array('B', 'KB', 'MB', 'GB', 'TB');
    $i = 0;
    while ($size >= 1024 && $i < count($units) - 1) {
        $size /= 1024;
        $i++;
    }
    return round($size, 2) . ' ' . $units[$i] . ' ' . get_string('used', 'core');
}
