<?php
// This file is part of the custom Moodle Bootstrap theme
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * @package    theme_alluri
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace theme_alluri;
use moodle_url;
use html_writer;
use outputlib;

class alluri_blocks {
    public $output;

    public function __construct() {
        global $OUTPUT;
        $this->output = $OUTPUT;
    }

     /**
     * Call the frontpage slider js.
     * @param string $blockid
     * @return void
     */
    public function include_frontslide_js($blockid, $data = []) {
        global $PAGE;
        $PAGE->requires->js_call_amd('theme_alluri/frontsliders', $blockid, $data);
    }

    public function alluri_homebanner($layout = 1) {
        global $CFG, $PAGE, $OUTPUT;

        $viewcourse = new moodle_url('/course/index.php');
        $searchurl = new moodle_url('/course/search.php');

        $courserenderer = $PAGE->get_renderer('core', 'course');
        $course_insights = $courserenderer->course_insights_home();

        $countype = theme_alluri_get_setting('counttype');

        $course_insights_1 = $course_insights['val1'];
        $course_insights_2 = $course_insights['val2'];
        $course_insights_3 = $course_insights['val3'];

        $searchcourses = get_string('searchcourses');
        $go = get_string('go');
        $view_all_courses = get_string('view_all_courses', 'theme_alluri');

        if ($countype == 'default') {
            $content1 = get_string('courses', 'theme_alluri');
            $content2 = get_string('teachers', "theme_alluri");
            $content3 = get_string('students', 'theme_alluri');
        } else {

            $content1 = theme_alluri_get_setting('countBlockContent1');
            $content1 = theme_alluri_lang($content1);
            $content2 = theme_alluri_get_setting('countBlockContent2');
            $content2 = theme_alluri_lang($content2);
            $content3 = theme_alluri_get_setting('countBlockContent3');
            $content3 = theme_alluri_lang($content3);
        }
         
        $bannersitestatus = theme_alluri_get_setting('bannersitestatus');
        $tbanner = theme_alluri_get_setting('homebannerstatus');

        if ($tbanner != '' && $tbanner != 0) {

            $searchbar = theme_alluri_get_setting('searchbarstatus');
            $bannercontent = theme_alluri_get_setting('homebannercontent');
            $bannercontent = theme_alluri_lang($bannercontent);
            $bannercont = (!empty($bannercontent)) ? $bannercontent : '';

            $videotype = theme_alluri_get_setting('bannervideotype');
            $youtube = $vimeo = $hosted = $image = '';

            if ($videotype == 1) {
                $youtube = 1;
                $vclass = 'youtube-player';
    
            } else if ($videotype == 2) {
                $hosted = 1;
                $vclass = 'hosted';
            } else {
                $image = 1;
                $vclass = 'imagebanner';
            }

            $strsearchcourses = get_string("searchcourses");
            $searchurl = new moodle_url('/course/search.php');
             $autocontents = theme_alluri_get_setting('searchAutocontent');
            $videourl = theme_alluri_get_setting('bannervideourl');
            $videourl = theme_alluri_check_url($videourl);
            $bannerimage = $PAGE->theme->setting_file_url('homebanner', 'homebanner');

             $maskurl = $PAGE->theme->setting_file_url('bannerposter', 'bannerposter');

            if ($image == 1) {
                $maskurl = '';
            }
            $type = $this->alluri_check_video_type($videourl);
            if ($type != $videotype) {
                $videourl == '';
            }
            $videoproperty = json_encode([
                'videoURL' => $videourl,
                'containment' => '.banner',
                'autoPlay' => true,
                'mute' => true,
                'startAt' => 0,
                'opacity' => 1,
                'showControls' => false,
                'loop' => true,
                'abundance' => 0.9,
                'showYTLogo' => false,
            ]);

            $template = array(
                'go' => $go,
                'viewcourse' => $viewcourse,
                'searchcourses' => $searchcourses,
                'view_all_courses' => $view_all_courses,

                'content1' => $content1,
                'content2' => $content2,
                'content3' => $content3,

                'course_insights_1' => $course_insights_1,
                'course_insights_2' => $course_insights_2,
                'course_insights_3' => $course_insights_3,


                'bannersitestatus' => $bannersitestatus,
                'searchbar' => $searchbar,
                'bannercontent' => $bannercont,
                // 'stats' => $stats,
                // 'statclass' => $class,
                // 'autocontents' => $autocontents,
                'placeholder' => $strsearchcourses,
                'vclass' => $vclass,
                'image' => $image,
                'vimeo' => $vimeo,
                'hosted' => $hosted,
                'youtube' => $youtube,
                'videourl' => $videourl,

                'bannerimage' => $bannerimage,
                'searchurl' => $searchurl,
                'maskurl' => $maskurl,
                'videoproperty' => $videoproperty,
            );
            return $OUTPUT->render_from_template('theme_alluri/homebanner', $template);
        }
    }

    public function sitefeatures() {

        global $CFG, $PAGE, $OUTPUT;

        $sitefeaturestatus = theme_alluri_get_setting('sitefeaturestatus');

        $sitefeatureblock1status = theme_alluri_get_setting('sitefeatureblock1status');
        $sitefeatureblock2status = theme_alluri_get_setting('sitefeatureblock2status');
        $sitefeatureblock3status = theme_alluri_get_setting('sitefeatureblock3status');

        $site_flink_txt1 = trim(theme_alluri_get_setting('sitefblock1buttontext', true));
        $site_flink_txt2 = trim(theme_alluri_get_setting('sitefblock2buttontext', true));
        $site_flink_txt3 = trim(theme_alluri_get_setting('sitefblock3buttontext', true));

        $sitefblock1title = theme_alluri_get_setting('sitefblock1title', true);
        $sitefblock2title = theme_alluri_get_setting('sitefblock2title', true);
        $sitefblock3title = theme_alluri_get_setting('sitefblock3title', true);

        $sitefblock1content = theme_alluri_get_setting('sitefblock1content', 'format_html');
        $sitefblock1content = theme_alluri_lang($sitefblock1content);
        $sitefblock2content = theme_alluri_get_setting('sitefblock2content', 'format_html');
        $sitefblock2content = theme_alluri_lang($sitefblock2content);
        $sitefblock3content = theme_alluri_get_setting('sitefblock3content', 'format_html');
        $sitefblock3content = theme_alluri_lang($sitefblock3content);

        $site_flink_txtcheck = (isset($site_flink_txt1) != '' || isset($site_flink_txt2) != '' || isset($site_flink_txt3) != '') ? 1 : 0;

        $sitefblock1buttonurl = theme_alluri_get_setting('sitefblock1buttonurl');
        $sitefblock2buttonurl = theme_alluri_get_setting('sitefblock2buttonurl');
        $sitefblock3buttonurl = theme_alluri_get_setting('sitefblock3buttonurl');

        $sitefblock1target = theme_alluri_get_setting('sitefblock1target');
        $sitefblock2target = theme_alluri_get_setting('sitefblock2target');
        $sitefblock3target = theme_alluri_get_setting('sitefblock3target');

        (int)$sfb = 0;
        for ($i = 1; $i <= 3; $i++) {
            $sitefeatureblockstatus = theme_alluri_get_setting('sitefeatureblock'.$i.'status');
            if (!empty($sitefeatureblockstatus)) {
                $sfb = $sfb + 1;
            }
        }

        switch ($sfb) {
            case 3:
                $class = 'col-md-4';
                break;
            case 2:
                $class = 'col-md-6';
                break;
            case 1:
                $class = 'col-md-12';
                break;
            case 0:
                $class = 'col-md-0';
                break;
            default:
                $class = 'col-md-4';
                break;
        }

        $bgimage = $PAGE->theme->setting_file_url('sitefeaturebg', 'sitefeaturebg');
        if (empty($bgimage)) {
            $bgimage = $OUTPUT->image_url('home/sitefeaturebg', 'theme');
        }

        $template = array(
            'sitefeaturestatus' => $sitefeaturestatus,

            'sitefeatureblock1status' => $sitefeatureblock1status,
            'sitefeatureblock2status' => $sitefeatureblock2status,
            'sitefeatureblock3status' => $sitefeatureblock3status,

            'sitefblock1title' => $sitefblock1title,
            'sitefblock2title' => $sitefblock2title,
            'sitefblock3title' => $sitefblock3title,

            'sitefblock1content' => $sitefblock1content,
            'sitefblock2content' => $sitefblock2content,
            'sitefblock3content' => $sitefblock3content,

            'site_flink_txt1' => $site_flink_txt1,
            'site_flink_txt2' => $site_flink_txt2,
            'site_flink_txt3' => $site_flink_txt3,

            'site_flink_txtcheck' => $site_flink_txtcheck,

            'sitefblock1buttonurl' => $sitefblock1buttonurl,
            'sitefblock2buttonurl' => $sitefblock2buttonurl,
            'sitefblock3buttonurl' => $sitefblock3buttonurl,

            'sitefblock1target' => $sitefblock1target,
            'sitefblock2target' => $sitefblock2target,
            'sitefblock3target' => $sitefblock3target,
            'bgimage' => $bgimage,
            'class' => $class,
            );
        $sitefeaturesjarallax = theme_alluri_get_setting('sitefeaturejarallaxstatus');
        $this->include_frontslide_js('sitefeature', [$sitefeaturesjarallax]);
        return $OUTPUT->render_from_template('theme_alluri/sitefeatures', $template);
    }

    public function marketingspot() {
        global $CFG, $PAGE, $OUTPUT;

        $marketingspotstatus = theme_alluri_get_setting('marketingspotstatus');
        $marketingspotcontent = theme_alluri_get_setting('marketingspotcontent');
        $marketingspotcontent = theme_alluri_lang($marketingspotcontent);
        $marketingspotbutton = theme_alluri_get_setting('marketingspotbutton');
        $marketingspotbuttonurl = theme_alluri_get_setting('marketingspotbuttonurl');

        // $url = new moodle_url($marketingspotbuttonurl);
        $buttonurl = theme_alluri_check_url($marketingspotbuttonurl);
        $template = array(
            'marketingspotstatus' => $marketingspotstatus,
            'marketingspotcontent' => $marketingspotcontent,
            'marketingspotbutton' => $marketingspotbutton,
            'marketingspotbuttonurl' => $marketingspotbuttonurl,
            'buttonurl' => $buttonurl
            );
        return $OUTPUT->render_from_template('theme_alluri/marketingspot', $template);
    }

    public function testimonials() {
        global $OUTPUT, $PAGE;
            $strtmonial = '';
            $titems = '';
            $indicators = "";
            $numberoftmonials = get_config('theme_alluri', 'numberoftmonials');
            $atestimonials = array();

        for ($i = 1; $i <= $numberoftmonials; $i++) {

                $testimonialstatus = theme_alluri_get_setting('testimonialstatus');
                $testimonial = get_config('theme_alluri', 'tmonial'.$i.'text');
                $testimonial = theme_alluri_lang($testimonial);
                $uname = get_config('theme_alluri', 'tmonial'.$i.'uname');
                $utype = get_config('theme_alluri', 'tmonial'.$i.'utype');
                $noimg_url = $OUTPUT->image_url('base/noimg-64x64', 'theme');
                $uimage = $PAGE->theme->setting_file_url('tmonial'.$i.'img', 'tmonial'.$i.'img');

            if (!empty($testimonial) && !empty($uname) ) {

                        $activeClass = ($i == "1") ? "active" : "";
                        // $cur_testimonial =  $atestimonials;
                        $noimg_url = $OUTPUT->image_url('base/noimg-64x64', 'theme');
                        $userimg = (!empty($uimage)) ? $uimage : $noimg_url;
                        $titems .= ' <div class="testimonial-items item '.$activeClass.'">
                        <h3>&ldquo; '.format_string($testimonial).' &rdquo;</h3>
                        <div class="user-info">
                            <div class="uithumb">
                                <a href="javascript:void(0);">
                                    <img src="'.$userimg.'" width="64" height="64" alt="">
                                </a>
                            </div>
                            <h3>'.format_string($uname).'<span>'.ucfirst(format_string($utype)).'</span></h3>
                        </div>
                        </div>
                        ';
                        $no = (int) $i - 1;
                        $indicators .= '<li class="'.$activeClass.'" data-target="#testimonials-carousel" data-slide-to="'.$no.'" ></li>';
            }

        }
        $testimonial_title =  theme_alluri_get_setting('tmonialTitle');

        if ($testimonialstatus != '') {

                $strtmonial .= '<div class="site-testimonials">
                <div class="container-fluid">
                    <h2>'.format_string($testimonial_title).'</h2>
                    <div class="text-quote"><span>&ldquo;</span></div>
                    <div id="testimonials-carousel" class="carousel slide slick"  data-ride="carousel" >
                         <div class="carousel-inner" role="listbox" >
                            '.$titems.'
                        </div>';

                if ($numberoftmonials >  1) {
                    $strtmonial .= '<a class="carousel-control-prev" href="#testimonials-carousel" role="button" data-slide="prev">
                        </a>
                        <a class="carousel-control-next" href="#testimonials-carousel" role="button" data-slide="next">
                        </a>';
                 }
               $strtmonial .= ' </div>
                    </div>
                </div>';
        }
        $this->include_frontslide_js('testimonials');
        return $strtmonial;
    }

    public function siteevents() {
        $content = '';
        $blockcontent = theme_alluri_get_setting('newsblockcontent','format_html');
        if ($blockcontent) {
            $content .= html_writer::start_tag('div', array('class' => 'site-noticearea'));
                $content .= html_writer::start_tag('div', array("class" => "content-overlay"));
                $content .= html_writer::end_tag('div');
                $content .= html_writer::start_tag('div', array("class" => "container-fluid"));
                $content .= $blockcontent;
                $content .= html_writer::end_tag('div');
            $content .= html_writer::end_tag('div');
        }
        $newseventsjarallax = theme_alluri_get_setting('newseventjarallax');
        $this->include_frontslide_js('newsevents', [$newseventsjarallax]);
        return $content;
    }

    /**
     * Testimonials block html contents.
     * @param type|string $counttype
     * @return type
     */
    public function theme_alluri_testimonials($counttype= "") {
        global $CFG, $PAGE, $OUTPUT;
        $content = '';
        $num = 0;
        $toggletmonial = theme_alluri_get_setting('testimonialstatus');

        if ($toggletmonial != 1) {
            return '';
        }
        $number = $PAGE->theme->settings->numberoftmonials;

        $testimonial_title = theme_alluri_get_setting('tmonialTitle');
        $testimonial_title = (!empty($testimonial_title)) ? $testimonial_title : get_string('tmonialblkTitle_default', 'theme_alluri');
        $testimonial_title = theme_alluri_lang($testimonial_title);
        if (!empty($number)) {

            $numberRange = range(0, $number);
            $numberArr = array_chunk($numberRange, 3);

            $content .= html_writer::start_tag('div', array('class' => 'testimonial-block'));
            $content .= html_writer::start_tag('div', array('class' => 'container'));
            // $span = html_writer::tag('span', ' <i class="fa fa-heart"></i>');
            $content .= html_writer::tag('h2', $testimonial_title , array('class' => 'title-headings'));
            // $content .= html_writer::start_tag('div', array('class' => 'tmonial-nav'));
            $content .= html_writer::start_tag('div', array('class' => 'testimonial-content'));
            $content .= html_writer::start_tag('div', array('class' => 'tmonial-button'));
            $content .= html_writer::link('javascript:void(0)', '<span aria-hidden="true"></span>', array('class' => 'prevBtn') );
            $content .= html_writer::link('javascript:void(0)', '<span aria-hidden="true"></span>', array('class' => 'nextBtn') );
            $content .= html_writer::end_tag('div');
            $content .= html_writer::start_tag('div', array('class' => 'tmonial-nav'));

            foreach ($numberRange as $key) {

                $data = $this->alluri_get_testimonial_contents($key);
                if (!empty($data['text'])) {
                    $content .= html_writer::start_tag('div', array('class' => 'card-img tmonial-li'));
                    $content .= html_writer::start_tag('div', array('class' => 'testimonial-img'));

                    $content .= html_writer::tag('div', '', array('class' => 'content-overlay'));
                    $timg = $OUTPUT->image_url('base/noimg-64x64', 'theme');
                    // $content .= html_writer::empty_tag('img', array('src' => $data['imgurl'],  'alt' => 'img-1' ));
                    $content .= html_writer::empty_tag('img', array('src' => $timg,  'alt' => 'img-1' ));
                    $content .= html_writer::end_tag('div'); // .card-img.

                    $content .= html_writer::end_tag('div'); // .card-img.
                    $num++;
                }
            }

            $content .= html_writer::end_tag('div');  // .col-md-3.
            // $content .= html_writer::end_tag('div');  // .row.
            // $content .= html_writer::end_tag('div');  // .row.

            $content .= html_writer::start_tag('div', array('class' => 'tmonial-slick '));
            // $content .= html_writer::start_tag('div', array('class' => 'row'));
            foreach ($numberRange as $value) {
                $data = $this->alluri_get_testimonial_contents($value);
                if (!empty($data['text'])) {
                    $content .= html_writer::start_tag('div', array('class' => 'card-block'));
                    $content .= html_writer::start_tag('div', array('class' => 'card-text'));
                    $content .= html_writer::tag('h2', theme_alluri_lang($data['uname']));
                    $content .= html_writer::tag('span', theme_alluri_lang($data['utype']));
                    $content .= html_writer::end_tag('div'); // .card-text.
                    $content .= html_writer::start_tag('div', array('class' => 'card-content'));
                    $content .= html_writer::tag('p', theme_alluri_lang($data['text']));
                    $content .= html_writer::end_tag('div');  // .card-content.
                    $content .= html_writer::end_tag('div');  // .card-content.
                }
            }
            // $content .= html_writer::end_tag('div');

            $content .= html_writer::end_tag('div');  // .tmonial-slick.

            $content .= html_writer::end_tag('div');  // .container.
            $content .= html_writer::end_tag('div');  // .testimonial-block.
        }
        if ($counttype == 'count') {
            return $num;
        } else {
            return $content;
        }
    }

    /**
     * Testimonials block contents from configurations.
     * @param type|Integer $key
     * @return type|array $data.
     */
    public function alluri_get_testimonial_contents($key) {
        global $CFG, $PAGE, $OUTPUT;
        $data = array();
        if (!empty($key)) {
            $data['text'] = theme_alluri_get_setting('tmonial'. $key .'text');
            $data['uname'] = theme_alluri_get_setting('tmonial'. $key .'uname');
            $data['utype'] = theme_alluri_get_setting('tmonial'. $key .'utype');
            $imgKey = 'tmonial'.$key.'img';
            $data['imgurl'] = $PAGE->theme->setting_file_url($imgKey, $imgKey);
            if (empty($data['imgurl'])) {
                $data['imgurl'] = $OUTPUT->image_url('no-user', 'theme');
            }
        }
        return $data;
    }

    public function alluri_check_video_type($url) {
        if (!empty($url)) {
            $urlcontent = parse_url($url);
            if (isset($urlcontent['host'])) {
                $host = $urlcontent['host'];
                if (strpos($host, 'youtube') > 0 ) {
                    return "YOUTUBE";
                } else if (strpos($host, 'vimeo') > 0) {
                    return "VIMEO";
                } else {
                    return 'HOST';
                }
            }
        }
        return "";
    }
}