<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * A one column layout for the alluri theme.
 *
 * @package   theme_alluri
 * @copyright 2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author    LMSACE Dev Team
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

// Get the HTML for the settings bits.
$html = theme_alluri_get_html_for_settings($OUTPUT, $PAGE);

user_preference_allow_ajax_update('drawer-open-nav', PARAM_ALPHA);
require_once($CFG->libdir . '/behat/lib.php');

if (isloggedin()) {
    $navdraweropen = (get_user_preferences('drawer-open-nav', 'true') == 'true');
} else {
    $navdraweropen = false;
}
$extraclasses = [];
if ($navdraweropen) {
    $extraclasses[] = 'drawer-open-left';
}
//$bodyattributes = $OUTPUT->body_attributes([]);
$bodyattributes = $OUTPUT->body_attributes($extraclasses);
$blockshtml = $OUTPUT->blocks('side-pre');
$hasblocks = strpos($blockshtml, 'data-block=') !== false;
$regionmainsettingsmenu = $OUTPUT->region_main_settings_menu();

$logo_url = alluri_get_logo_url();
$footerlogo = theme_alluri_get_setting('footerlogostatus');
$footnote = theme_alluri_get_setting('footnote', 'format_html');
$footnote = theme_alluri_lang($footnote);
$copyright = theme_alluri_get_setting('copyright', true);

$address = theme_alluri_get_setting('address');
$emailid = theme_alluri_get_setting('emailid');
$phoneno = theme_alluri_get_setting('phoneno');

$socialmedianame1 = theme_alluri_get_setting('socialmedianame1');
$socialmedianame2 = theme_alluri_get_setting('socialmedianame2');
$socialmedianame3 = theme_alluri_get_setting('socialmedianame3');
$socialmedianame4 = theme_alluri_get_setting('socialmedianame4');

$socialmediaurl1 = theme_alluri_get_setting('socialmediaurl1');
$socialmediaurl2 = theme_alluri_get_setting('socialmediaurl2');
$socialmediaurl3 = theme_alluri_get_setting('socialmediaurl3');
$socialmediaurl4 = theme_alluri_get_setting('socialmediaurl4');

$logoutpage = new moodle_url('/login/logout.php', array('sesskey' => sesskey(), 'alt' => 'logout'));
$profilepage = new moodle_url('/user/edit.php',array('id' => $USER->id));
$signuppage = new moodle_url("/login/signup.php");
$loginpage = new moodle_url("/login/index.php");

$authcheck = (($CFG->registerauth == 'email') || !empty($CFG->registerauth)) ? 1 : 0;
$logincheck = (isloggedin()) ? 1 : 0;

$connectstr = get_string('connectus','theme_alluri');
$contactstr = get_string('contact', 'theme_alluri');

$emailstr = get_string('emailid', 'theme_alluri');
$phonestr = get_string('phone');

$aboutstr = get_string('aboutus','theme_alluri');
$editmyprofilestr = get_string('editmyprofile');
$signupstr = get_string('signup','theme_alluri');
$sitenewsstr = get_string('sitenews');
$logoutstr = get_string('logout');
$loginstr = get_string('login');
$home = get_string('home');

//echo (!empty($flatnavbar)) ? $flatnavbar : "";

$templatecontext = [
    'sitename' => format_string($SITE->shortname, true, ['context' => context_course::instance(SITEID), "escape" => false]),
    'output' => $OUTPUT,
    'bodyattributes' => $bodyattributes,
    'sidepreblocks' => $blockshtml,
    'hasblocks' => $hasblocks,
    'navdraweropen' => $navdraweropen,
    'regionmainsettingsmenu' => $regionmainsettingsmenu,
    'hasregionmainsettingsmenu' => !empty($regionmainsettingsmenu),

    'logo' => $logo_url,
    'footerlogo' => $footerlogo,
    'footnote' => $footnote,
    'address' => $address,
    'phoneno' => $phoneno,
    'emailid' => $emailid,

    'socialmedianame1' => $socialmedianame1,
    'socialmedianame2' => $socialmedianame2,
    'socialmedianame3' => $socialmedianame3,
    'socialmedianame4' => $socialmedianame4,

    'socialmediaurl1' => $socialmediaurl1,
    'socialmediaurl2' => $socialmediaurl2,
    'socialmediaurl3' => $socialmediaurl3,
    'socialmediaurl4' => $socialmediaurl4,

    'copyright' => $copyright,

    'phonestr' => $phonestr,
    'emailstr' => $emailstr,

    'editmyprofilestr' => $editmyprofilestr,
    'sitenewsstr' => $sitenewsstr,
    'contactstr' => $contactstr,
    'connectstr' => $connectstr,
    'signupstr' => $signupstr,
    'logoutstr' => $logoutstr,
    'loginstr' => $loginstr,
    'home' => $home,

    'profilepage' => $profilepage,
    'signuppage' => $signuppage,
    'logoutpage' => $logoutpage,
    'loginpage' => $loginpage,
];

$templatecontext['flatnavigation'] = $PAGE->flatnav;
$flatnavbar = $OUTPUT->render_from_template('theme_boost/nav-drawer', $templatecontext);
echo $OUTPUT->render_from_template('theme_alluri/columns1', $templatecontext);
