<?php
// This file is part of the custom Moodle Bootstrap theme
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * frontpage.php
 *
 * @package    theme_alluri
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

// Get the HTML for the settings bits.

global $OUTPUT, $PAGE;

$theme = theme_config::load('alluri');

$html = theme_alluri_get_html_for_settings($OUTPUT, $PAGE);

$hassidepre = $PAGE->blocks->region_has_content('side-pre', $OUTPUT);
$hassidepost = $PAGE->blocks->region_has_content('side-post', $OUTPUT);

$knownregionpre = $PAGE->blocks->is_known_region('side-pre');
$knownregionpost = $PAGE->blocks->is_known_region('side-post');

$regions = alluri_grid($hassidepre, $hassidepost);
$PAGE->set_popup_notification_allowed(false);
$PAGE->requires->js('/theme/alluri/javascript/bootstrap-carousel.js');
$PAGE->requires->js('/theme/alluri/javascript/bootstrap-transition.js');

echo $OUTPUT->doctype() ?>

<html <?php echo $OUTPUT->htmlattributes(); ?>>
<head>
    <title><?php echo $OUTPUT->page_title(); ?></title>
    <link rel="shortcut icon" href="<?php echo $OUTPUT->favicon(); ?>" />
    <?php echo $OUTPUT->standard_head_html(); ?>
    <meta name="viewport" content="width=device-width, initial-scale=1.0, minimal-ui">
</head>
<link href="<?php echo theme_url(); ?>/style/animate.css" rel="stylesheet" media="all">
<body <?php echo $OUTPUT->body_attributes(); ?>>

<?php echo $OUTPUT->standard_top_of_body_html(); ?>

<?php
require_once(dirname(__FILE__) . '/includes/header.php');
//require_once($CFG->libdir. '/coursecatlib.php');

$alluriblocks = new \theme_alluri\alluri_blocks;

$searchurl = new moodle_url('/course/search.php');
$viewcourse = new moodle_url('/course/index.php');
$courserenderer = $PAGE->get_renderer('core', 'course');

$context = context_system::instance();
$course_insights = $courserenderer->course_insights_home();

?>
<script type="text/javascript" src="<?php echo $CFG->wwwroot?>/theme/alluri/javascript/frontpage.js"></script>


<?php echo $alluriblocks->alluri_homebanner();?>
    <!--E.O.Banner-->

<div id="content">
<?php echo $courserenderer->featured_courses();?>
<!--E.O.Featured Courses-->
<?php echo $alluriblocks->sitefeatures();?>
<!--E.O.Site Features-->

<?php $pc = $courserenderer->popular_courses();
if(!empty($pc)) {
    //echo $pc;
}

?>

<!--E.O.Content-->

<div id="page" class="container">
<!-- <div id="page" class="container">-->
    <header id="page-header" class="clearfix">
        <div id="course-header">
            <?php echo $OUTPUT->course_header(); ?>
        </div>
    </header>

    <div id="page-content">
        <div id="region-main" class="<?php echo $regions['content']; ?>">
            <?php
            echo $OUTPUT->course_content_header();
            echo $OUTPUT->main_content();
            echo $OUTPUT->course_content_footer();
            ?>
        </div>

        <?php
        if ($knownregionpre) {
            echo $OUTPUT->blocks('side-pre', $regions['pre']);
        }
        if ($knownregionpost) {
            echo $OUTPUT->blocks('side-post', $regions['post']);
        }
        ?>
    </div>
</div>

<!--E.O.Popular Courses-->

<?php
$newseventblockstatus = theme_alluri_get_setting('newseventstatus');
if($newseventblockstatus != '') {
?>
    <div class="site-noticearea">
       <div class="content-overlay"></div>
        <div class="container">
            <?php echo theme_alluri_get_setting('newsblockcontent','format_html'); ?>
      </div>
    </div>
<?php } ?>
    <!--E.O.News & Events-->



    <?php //echo $OUTPUT->testimonials(); ?>
<?php echo $alluriblocks->testimonials();

 ?>
    <!--E.O.Testimonials-->


    <?php echo $alluriblocks->marketingspot();
    //echo $alluriblocks->theme_alluri_testimonials();?>
    <!--E.O.Marketingspot-->
</div>

<?php
if (right_to_left()) {
    $rtl = "true";
} else {
    $rtl = "false";
}

?>

<!-- Smooth scorll cdn for make scroll smooth. -->

<!-- <script src="https://cdnjs.cloudflare.com/ajax/libs/smoothscroll/1.4.0/SmoothScroll.min.js"></script>
 --><link rel="stylesheet" href="<?php echo theme_url() ; ?>/style/slick.css" />
<script src="<?php echo theme_url() ; ?>/javascript/slick.js"></script>
<script type="text/javascript" src="<?php echo theme_url(); ?>/javascript/jarallax.js"></script>

<?php
// echo (isset($flatnavbar)) ? $flatnavbar : "";
require_once(dirname(__FILE__) . '/includes/footer.php');
$sitefeaturesjarallax = theme_alluri_get_setting('sitefeaturejarallaxstatus');
$newseventsjarallax = theme_alluri_get_setting('newseventjarallax');
?>
<style type="text/css">
    .run-words {
        display:none;
    }
   /* .run-words.active {
        display: inline;
    }*/
</style>
<script>
jQuery(function($) {

var sitefeaturejar = "<?php echo $sitefeaturesjarallax; ?>";
if(sitefeaturejar == 1) {
    $('.site-features').jarallax();
}
var newseventsjarallax = "<?php echo $newseventsjarallax; ?>";
if(newseventsjarallax == 1) {
    $('.site-noticearea').jarallax();
}

    $(".featured_courses").slick({
        arrows:true ,
        rtl:<?php echo $rtl;?>,
        swipe:false,
        prevArrow:'#Featured-Courses .pagenav .slick-prev',
        nextArrow: '#Featured-Courses .pagenav .slick-next',
         slidesToShow: 4,
        slideToScroll: 4,
        responsive: [
            {
              breakpoint: 991,
              settings: {
                slidesToShow: 3,
                 slidesToScroll: 1,
                 centerMode: false,
              }
            },
            {
              breakpoint: 768,
              settings: {
                  slidesToShow: 1,
                  slidesToScroll: 1,
                  centerMode: false,
              }
            },
        ],
    });

    $(".availablecourses").slick({
        arrows:true ,
        rtl:<?php echo $rtl;?>,
        swipe:false,
        prevArrow:'#Available-Courses .pagenav .slick-prev',
        nextArrow: '#Available-Courses .pagenav .slick-next',
        slidesToShow: 4,
        slideToScroll: 4,
        responsive: [
            {
              breakpoint: 991,
              settings: {
                slidesToShow: 3,
                 slidesToScroll: 1,
                 centerMode: false,
              }
            },
            {
              breakpoint: 768,
              settings: {
                  slidesToShow: 1,
                  slidesToScroll: 1,
                  centerMode: false,
              }
            },
        ],
    });

    $(".mycourses").slick({
        arrows:true ,
        rtl:<?php echo $rtl;?>,
        swipe:false,
        prevArrow:'#My-Courses .pagenav .slick-prev',
        nextArrow: '#My-Courses .pagenav .slick-next',
        slidesToShow: 4,
        slideToScroll: 4,
        responsive: [
            {
              breakpoint: 991,
              settings: {
                slidesToShow: 3,
                 slidesToScroll: 1,
                 centerMode: false,
              }
            },
            {
              breakpoint: 768,
              settings: {
                  slidesToShow: 1,
                  slidesToScroll: 1,
                  centerMode: false,
              }
            },
        ],
    });
        var case3 = [{
              breakpoint: 1000,
              settings: {
              slidesToShow: 1,
              slidesToScroll: 1,
                  centerMode: false,
              }
          },
          {
              breakpoint: 600,
              settings: {
                  slidesToShow: 1,
                  slidesToScroll: 1,
                  centerMode: false,
              }
          }];
          var case2 = [{
              breakpoint: 1000,
              settings: {
                  slidesToShow: 1,
                  slidesToScroll: 1,
                  centerMode: false,
              }
          },
          {
              breakpoint: 600,
              settings: {
                  slidesToShow: 1,
                  slidesToScroll: 1,
                  centerMode: false,
              }
          }];
          var case1 = [{
              breakpoint: 1000,
              settings: {
                slidesToShow: 1,
                 slidesToScroll: 1,
                 centerMode: false,
              }
          },
          {
              breakpoint: 600,
              settings: {
                  slidesToShow: 1,
                  slidesToScroll: 1,
                  centerMode: false,
              }
          }];

    var frow = $(".featured_courses").attr("data-crow");
    frow = parseInt(frow);
    if (frow < 2) {
        $("#Featured-Courses .pagenav").hide();
    }

    var prow = $(".popular_courses").attr("data-crow");
    prow = parseInt(prow);

    if (prow < 2) {
        $("#Popular-Courses .pagenav").hide();
    }
    $("#testimonials-carousel .carousel-inner").slick({
        interval: 3000 ,
        arrows:true,
        slidesToShow: 1,
        prevArrow:'#testimonials-carousel .carousel-control-prev',
        nextArrow: '#testimonials-carousel .carousel-control-next',
         rtl:<?php echo $rtl;?>
    });
});

$(window).on('load', function() {
    $('[data-animation ^= "animated"]').each( function() {
        $this = $(this);
        doAnimations($this);
    })
})
 function doAnimations(elems, anim='') {
    var animEndEv = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';
    elems.each(function () {
            if (!anim)
                $animationType = $(this).data('animation');
            else
                $animationType = anim;
        var $this = $(this), $animationType

            $this.show();
        // Check End of Animation and Clear the class from slide.
        $this.addClass($animationType).one(animEndEv, function () {
            $this.removeClass($animationType);
        });
    });
}
</script>

<script type="text/javascript" src="<?php echo $CFG->wwwroot;?>/lib/jquery/jquery-3.5.1.js"></script>

<script src="<?php echo $CFG->wwwroot;?>/theme/alluri/javascript/jquery.mb.YTPlayer.js"></script>
<link rel="stylesheet" type="text/css" media="all" href="<?=$CFG->wwwroot;?>/theme/alluri/style/jquery.mb.YTPlayer.min.css">
<script>

   (function($) {
        $(window).on('load', function() {
           if ( $('.banner').hasClass('youtube-player') ) {
                $("#bgndvideo").YTPlayer(); // Youtube player
          }
     })
    })(jQuery);
</script>
