<?php
// This file is part of the custom Moodle Bootstrap theme
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * settings.php
 *
 * @package    theme_alluri
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @author    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die;

$settings = null;

if (is_siteadmin()) {

    $settings = new theme_boost_admin_settingspage_tabs('themesettingalluri', get_string('configtitle', 'theme_alluri'));
    $ADMIN->add('themes', new admin_category('theme_alluri', 'Alluri'));

    /*General settings*/
    $temp = new admin_settingpage('theme_alluri_general', get_string('generalheading', 'theme_alluri'));

    // Custom CSS file.
    $name = 'theme_alluri/customcss';
    $title = get_string('customcss', 'theme_alluri');
    $description = '';
    $default = '';
    $setting = new admin_setting_configtextarea($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    $settings->add($temp);

    /* Header Settings */
    $temp = new admin_settingpage('theme_alluri_header', get_string('headerheading', 'theme_alluri'));

    // Logo file setting.
    $name = 'theme_alluri/logo';
    $title = get_string('logo', 'theme_alluri');
    $description = get_string('logodesc', 'theme_alluri');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'logo');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    $settings->add($temp);

    $temp = new admin_settingpage('theme_alluri_footer', get_string('footerheading', 'theme_alluri'));

    // Footer logo enable/disable.
    $name = 'theme_alluri/footerlogostatus';
    $title = get_string('footerlogo', 'theme_alluri');
    $description = get_string('footerlogodesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Footer background file.
    $name = 'theme_alluri/footbgimg';
    $title = get_string('footbgimg', 'theme_alluri');
    $description = get_string('footbgimgdesc', 'theme_alluri');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'footbgimg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    /* Footer Content */
    $name = 'theme_alluri/footnote';
    $title = get_string('footnote', 'theme_alluri');
    $description = get_string('footnotedesc', 'theme_alluri');
    // $default = get_string('footnotedefault', 'theme_alluri');
    $default = 'lang:footnote_default';
    $setting = new admin_setting_confightmleditor($name, $title, $description, $default);
    // $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    $name = 'theme_alluri/footmenu';
    $title = get_string('footmenu', 'theme_alluri');
    $description = get_string('footnotedesc', 'theme_alluri');
    // $default = get_string('footnotedefault', 'theme_alluri');
    $default = 'lang:footmenu_default';
    $setting = new admin_setting_confightmleditor($name, $title, $description, $default);
    // $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    /* Address , Email , Phone No */
    $name = 'theme_alluri/address';
    $title = get_string('address', 'theme_alluri');
    $description = '';
    $default = get_string('defaultaddress', 'theme_alluri');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    $name = 'theme_alluri/emailid';
    $title = get_string('emailid', 'theme_alluri');
    $description = '';
    $default = get_string('defaultemailid', 'theme_alluri');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    $name = 'theme_alluri/phoneno';
    $title = get_string('phoneno', 'theme_alluri');
    $description = '';
    $default = get_string('defaultphoneno', 'theme_alluri');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    /* Facebook,Pinterest,Twitter,Google+ Settings */
    $socialnames = array(1 => 'fburl', 2 => 'pinurl', 3 => 'twurl', 4 => 'gpurl');
    for ($i = 1; $i <= 4; $i++) {

        $name = 'theme_alluri/socialmedianame'.$i;
        $title = get_string('socialicontitle', 'theme_alluri');
        $description = get_string('socialicondesc', 'theme_alluri');
        $default = get_string($socialnames[$i].'icon_default', 'theme_alluri');
        $setting = new admin_setting_configtext($name, $title, $description, $default);
        $temp->add($setting);

        $name = 'theme_alluri/socialmediaurl'.$i;
        $title = get_string('socialmediaurltitle', 'theme_alluri');
        $description = get_string($socialnames[$i].'desc', 'theme_alluri');
        $default = get_string($socialnames[$i].'_default', 'theme_alluri');
        $setting = new admin_setting_configtext($name, $title, $description, $default);
        $temp->add($setting);
    }

    // Copyright setting.
    $name = 'theme_alluri/copyright';
    $title = get_string('copyright', 'theme_alluri');
    $description = get_string('copyrightdesc', 'theme_alluri');
    $default = get_string('copyright_default', 'theme_alluri');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);
    $settings->add($temp);
    /*  Footer Settings end */

    /* Front Page Settings */
    $temp = new admin_settingpage('theme_alluri_frontpage', get_string('frontpageheading', 'theme_alluri'));


    $name = 'theme_alluri_homebannertitle';
    $heading = get_string('homebannertitle', 'theme_alluri');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);


    /*Banner settings*/
    // Enable & disable banner block.
    $name = 'theme_alluri/homebannerstatus';
    $title = get_string('bannerstatus', 'theme_alluri');
    $description = get_string('bannerstatusdesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Enable & disable banner search box.
    $name = 'theme_alluri/searchbarstatus';
    $title = get_string('searchboxstatus', 'theme_alluri');
    $description = get_string('searchboxdesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    $name = 'theme_alluri/bannersitestatus';
    $title = get_string('bannersitestatus', 'theme_alluri');
    $description = get_string('bannersitestatusdesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);


    // Banner height.
    $name = 'theme_alluri/bannerheight';
    $title = get_string('bannerheighttitle', 'theme_alluri');
    $description = get_string('bannerheightdesc', 'theme_alluri');
    $default = '600';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Banner video type.
    $name = 'theme_alluri/bannervideotype';
    $title = get_string('bannertypetitle', 'theme_alluri');
    $description = get_string('bannertypedesc', 'theme_alluri');
    $default = 2;
    $choice = array(
            '1' => get_string('banneryoutube', 'theme_alluri'),
            '2' => get_string('bannerhosted', 'theme_alluri'),
            '3' => get_string('bannerimagebanner', 'theme_alluri'),
        );
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choice);
    $temp->add($setting);

    // Video URL.
    $name = 'theme_alluri/bannervideourl';
    $title = get_string('bannervideourl', 'theme_alluri');
    $description = get_string('bannervideourldesc', 'theme_alluri');
    $default = 'http://res.cloudinary.com/lmsace/video/upload/v1502450231/Children.mp4';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    // Banner image upload block.
    $name = 'theme_alluri/homebanner';
    $title = get_string('homebanner', 'theme_alluri');
    $description = get_string('homebannerdesc', 'theme_alluri');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'homebanner');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Banner video poster image.
    $name = 'theme_alluri/bannerposter';
    $title = get_string('al_bannerposter', 'theme_alluri');
    $description = get_string('al_bannerposterdesc', 'theme_alluri');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'bannerposter');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    // Banner content block.
    $name = 'theme_alluri/homebannercontent';
    $title = get_string('bannercontent', 'theme_alluri');
    $description = get_string('homebannercontentdesc', 'theme_alluri');
    $default = 'lang:banner_default';
    $setting = new admin_setting_configtextarea($name, $title, $description, $default);
    // $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    $name = 'theme_alluri/fcoursestitle';
    $title = get_string('fcoursestitle', 'theme_alluri');
    $description = get_string('fcoursestitledesc', 'theme_alluri');
    $default = '';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    /* Featured courses block. */
    $name = 'theme_alluri/featured_courses';
    $title = get_string('fcourses', 'theme_alluri');
    $description = get_string('fcoursesdesc', 'theme_alluri');
    $default = '';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);


    $name = 'theme_alluri/acoursestitle';
    $title = get_string('acoursestitle', 'theme_alluri');
    $description = get_string('acoursestitledesc', 'theme_alluri');
    $default = 'lang:available_courses';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    $name = 'theme_alluri/ecoursestitle';
    $title = get_string('ecoursestitle', 'theme_alluri');
    $description = get_string('ecoursestitledesc', 'theme_alluri');
    $default = 'lang:enrolled_courses';
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    /* Featured Courses
    $name = 'theme_alluri/featured_courses';
    $title = get_string('fcourses', 'theme_alluri');
    $description = get_string('fcoursesdesc', 'theme_alluri');
    $default = array();
    $courses[0] = '';
    $cnt = 0;
    if ($ccc = get_courses('all', 'c.sortorder ASC', 'c.id,c.shortname,c.visible')) {
        foreach ($ccc as $cc) {
            if($cc->visible=="0" || $cc->id=="1") {
                continue;
            }
            $cnt++;
            $courses[$cc->id] = $cc->shortname;
            // set some courses for default option
            if( $cnt < 7 ) {
                $default[] = $cc->id;
            }
        }
    }
    $setting = new admin_setting_configmultiselect($name, $title, $description, $default, $courses);
    //$setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);*/

    /* News and Events */
    $name = 'theme_alluri_newsblocksheading';
    $heading = get_string('newsblockheading', 'theme_alluri');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);


    // News and events block enable/disable.
    $name = 'theme_alluri/newseventstatus';
    $title = get_string('newseventstatustitle', 'theme_alluri');
    $description = get_string('newseventstatusdesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // News and events jarallax enable/disable.
    $name = 'theme_alluri/newseventjarallax';
    $title = get_string('newseventjarallaxtitle', 'theme_alluri');
    $description = get_string('newseventjarallaxdesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    /* News Events BG Image file setting. */
    $name = 'theme_alluri/newseventbg';
    $title = get_string('newseventbg', 'theme_alluri');
    $description = get_string('newseventbgdesc', 'theme_alluri');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'newseventbg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    /* News and Events Block Content */
    $name = 'theme_alluri/newsblockcontent';
    $title = get_string('newsblockcontent', 'theme_alluri');
    $description = get_string('newsblockcontentdesc', 'theme_alluri');
    $default = get_string('newseventcontent', 'theme_alluri');
    $setting = new admin_setting_confightmleditor($name, $title, $description, $default);
    // $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);
    $settings->add($temp);


    //counter

    $temp = new admin_settingpage('theme_alluri_counter', get_string('countertabheading', 'theme_alluri'));


    // Counter block heading.
    $name = 'theme_alluri_countBlockheading';
    $heading = get_string('countBlockSetting', 'theme_alluri');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    $name = 'theme_alluri/counttype';
    $title = get_string('counttypestaus', 'theme_alluri');
    $description = '';
    $default = 'default';
    $options =  array(
                        'custom' => get_string('custom', 'theme_alluri'),
                        'default' => get_string('default', 'theme_alluri'),
                );
    $setting = new admin_setting_configselect($name, $title, $description, $default,$options);
    $temp->add($setting);



    for ($i = 1; $i <= 3; $i++) {
        // Counter inner block heading.
        $name = 'theme_alluri/countBlock'.$i;
        $heading = get_string('countBlock', 'theme_alluri', array('num' => $i));
        $information = '';
        $setting = new admin_setting_heading($name, $heading, $information);
        $temp->add($setting);

        // Counter block value.
        $name = 'theme_alluri/countBlockValue'.$i;
        $title = get_string('countBlockValue', 'theme_alluri', array('num' => $i));
        $description = get_string('countBlockValue_desc', 'theme_alluri', array('num' => $i));
        $default = "50";
        $setting = new admin_setting_configtext($name, $title, $description, $default);
        $temp->add($setting);

        // Counter block Content.
        $name = 'theme_alluri/countBlockContent'.$i;
        $title = get_string('countBlockContent', 'theme_alluri', array('num' => $i));
        $description = get_string('countBlockContent_desc', 'theme_alluri', array('num' => $i));
        $default = 'lang:countBlockContent';
        $setting = new admin_setting_confightmleditor($name, $title, $description, $default);
        $temp->add($setting);
    }
    $settings->add($temp);




    /* Site Feature Blocks Settings */
    $temp = new admin_settingpage('theme_alluri_sitefeatures', get_string('frontpage_sitefeatures', 'theme_alluri'));

    /* Site Feature Blocks Settings */
    $name = 'theme_alluri_sitefeaturesheading';
    $heading = get_string('sitefblocksheading', 'theme_alluri');
    $information = '';
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Site feature block enable/disable.
    $name = 'theme_alluri/sitefeaturestatus';
    $title = get_string('sitefeaturestatustitle', 'theme_alluri');
    $description = get_string('sitefeaturestatusdesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    // Site feature jarallax enable/disable.
    $name = 'theme_alluri/sitefeaturejarallaxstatus';
    $title = get_string('sitefeaturejarallaxtitle', 'theme_alluri');
    $description = get_string('sitefeaturejarallaxdesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    /* Site Features BG Image file setting */
    $name = 'theme_alluri/sitefeaturebg';
    $title = get_string('sitefeaturebg', 'theme_alluri');
    $description = get_string('sitefeaturebgdesc', 'theme_alluri');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'sitefeaturebg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);

    for ($i = 1; $i <= 3; $i++) {
        // Heading.
        $name = 'theme_alluri_sitefblock'.$i.'heading';
        $heading = get_string('sitefblock'.$i, 'theme_alluri');
        $information = '';
        $setting = new admin_setting_heading($name, $heading, $information);
        $temp->add($setting);

        // Status.
        $name = 'theme_alluri/sitefeatureblock'.$i.'status';
        $title = get_string('sitefeatureblockstatustitle', 'theme_alluri');
        $description = get_string('sitefeatureblockstatusdesc', 'theme_alluri');;
        $default = 1;
        $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
        $temp->add($setting);

        // Image.
        $name = 'theme_alluri/sitefblock'.$i.'image';
        $title = get_string('sitefblockimage', 'theme_alluri');
        $description = get_string('sitefblockimagedesc', 'theme_alluri');
        $setting = new admin_setting_configstoredfile($name, $title, $description, 'sitefblock'.$i.'image');
        $setting->set_updatedcallback('theme_reset_all_caches');
        $temp->add($setting);

        // Bgcolor.
        $name = 'theme_alluri/sitefblock'.$i.'bgcolor';
        $title = get_string('sitefblockimgcolors', 'theme_alluri');
        $description = get_string('sitefblockimgcolorsdesc', 'theme_alluri');
        $default = '#78adc9';
        $previewconfig = null;
        $setting = new admin_setting_configcolourpicker($name, $title, $description, $default, $previewconfig);
        $setting->set_updatedcallback('theme_reset_all_caches');
        $temp->add($setting);

        // Title.
        $name = 'theme_alluri/sitefblock'.$i.'title';
        $title = get_string('sitefblocktitle', 'theme_alluri');
        $description = get_string('sitefblocktitledesc', 'theme_alluri');
        $default = get_string('sb1_default_title', 'theme_alluri');
        $setting = new admin_setting_configtext($name, $title, $description, $default);
        $temp->add($setting);

        // Content.
        $name = 'theme_alluri/sitefblock'.$i.'content';
        $title = get_string('sitefblockcontent', 'theme_alluri');
        $description = get_string('sitefblockcontentdesc', 'theme_alluri');
        // $default = get_string('sb_default','theme_alluri');
        $default = 'lang:sb_default';
        $setting = new admin_setting_confightmleditor($name, $title, $description, $default);
        $temp->add($setting);

        // Buttontext.
        $name = 'theme_alluri/sitefblock'.$i.'buttontext';
        $title = get_string('sitefblockbuttontext', 'theme_alluri');
        $description = get_string('sitefblockbuttontextdesc', 'theme_alluri');
        $default = get_string('readmore', 'theme_alluri');
        $setting = new admin_setting_configtext($name, $title, $description, $default);
        $temp->add($setting);

        // Buttonurl.
        $name = 'theme_alluri/sitefblock'.$i.'buttonurl';
        $title = get_string('sitefblockbuttonurl', 'theme_alluri');
        $description = get_string('sitefblockbuttonurldesc', 'theme_alluri');
        $default = 'http://www.lmsace.com/';
        $setting = new admin_setting_configtext($name, $title, $description, '', PARAM_URL);
        $temp->add($setting);

        /* First Block Link Target */
        $name = 'theme_alluri/sitefblock'.$i.'target';
        $title = get_string('sitefblockurltarget', 'theme_alluri');
        $description = get_string('sitefblockurltargetdesc', 'theme_alluri');
        $target1 = get_string('sitefblockurltargetself', 'theme_alluri');
        $target2 = get_string('sitefblockurltargetnew', 'theme_alluri');
        $target3 = get_string('sitefblockurltargetparent', 'theme_alluri');
        $default = '_blank';
        $choices = array('_self' => $target1, '_blank' => $target2, '_parent' => $target3);
        $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
        $temp->add($setting);
    }
    $settings->add($temp);
    /* Site Feature Blocks End */
    /* Front Page Settings */

    /* Testimonial Settings */
    $temp = new admin_settingpage('theme_alluri_tmonialhead', get_string('tmonialheading', 'theme_alluri'));

    // Site feature block enable/disable.
    $name = 'theme_alluri/testimonialstatus';
    $title = get_string('testimonialstatustitle', 'theme_alluri');
    $description = get_string('testimonialstatusdesc', 'theme_alluri');;
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    $name = 'theme_alluri/tmonialTitle';
    $title = get_string('tmonialblkTitle', 'theme_alluri');
    $description = get_string('tmonialblkTitledesc', 'theme_alluri');
    $default = get_string('tmonialblkTitle_default', 'theme_alluri');
    $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
    $temp->add($setting);

    $name = 'theme_alluri/numberoftmonials';
    $title = get_string('numberoftmonials', 'theme_alluri');
    $description = get_string('numberoftmonials_desc', 'theme_alluri');
    $default = 4;
    $choices = array(
        1 => '1',
        2 => '2',
        3 => '3',
        4 => '4',
        5 => '5',
        6 => '6',
        7 => '7',
        8 => '8',
        9 => '9',
        10 => '10',
        11 => '11',
        12 => '12',
        13 => '13',
        14 => '14',
        15 => '15',
        16 => '16'
    );
    $temp->add(new admin_setting_configselect($name, $title, $description, $default, $choices));

    $numberoftmonials = get_config('theme_alluri', 'numberoftmonials');
    for ($i = 1; $i <= $numberoftmonials; $i++) {

        // Testimonial Heading.
        $name = 'theme_alluri/testimonialno' . $i . 'info';
        $heading = get_string('testimonialno', 'theme_alluri', array('tmonial' => $i));
        $information = get_string('testimonialnodesc', 'theme_alluri', array('tmonial' => $i));
        $setting = new admin_setting_heading($name, $heading, $information);
        $temp->add($setting);

        // User Name.
        $name = 'theme_alluri/tmonial' . $i . 'uname';
        $title = get_string('tmonialuname', 'theme_alluri');
        $description = get_string('tmonialunamedesc', 'theme_alluri');
        $default = ($i == 1) ? get_string('tmonialuname_default', 'theme_alluri') : '';
        $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

        // User Type.
        $name = 'theme_alluri/tmonial' . $i . 'utype';
        $title = get_string('tmonialutype', 'theme_alluri');
        $description = get_string('tmonialutypedesc', 'theme_alluri');
        $default = ($i == 1) ? get_string('tmonialutype_default','theme_alluri') : '';
        $choices1 = array(
                        'student' => get_string('student', 'theme_alluri'),
                        'teacher' => get_string('teacher', 'theme_alluri'),
         );
        $temp->add(new admin_setting_configselect($name, $title, $description, $default, $choices1));

        // Testimonial text.
        $name = 'theme_alluri/tmonial' . $i . 'text';
        $title = get_string('tmonialtext', 'theme_alluri');
        $description = get_string('tmonialtextdesc', 'theme_alluri');
        // $default = ($i == 1) ? get_string('tmonialtext_default','theme_alluri') : '';
        $default = 'lang:tmonialtext_default';
        $setting = new admin_setting_configtextarea($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

        // Testimonial image.
        $name = 'theme_alluri/tmonial'.$i.'img';
        $title = get_string('tmonialimg', 'theme_alluri');
        $description = get_string('tmonialimgdesc', 'theme_alluri');
        $default = 'tmonial'.$i.'img';
        $setting = new admin_setting_configstoredfile($name, $title, $description, $default);
        $setting->set_updatedcallback('theme_reset_all_caches');
        $temp->add($setting);


    }
    $settings->add($temp);

    /* Testimonial End */

    /* Marketing spot starts*/
    $temp = new admin_settingpage('theme_alluri_marketingspot', get_string('marketingspot', 'theme_alluri'));

        // Marketingspot status.
        $name = 'theme_alluri/marketingspotstatus';
        $title = get_string('marketingspottitle', 'theme_alluri');
        $description = get_string('marketingspotdesc', 'theme_alluri');;
        $default = 1;
        $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
        $temp->add($setting);

        // Marketingspot content.
        $name = 'theme_alluri/marketingspotcontent';
        $title = get_string('marketingspotcontenttitle', 'theme_alluri');
        $description = '';
        $default = 'lang:marketingspotcontent_default';
        $setting = new admin_setting_confightmleditor($name, $title, $description, $default);
        $temp->add($setting);

        // Marketingspot button title.
        $name = 'theme_alluri/marketingspotbutton';
        $title = get_string('marketingspotbuttontitle', 'theme_alluri');
        $description = '';
        $default = get_string('marketingspotbuttondefault', 'theme_alluri');
        $setting = new admin_setting_configtext($name, $title, $description, $default);
        $temp->add($setting);

        // Marketingspot button url.
        $name = 'theme_alluri/marketingspotbuttonurl';
        $title = get_string('marketingspotbuttontitleurl', 'theme_alluri');
        $description = get_string('marketingspotbuttondescurl', 'theme_alluri');
        $default = 'http://example.com/';
        $setting = new admin_setting_configtext($name, $title, $description, $default);
        $temp->add($setting);
        $settings->add($temp);

    /*Marketing spot ends*/

}
