define("theme_boost_union/smartmenu", ["exports"], function (_exports) {
   Object.defineProperty(_exports, "__esModule", { value: !0 }), (_exports.init = void 0);
   /**
    * Theme Boost Union - JS for smartmenu to make the third level submenu support.
    *
    * @module     theme_boost_union/smartmenu
    * @copyright  bdecent GmbH 2023
    * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
    */
   const hideSubmenus = (target) => {
       var visibleMenu = document.querySelectorAll("nav.moremenu .dropdown-submenu.show");
       null !== visibleMenu &&
           visibleMenu.forEach((el) => {
               el != target && el.classList.remove("show");
           });
   };

   /**
     * Move a node out of the "more" dropdown menu. Modified version of core\moremenu.js
     *
     * This method forces a given node from the "more" dropdown menu to be displayed in the main section of the menu.
     *
     * @param {HTMLElement} menu The navbar moremenu.
     * @param {HTMLElement} navNode The navigation node.
     */
    const moveOutOfMoreDropdown = (menu, navNode) => {
        const moreButton = menu.querySelector(Selectors.regions.morebutton);
        const dropdownToggle = menu.querySelector(Selectors.attributes.dropdowntoggle);
        const navLink = navNode.querySelector('.' + Selectors.classes.dropdownitem);

        // If the more menu is rendered as a tab list,
        // this will become a tab instead of a menuitem when moved out of the more menu dropdown.
        if (isTabListMenu) {
            navLink.setAttribute('role', 'tab');
        }

        // Stop displaying the active state on the dropdownToggle if
        // the active navlink is removed.
        if (navLink.classList.contains(Selectors.classes.active)) {
            dropdownToggle.classList.remove(Selectors.classes.active);
            dropdownToggle.setAttribute('tabindex', '-1');
            navLink.setAttribute('tabindex', '0');
            if (isTabListMenu) {
                // Replace aria selection state when necessary.
                navLink.removeAttribute('aria-current');
                navLink.setAttribute('aria-selected', 'true');
            }
        }
        navLink.classList.remove(Selectors.classes.dropdownitem);
        navLink.classList.add(Selectors.classes.navlink);
        menu.insertBefore(navNode, moreButton);
    };

    /**
     * Auto Collapse navigation items that wrap into a dropdown menu.
     *
     * @param {HTMLElement} menu The navbar container.
     */
    const autoCollapse = () => {
        var menus = document.querySelectorAll('.nav.more-nav');
        menu.forEach((menu) => {
            var menuid = menu.id;
            var outitems = menu.querySelectorAll('.force-menu-out');
            if (outitems !== null) {

            }
        });
    };

   _exports.init = () => {
       var submenu;
       var helpIcon = document.querySelectorAll('.moremenu .dropdown .menu-helpicon a');
        if (helpIcon !== null) {
            helpIcon.forEach((icon) => {
                icon.addEventListener('click', (e) => {
                e.stopPropagation();
                });
            });
        }

        // When the screen size changes make sure the menu still fits.
        window.addEventListener('resize', () => {
            autoCollapse();
            // menu_navigation(menu);
        });

       null !== (submenu = document.querySelectorAll("nav.moremenu .dropdown-submenu")) &&
           submenu.forEach((item) => {
               item.addEventListener("click", (e) => {
                   var target = e.currentTarget;
                   hideSubmenus(target), target.classList.toggle("show"), e.stopPropagation();
               });

           }),

           (() => {
               var cards = document.querySelectorAll(".card-dropdown.card-overflow-no-wrap");
               if (null !== cards) {
                   var scrollStart, scrollMoved;
                   let startPos, scrollPos;
                   cards.forEach((card) => {
                       var scrollElement = card.querySelector(".dropdown-menu");
                       scrollElement.addEventListener("mousedown", (e) => {
                           scrollStart = !0;
                           var target = e.currentTarget.querySelector(".card-block-wrapper");
                           (startPos = e.pageX), (scrollPos = target.scrollLeft);
                       }),
                           scrollElement.addEventListener("mousemove", (e) => {
                               if ((e.preventDefault(), !scrollStart)) return;
                               scrollMoved = !0;
                               var target = e.currentTarget.querySelector(".card-block-wrapper");
                               const scroll = e.pageX - startPos;
                               target.scrollLeft = scrollPos - scroll;
                           }),
                           scrollElement.addEventListener("click", (e) => {
                               scrollMoved && (e.preventDefault(), (scrollMoved = !1)), e.stopPropagation();
                           }),
                           scrollElement.addEventListener("mouseleave", () => {
                               (scrollStart = !1), (scrollMoved = !1);
                           }),
                           scrollElement.addEventListener("mouseup", () => {
                               scrollStart = !1;
                           });
                   });
               }
           })();
   };
});

//# sourceMappingURL=smartmenu.min.js.map
