<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * This file contains the submission form used by the assign module.
 *
 * @package   mod_assign
 * @copyright 2012 NetSpot {@link http://www.netspot.com.au}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


namespace theme_educli\form;

defined('MOODLE_INTERNAL') || die('Direct access to this script is forbidden.');


require_once($CFG->libdir . '/formslib.php');
require_once($CFG->dirroot . '/mod/assign/locallib.php');

/**
 * Assign submission form
 *
 * @package   mod_assign
 * @copyright 2012 NetSpot {@link http://www.netspot.com.au}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class submission_form extends \moodleform {

    /**
     * Define this form - called by the parent constructor
     */
    public function definition() {
        global $USER, $PAGE;
        $mform = $this->_form;
        list($assign, $data) = $this->_customdata;
        $instance = $assign->get_instance();
        $submissionplugins = $assign->get_submission_plugins();
        $asessmenttypes = [];

        foreach ($submissionplugins as $plugin) {
            if ($plugin->is_enabled() && $plugin->is_visible() && $plugin->allow_submissions()) {
                if ($plugin instanceof \assign_submission_onlinetext) {
                    $asessmenttypes['onlinetext'] = $plugin->get_name();
                } else if ($plugin instanceof \assign_submission_file) {
                    $asessmenttypes['filetype'] = $plugin->get_name();
                }
            }
        }

        if ($instance->teamsubmission) {
            $submission = $assign->get_group_submission($data->userid, 0, true);
        } else {
            $submission = $assign->get_user_submission($data->userid, true);
        }
        if ($submission) {
            $mform->addElement('hidden', 'lastmodified', $submission->timemodified);
            $mform->setType('lastmodified', PARAM_INT);
        }

        $mform->addElement('text', 'asessment', 'Asessment', array('size' => 40, 'disabled' => true));
        $mform->setType('asessment', PARAM_TEXT);
        $mform->setDefault('asessment', $instance->name);

        $mform->addElement('text', 'asessmentdate', 'AsessmentDate', array('size' => 40, 'disabled' => true));
        $mform->setType('asessmentdate', PARAM_TEXT);
        $mform->setDefault('asessmentdate', userdate($instance->allowsubmissionsfromdate,
            '%d/%m/%Y,%I:%M %p', '', false));

        $mform->addElement('select', 'asessmenttype', 'Type', $asessmenttypes);
        $mform->setType('asessmenttype', PARAM_TEXT);

        $assign->add_submission_form_elements($mform, $data);

        $mform->hideIf('files_filemanager', 'asessmenttype', 'eq', 'onlinetext');
        $PAGE->requires->js_init_code('
            require([], function() {
                document.querySelector("select#id_asessmenttype").addEventListener("change", function() {
                    if (this.value != "onlinetext") {
                        document.querySelector("#fitem_id_onlinetext_editor").style.display = "none";
                    } else {
                        document.querySelector("#fitem_id_onlinetext_editor").style.display = "flex";
                    }
                });
            })
        ');

        $mform->addElement('hidden', 'action', 'view');

        $this->add_action_buttons(false, get_string('savechanges', 'assign'));
        if ($data) {
            $this->set_data($data);
        }
    }
}

