<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Edit user profile form.
 *
 * @package    theme_educli
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @authors    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
 require_once($CFG->libdir.'/formslib.php');
 require_once($CFG->dirroot.'/user/editadvanced_form.php');
 require_once($CFG->dirroot.'/user/editlib.php');

class user_profile  {

    /**
     * Remove form elements from edit user profile form.
     */
    public static function removeElements() {
        $elements = [
            'suspended',
            'passwordpolicyinfo',
            'maildisplay',
            'moodlenetprofile',
            'city',
            'timezone',
            'description_editor',
            'moodle_picture',
            'imagealt',
            'moodle_additional_names',
            'firstnamephonetic',
            'lastnamephonetic',
            'middlename',
            'alternatename',
            'moodle_interests',
            'interests',
            'moodle_optional',
            'idnumber',
            'institution',
            'department',
            'phone2',
            'address',
        ];
        return $elements;
    }

    /**
     * Get a user profile update form.
     * @return $userform user profile form.
     */
    public static function user_profile_form() {
        global $CFG, $PAGE, $DB, $USER;
        $id     = optional_param('id', $USER->id, PARAM_INT);    // User id; -1 if creating new user.
        $user = $DB->get_record('user', array('id' => $id), '*', MUST_EXIST);
        $usercontext = context_user::instance($user->id);
        $editoroptions = array(
            'maxfiles'   => EDITOR_UNLIMITED_FILES,
            'maxbytes'   => $CFG->maxbytes,
            'trusttext'  => false,
            'forcehttps' => false,
            'context'    => $usercontext
        );
        $user = file_prepare_standard_editor($user, 'description', $editoroptions, $usercontext, 'user', 'profile', 0);
        // Prepare filemanager draft area.
        $draftitemid = 0;
        $filemanagercontext = context_system::instance();
        $filemanageroptions = array('maxbytes'       => $CFG->maxbytes,
                                    'subdirs'        => 0,
                                    'maxfiles'       => 1,
                                    'accepted_types' => 'optimised_image');
        file_prepare_draft_area($draftitemid, $filemanagercontext->id, 'user', 'newicon', 0, $filemanageroptions);
        $user->imagefile = $draftitemid;
        // Create form.
        $actionurl = new moodle_url('/user/editadvanced.php', ['id' => $USER->id]);
        $userform = new user_editadvanced_form(new moodle_url($actionurl, array('returnto' => 'profile')), array(
            'editoroptions' => $editoroptions,
            'filemanageroptions' => $filemanageroptions,
            'user' => $user)
        );

        $reflection = new ReflectionClass($userform);
        $property = $reflection->getProperty('_form');
        $property->setAccessible(true);
        $mform = $property->getValue($userform);
        $mform->addElement('hidden', 'educli', 1);
        foreach ($mform->_elements as $element) {
            if (!isset($element->_attributes['name'])) {
                continue;
            }
            $name = $element->_attributes['name'];
            if (in_array($name, user_profile::removeElements()) ) {
                $mform->removeElement($name);
            }
        }
        return $userform;
    }
}