<?php

namespace theme_educli\output;
use stdClass;
use html_writer;
use moodle_url;
use mod_assign\output\renderer as assign_renderer;
use theme_educli\form\submission_form;

class mod_assign_renderer extends assign_renderer {


    /**
     * Renders the grading action menu.
     *
     * @param \mod_assign\output\grading_actionmenu $actionmenu The actionmenu
     * @return string The rendered grading action menu.
     */
    public function render_grading_actionmenu(\mod_assign\output\grading_actionmenu $actionmenu): string {
        $context = $actionmenu->export_for_template($this);
        $output = '';
        //$output .= html_writer::start_div("col-lg-9 col-md-9");
        //$output .= html_writer::start_div("main-mid-section-mls main-mid-frofile-mls");
        //$output .= html_writer::start_div("card-lms profile-card-d main-top");
        //$output .= html_writer::start_div("header-context");
        $output .= $this->render_from_template('mod_assign/grading_actionmenu', $context);
        //$output .= html_writer::start_div("row w-100 align-items-center");
        return $output;
    }

    /**
     * Render the grading table.
     *
     * @param \assign_grading_table $table
     * @return string
     */
    public function render_assign_grading_table(\assign_grading_table $table) {
        $params = [
            'submissionController' => true,
            'perpage' => $table->get_rows_per_page(),
            'filter' => get_user_preferences('assign_filter', ''),
            'contextid' => $this->page->context->id,
            'courseid' => $this->page->course->id,
            'cmid' => $this->page->cm->id
        ];
        $this->page->requires->js_call_amd('theme_educli/educliconfig', 'init', array('params' => $params));
        $o = '';
        // Define the search box.
        $searchbox = '';
        $o .= html_writer::start_div('col-lg-4 col-md-12 mt-lg-0 mt-md-2 mt-sm-2');
        $o .= html_writer::start_div('position-relative');
        $o .= html_writer::tag('input', null, [
            'type' => 'text',
            'name' => 'typeFullName',
            'placeholder' => 'Type Full Name',
            'class' => 'w-100'
        ]);
        $o .= html_writer::end_div(); // Close col-lg-4 col-md-12 mt-lg-0 mt-md-2 mt-sm-2.
        $o .= html_writer::end_div(); // Close position-relative.
        //$o .= html_writer::end_div(); // Close row w-100 align-items-center.
        //$o .= html_writer::end_div(); // Close header-context.
        //$o .= html_writer::end_div(); // Close card-lms profile-card-d main-top.

        // Start before render html.

        $o .= html_writer::start_div('card-lms mt-3');
        $o .= html_writer::start_div();


        $o .= $this->output->box_start('boxaligncenter gradingtable');
        $this->page->requires->js_init_call('M.mod_assign.init_grading_table', array());
        $this->page->requires->string_for_js('nousersselected', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmgrantextension', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmlock', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmremovesubmission', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmreverttodraft', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmunlock', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmaddattempt', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmdownloadselected', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmsetmarkingworkflowstate', 'assign');
        $this->page->requires->string_for_js('batchoperationconfirmsetmarkingallocation', 'assign');
        $this->page->requires->string_for_js('editaction', 'assign');
        foreach ($table->plugingradingbatchoperations as $plugin => $operations) {
            foreach ($operations as $operation => $description) {
                $this->page->requires->string_for_js('batchoperationconfirm' . $operation,
                                                     'assignfeedback_' . $plugin);
            }
        }
        $searchquery = '';
        if ($searchquery) {
            $table->sql->where .= " AND CONCAT(u.firstname, ' ', u.lastname) LIKE :liketext  ESCAPE '\\\'";
            $table->sql->params += ['liketext' => '%'.$searchquery.'%'];
        }
        $o .= $this->flexible_table($table, $table->get_rows_per_page(), true);
        $o .= $this->output->box_end();
        return $o;
    }

    /**
     * Render the header.
     *
     * @param assign_header $header
     * @return string
     */
    public function render_assign_header(\mod_assign\output\assign_header $header) {
        if ($header->subpage) {
            $this->page->navbar->add($header->subpage, $header->subpageurl);
            $args = ['contextname' => $header->context->get_context_name(false, true), 'subpage' => $header->subpage];
            $title = get_string('subpagetitle', 'assign', $args);
        } else {
            $title = $header->context->get_context_name(false, true);
        }
        $courseshortname = $header->context->get_course_context()->get_context_name(false, true);
        $title = $courseshortname . ': ' . $title;
        $heading = format_string($header->assign->name, false, array('context' => $header->context));

        $this->page->set_title($title);
        $this->page->set_heading($this->page->course->fullname);

        $description = $header->preface;
        $activityheader = $this->page->activityheader;
        $activityheader->set_attrs([
            'title' => $activityheader->is_title_allowed() ? $heading : '',
            'description' => $description
        ]);

        return $this->output->header();
    }


    /**
     * Renders the user submission action menu.
     *
     * @param \mod_assign\output\user_submission_actionmenu $actionmenu The actionmenu
     * @return string The rendered action menu.
     */
    public function render_user_submission_actionmenu(\mod_assign\output\user_submission_actionmenu $actionmenu): string {
        global $USER, $CFG, $PAGE;
        $content = '';
        $context = $actionmenu->export_for_template($this);
        $removecontext['remove'] = isset($context['remove']) ? $context['remove'] : [];
        $removeactionmenu = $this->render_from_template('mod_assign/user_submission_actionmenu', $removecontext);
        $userid = optional_param('userid', $USER->id, PARAM_INT);
        $data = new stdClass();
        $data->userid = $USER->id;
        $assign = new \assign($PAGE->context, $PAGE->cm, $PAGE->course);
        $instance = $assign->get_instance();
        $mform = new submission_form(null, array($assign, $data));
        $notices = [];
        // Submit the form submisson
        if ($formdata = $mform->get_data()) {
            $data->action = 'savesubmission';
            $userid = optional_param('userid', $USER->id, PARAM_INT);
            require_sesskey();
            if (!$assign->submissions_open($userid)) {
                $notices[] = get_string('duedatereached', 'assign');
                return false;
            }
            $assign->save_submission($data, $notices);
            $nextpageurl = new moodle_url('/mod/assign/view.php', ['id' => $assign->get_course_module()->id, 'action' => 'view']);
            redirect($nextpageurl);
        }
        // Check user need confirmation.
        if ($userid == $USER->id) {
            if (!$assign->can_edit_submission($userid, $USER->id)) {
                throw new \moodle_exception('nopermission');
            }
            // User is editing their own submission.
            require_capability('mod/assign:submit', $assign->get_context());
        } else {
            // User is editing another user's submission.
            if (!$assign->can_edit_submission($userid, $USER->id)) {
                throw new \moodle_exception('nopermission');
            }
        }
        $content .= $this->render_assign_form(new \assign_form('editsubmissionform', $mform));

        // Display the header description.
        $postfix = '';
        if ($this->has_visible_attachments($assign->get_context()->id) && (!$assign->get_instance($USER->id)->submissionattachments)) {
            $postfix = $assign->render_area_files('mod_assign', ASSIGN_INTROATTACHMENT_FILEAREA, 0);
        }
        $assignheader = new \mod_assign\output\assign_header($instance,
                                                      $assign->get_context(),
                                                      $assign->show_intro(),
                                                      $assign->get_course_module()->id,
                                                      '', '', $postfix);

        if ($assignheader->showintro || $assignheader->activity) {
            $description = $this->output->box_start('generalbox boxaligncenter');
            if ($assignheader->showintro) {
                $description .= format_module_intro('assign', $assignheader->assign, $assignheader->coursemoduleid);
            }
            if ($assignheader->activity) {
                $description .= $this->format_activity_text($assignheader->assign, $assignheader->coursemoduleid);
            }
            $description .= html_writer::start_div('right-edu-text-data-ass');
            $description .= html_writer::start_div('thard-rowprofile-card-lms mt-3');
            $description .= html_writer::start_div("card-lms profile-card-d");
            $description .= html_writer::start_div("has-section-assessment");
            $description .= html_writer::start_div("row");
            $description .= html_writer::start_div("col-lg-12");
                $description .= html_writer::tag("p", get_string('attachmentfromtrainer', 'theme_educli'));
            $description .= html_writer::end_div();
                $description .= $assignheader->postfix;
            $description .= html_writer::end_div();
            $description .= html_writer::end_div();
            $description .= html_writer::end_div();
            $description .= html_writer::end_div();
            $description .= html_writer::end_div();
            $description .= $this->output->box_end();
        }
        $content .= $description;
        $content .= $removeactionmenu;
        return $content;
    }

    public function has_visible_attachments($contextid) {
        $fs = get_file_storage();
        $files = $fs->get_area_files($contextid, 'mod_assign', ASSIGN_INTROATTACHMENT_FILEAREA,
                        0, 'id', false);
        return (count($files) > 0);
    }
}