<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Theme config for the theme educli.
 *
 * @package    theme_educli
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @authors    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

 namespace theme_educli;

use core_reportbuilder\external\reports\retrieve;
use moodle_url;

 class themeconfig {

    /**
     * get a header and footer data from theme educli settings page.
     * @return $themeconfigdata array header and footer data.
     */
    public function themedata() {
        global $PAGE, $OUTPUT, $USER;

        // Header.
        $logo = theme_educli_get_logo_url();
        // Nav drawer images.
        $profilepix = $OUTPUT->image_url('nav-lms-1', 'theme_educli');
        $lecturespix = $OUTPUT->image_url('nav-lms-2', 'theme_educli');
        $gradingpix = $OUTPUT->image_url('nav-lms-3', 'theme_educli');
        $studytoolboxpix = $OUTPUT->image_url('study-toolbox', 'theme_educli');
        $streamingevideopix = $OUTPUT->image_url('streaming-e-video', 'theme_educli');
        $hatlecturepix = $OUTPUT->image_url('graduation-hat-lecture', 'theme_educli');
        $examasessmpix = $OUTPUT->image_url('exam-asessm', 'theme_educli');
        $toolboxespix  = $OUTPUT->image_url('nav-lms-4', 'theme_educli');
        $evideospix = $OUTPUT->image_url('nav-lms-5', 'theme_educli');
        $notificationspix = $OUTPUT->image_url('nav-lms-6', 'theme_educli');
        $chatpix = $OUTPUT->image_url('lms-nva-chat', 'theme_educli');
        $hellopix = $OUTPUT->image_url('hello', 'theme_educli');
        if (isloggedin()) {
            $username = $USER->username;
        } else {
            $username = '';
        }
        // Hide the nav drawer on login page.
        $isloginpage = ($PAGE->pagelayout != 'login') ? true : false;
        $loginurl = get_login_url();
        $layoutcheck = (($PAGE->pagelayout == 'frontpage') || ($PAGE->pagelayout == 'login')) ? true : false;
        $footerclass = (($PAGE->pagelayout == 'frontpage') || ($PAGE->pagelayout == 'login')) ? 'lms-footer-section' : 'mls-footer-contect lms-footer-section';
        // Footer.
        $email = theme_educli_get_setting('emailid');
        $fburl = theme_educli_get_setting('fburl');
        $pinurl = theme_educli_get_setting('pinurl');
        $twurl = theme_educli_get_setting('twurl');
        $gpurl = theme_educli_get_setting('gpurl');
        $instagramurl = theme_educli_get_setting('instagramurl');
        $linkedinurl = theme_educli_get_setting('linkedinurl');
        $termsconditions = theme_educli_get_setting('termsconditions');
        $privacypolicyurl = theme_educli_get_setting('privacypolicyurl');
        $contacturl = theme_educli_get_setting('contacturl');
        $profileurl = new moodle_url('/user/profile.php');
        $themeconfigdata = [
            'logo' => $logo,
            'email' => $email,
            'fburl' => $fburl,
            'pinurl' => $pinurl,
            'twurl' => $twurl,
            'gpurl' => $gpurl,
            'instagramurl' => $instagramurl,
            'linkedinurl' => $linkedinurl,
            'termsconditions' => $termsconditions,
            'privacypolicyurl' => $privacypolicyurl,
            'isloginpage' => $isloginpage,
            'loginurl' => $loginurl,
            'profilepix' => $profilepix,
            'lecturespix' => $lecturespix,
            'gradingpix' => $gradingpix,
            'studytoolboxpix' => $studytoolboxpix,
            'streamingevideopix' => $streamingevideopix,
            'hatlecturepix' => $hatlecturepix,
            'examasessmpix' => $examasessmpix,
            'toolboxespix' => $toolboxespix,
            'evideospix' => $evideospix,
            'notificationspix' => $notificationspix,
            'chatpix' => $chatpix,
            'hellopix' => $hellopix,
            'username' => $username,
            'layoutcheck' => $layoutcheck,
            'footerclass' => $footerclass,
            'contacturl' => $contacturl,
            'profileurl' => $profileurl
        ];
        return $themeconfigdata;
    }
 }