<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * @package    theme_educli
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @authors    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
defined('MOODLE_INTERNAL') || die;

/* Header settings */
$header = new admin_settingpage('theme_educli_header', get_string('headerheading', 'theme_educli'));

    // Logo file setting.
    $name = 'theme_educli/logo';
    $title = get_string('logo', 'theme_educli');
    $description = get_string('logodesc', 'theme_educli');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'logo');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $header->add($setting);

    // Header background image file setting.
    $name = 'theme_educli/headerbgimg';
    $title = get_string('headerbgimg', 'theme_educli');
    $description = get_string('headerbgimgdesc', 'theme_educli');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'headerbgimg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $header->add($setting);

$settings->add($header);

/* Footer settings */
$footer = new admin_settingpage('theme_educli_footer', get_string('footerheading', 'theme_educli'));

    //Email.
    $name = 'theme_educli/emailid';
    $title = get_string('emailid', 'theme_educli');
    $description = '';
    $default = get_string('defaultemailid', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    /* Facebook, Pinterest, Twitter, Google+, Instagram, Linkedin Settings */
    $name = 'theme_educli/fburl';
    $title = get_string('fburl', 'theme_educli');
    $description = get_string('fburldesc', 'theme_educli');
    $default = get_string('fburl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    $name = 'theme_educli/pinurl';
    $title = get_string('pinurl', 'theme_educli');
    $description = get_string('pinurldesc', 'theme_educli');
    $default = get_string('pinurl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    $name = 'theme_educli/twurl';
    $title = get_string('twurl', 'theme_educli');
    $description = get_string('twurldesc', 'theme_educli');
    $default = get_string('twurl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    $name = 'theme_educli/gpurl';
    $title = get_string('gpurl', 'theme_educli');
    $description = get_string('gpurldesc', 'theme_educli');
    $default = get_string('gpurl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    $name = 'theme_educli/instagramurl';
    $title = get_string('instagramurl', 'theme_educli');
    $description = get_string('instagramurldesc', 'theme_educli');
    $default = get_string('instagramurl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    $name = 'theme_educli/linkedinurl';
    $title = get_string('linkedinurl', 'theme_educli');
    $description = get_string('linkedinurldesc', 'theme_educli');
    $default = get_string('linkedinurl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    // Terms & Conditions.
    $name = 'theme_educli/termsconditions';
    $title = get_string('termsconditionsurl', 'theme_educli');
    $description = get_string('termsconditionsurldesc', 'theme_educli');
    $default = get_string('termsconditionsurl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    // Privacy policy.
    $name = 'theme_educli/privacypolicyurl';
    $title = get_string('privacypolicyurl', 'theme_educli');
    $description = get_string('privacypolicyurldesc', 'theme_educli');
    $default = get_string('privacypolicyurl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

    // contact support
    $name = 'theme_educli/contacturl';
    $title = get_string('contacturl', 'theme_educli');
    $description = get_string('contacturl_desc', 'theme_educli');
    $default = get_string('contacturl_default', 'theme_educli');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $footer->add($setting);

$settings->add($footer);

/* Login settings */
$login = new admin_settingpage('theme_educli_login', get_string('loginheading', 'theme_educli'));

    // Login page image setting.
    $name = 'theme_educli/loginpageimg';
    $title = get_string('loginpageimg', 'theme_educli');
    $description = get_string('loginpageimg_desc', 'theme_educli');
    $setting = new admin_setting_configstoredfile($name, $title, $description, 'loginpageimg');
    $setting->set_updatedcallback('theme_reset_all_caches');
    $login->add($setting);

$settings->add($login);
