<?php 


namespace theme_enlight;

use html_writer;


defined('MOODLE_INTERNAL') || die('No direct access');

class customblocks {

	public $theme_jsdata;

	public function __construct() {
		$this->theme_jsdata = array();
	}

	/* Site features block.
	 *  return template|HTML.
	 */
	public function sitefeatures() {
		global $OUTPUT;
		$status = theme_enlight_get_setting('togglesitefeatures');
		$items = array();
		if ($status == 1) {
			$block = $this->get_block_title('sitefblocktitle', '');
			$features = theme_enlight_get_setting('numberofsitef');
			for ( $i=1; $i <= $features; $i++ ) {
				$status = theme_enlight_get_setting('sitefblock'.$i.'status');
				$image = theme_enlight_get_setting('sitefblock'.$i.'image', 'file');
				$link = theme_enlight_get_setting('sitefblock'.$i.'link');
				$items[] = [
					'status' => $status,
					'image' => $image,
					'title' => theme_enlight_get_setting('sitefblock'.$i.'title'),
					'description' => theme_enlight_get_setting('sitefblock'.$i.'content'),
					'link' => ($link) ? $link : 'javascript:void(0)',
				];
			}
			$block['features'] = $items;
			$block['sitefeatures'] = 1;	
			
			return $OUTPUT->render_from_template('theme_enlight/custom_blocks', $block);
		}

	}

	public function testimonials() {

		$toggletmonial = theme_enlight_get_setting('toggletmonial');
		if ($toggletmonial == 1) {

			// tmonialTraversal_status
			$configlist = array(
				'count' => ['numberoftmonials'],
				'autoplay' => ['testimonialAutoplay'],
				'title' => ['testimonialtitle'],
				'pagination' => ['tmonialTraversal_status'],
			);

			$block = $this->get_config_array($configlist);
			$block['classes'] = theme_enlight_block_backgroundclass('testimonialsbg_type');
			$itemsList = array(
				'testimonial' => ['tmonial${i}text', 'format_text'],
				'username' => ['tmonial${i}uname'],
				'userimage' => ['tmonial${i}img', 'file'],
				'userposition' => ['tmonial${i}userposition'],
			);
			$block['items'] = $this->get_items_config($itemsList, $block['count']);
			$this->include_frontslide_js('testimonials', ['autoplay' => ($block['autoplay']) ? true : false,
				'pagination' => ($block['pagination']) ? true : false]);
			return $this->render_template('testimonials', $block);
		}
		return '';
	}

	public function counter() {
		global $OUTPUT;
		$status = theme_enlight_get_setting('counterBlock');
		if ($status == 1) {
			$block = $this->get_block_title('countBlockTitle', 'countBlockDesc');
			$block['bgimage'] = theme_enlight_get_setting('counterbg_image', 'file');
			for ( $i=1; $i <= 4; $i++ ) {
				
				$items[] = [					
					'value' => theme_enlight_get_setting('countBlockValue'.$i),
					'content' => theme_enlight_get_setting('countBlockContent'.$i),					
				];
			}
			$block['items'] = $items;
			$block['counter'] = 1;
			return $OUTPUT->render_from_template('theme_enlight/custom_blocks', $block);
		}
	}

	/*
	 * About us block (marketing spot)
	 */
	public function marketingspot1() {
		$status = theme_enlight_get_setting('marketingSpot1_status');
		if ($status == 1) {
		    $ms['title'] = theme_enlight_get_setting('mspot1title');
			$ms['description'] = theme_enlight_get_setting('mspot1desc', 'format_html');
		    $ms['media'] = theme_enlight_get_setting('mspot1media', 'format_html');
		    $ms['class'] = '';
		    if (!empty($ms['media'])) {
		    	$ms['class'] .= ' media-available ';
		    }

		    if (!empty($ms['description'])) {
		    	$ms['class'] .= ' description_available ';
		    }
		    return $this->render_template('marketingspot1', $ms);
		}
	}

	public function marketingspot2() {
		$status = theme_enlight_get_setting('marketingSpot2_status');
		if ($status == 1) {
	    	$msp2['title'] = theme_enlight_get_setting('mspot2title', 'format_text');
    		$msp2['desc'] = theme_enlight_get_setting('mspot2desc', 'format_html');
			$url = theme_enlight_get_setting('mspot2url');
			$msp2['url'] = ($url) ? $url : 'javascript:void(0);';
			$msp2['urltxt'] = theme_enlight_get_setting('mspot2urltext', 'format_text');
			$target = theme_enlight_get_setting('mspot2urltarget');
			$msp2['urltarget'] = ($target) ? "_blank" : "_self";
			return $this->render_template('marketingspot2', $msp2);
		}
	}

	/**
	 * This code returns the our team block contents.
	 * @return type
	 */
	public function our_team() {
		global $OUTPUT;
		$ourteamStatus = theme_enlight_get_setting('ourteamStatus');
		if ($ourteamStatus == 0 ) {
			return '';
		}
		$numberofpersons = theme_enlight_get_setting('numberofpersons');
		$num = range(1, $numberofpersons);
		$checkstatus = theme_enlight_check_our_team_status($num);

		if (!empty($checkstatus)) {
			$rows = array_chunk($checkstatus, 4);
		} else {
			return "";
		}
		$title = theme_enlight_get_setting('ourteamTitle');
		$title = theme_enlight_lang($title);


		$teamContent = "";
			$teamContent .= html_writer::start_tag('div', array('class' => 'our-team', 'id' => 'ourteam'));
			$teamContent .= html_writer::start_tag('div', array('class' => 'container-fluid'));
			$teamContent .= html_writer::tag('h2', $title);

			$teamContent .= html_writer::start_tag('div', array('class' => 'row'));
			$teamContent .= html_writer::start_tag('div', array('class' => 'our_team_slider col-md-12', 'data-crow' => '4'));
			foreach ($rows as $row) {
			// $teamContent .= html_writer::start_tag('div', array('class' => 'row '));
				foreach ($row as $i) {

					$value = theme_enlight_get_team_user($i);
					if (!empty($value)) {
						$img = $OUTPUT->image_url("home/img", 'theme');
						$nouserimg = $OUTPUT->image_url('no-user', 'theme');
						$teamContent .= html_writer::start_tag('div', array('class' => 'card-block '));
						$teamContent .= html_writer::start_tag('div', array('class' => 'card-img'));
						$teamContent .= html_writer::empty_tag('img', array('src' => $value['userImg'] , 'width' => '150', 'height' => '150', 'alt' => 'our-team-1')); // Person Image.

						$teamContent .= html_writer::start_tag('div', array('class' => 'social-link'));

						if (!empty($value['userSocial_icon1'])) {
							$teamContent .= html_writer::link($value['userSocial_url1'], html_writer::tag('i', '', array('class' => 'fa '.$value['userSocial_icon1'])), array('class' => 'icon-link') );
						}
						if (!empty($value['userSocial_icon2'])) {
							$teamContent .= html_writer::link($value['userSocial_url2'], html_writer::tag('i', '', array('class' => 'fa '.$value['userSocial_icon2'])), array('class' => 'icon-link') );
						}
						if (!empty($value['userSocial_icon3'])) {
							$teamContent .= html_writer::link($value['userSocial_url3'], html_writer::tag('i', '', array('class' => 'fa '.$value['userSocial_icon3'])), array('class' => 'icon-link') );
						}
						if (!empty($value['userSocial_icon4'])) {
							$teamContent .= html_writer::link($value['userSocial_url4'], html_writer::tag('i', '', array('class' => 'fa '.$value['userSocial_icon4'])), array('class' => 'icon-link') );
						}

						$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of social-link -->.

						$teamContent .= html_writer::start_tag('div', array('class' => 'card-content'));
						$teamContent .= html_writer::start_tag('div', array('class' => 'card-header'));
						$teamContent .= html_writer::tag('h6', $value['username'] ); // Our Team Person Name.
						$teamContent .= html_writer::tag('span', $value['userPosition']);
						$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of Card-header -->.
						$teamContent .= html_writer::start_tag('div', array('class' => 'card-element'));
					//$teamContent .= html_writer::tag('p', $description); // Team person description.
						if (!empty($value['userProfileurl'])) {
							$teamContent .= html_writer::start_tag('div', array('class' => 'card-link'));
							$teamContent .= html_writer::link($value['userProfileurl'], get_string('seeprofile', 'theme_enlight'));
							$teamContent .= html_writer::end_tag('div'); // Div <!-- End of card-link -->.
						}
						$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of card-element -->.
						$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of card-content -->.
						$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of Card-img -->. /*changes*/
						$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of card-block -->.
					}
				}
				//$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of container -->.
			}
			$teamContent .= html_writer::end_tag('div');
			$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of container -->.
			$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of container -->.
			$teamContent .= html_writer::end_tag('div'); // Div <!-- End Of Our Team -->.
		//}
		$this->include_frontslide_js('ourteam');
		return $teamContent;
	}

	public function ourpartner() {
		$status = theme_enlight_get_setting('ourPartner_status');
		if ($status == 1) {
			$block = $this->get_block_title('ourPartner_title', 'ourPartner_desc');
			$js['autotime'] = theme_enlight_get_setting('ourPartner_autotime');
			$config = array(
				'autotime' => ['ourPartner_autotime'],
				'autoplay' => ['ourPartner_autoplay'],
				'count' => ['ourPartner_number'],
				'title' => ['ourPartner_title'],
				'description' => ['ourPartner_desc']
			);
			$block = $this->get_config_array($config);
			$itemsList = array(
				'title' => ['partner${i}title'],
				'img' => ['partner${i}img', 'file'],
				'link' => ['partner${i}link']
			);
			$block['partners'] = $this->get_items_config($itemsList, $block['count']);
			$this->include_frontslide_js('ourpartners', ['autoplay' => $block['autoplay'], 'autotime' => $block['autotime']]);
			return $this->render_template('ourpartner', $block);

		}
	}

	 /**
     * Define the call slider for frontpage blocks.
     * @param string $blockid block name
     * @param array $data
     * @return void
     */
    public function include_frontslide_js($blockid, $data=[]) {
        global $PAGE;
        $PAGE->requires->js_call_amd('theme_enlight/front-sliders', $blockid, $data);
    }

	public function add_theme_jsdata($variable, $data) {
		$this->theme_jsdata[$variable] = $data;
	}
	public function get_items_config($configlist=[], $count=null) {
		if (!empty($count)) {
			for ($i=1; $i<=$count; $i++) {
				$block = [];
				foreach ($configlist as $key => $config) {
					$setting = $config[0];
					eval("\$newconfig = \"$setting\";"); // Convert the config with count variable to variable.
					$type = (isset($config[1])) ? $config[1] : '';

					$block[$key] = theme_enlight_get_setting($newconfig, $type);
				}
				if (!empty($block['testimonial']) || !empty($block['username']) || !empty($block['userposition']) ) {
					$enable_content = true;
				} else {
					$enable_content = false;
				}
				$block['enable_content'] = $enable_content;
				$items[] = $block;
			}
			return isset($items) ? $items : [];
		}		
	}

	public function get_config_array($configlist=[]) {

		if  (!empty($configlist)) {
			foreach ( $configlist as $key => $config ) {
				
				$type = (isset($config[1])) ? $config[1] : '';
				$block[$key] = theme_enlight_get_setting($config[0], $type);
			}
			
			return $block;
		}
	}

	public function get_block_title($title, $desc) {		
		$return['title'] = ($title) ? theme_enlight_get_setting($title) : '';
		$return['description'] = ($desc) ? theme_enlight_get_setting($desc) : '';
		return $return;
	}

	public function render_template($template, $data) {
		global $OUTPUT;
		$data[$template] = 1;
		$data['ouput'] = $OUTPUT;
		return $OUTPUT->render_from_template('theme_enlight/custom_blocks', $data);
	}



}